#
# spec file for package yast2-packager
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-packager
VCS: https://src.suse.de/SLFO-pool/yast2-packager#fd42b93e6d8a636afee998000b8789912165277eb1e21620ca99a6e9b5774295
Version:        5.0.6
Release:        160000.1.3
Summary:        YaST2 - Package Library
License:        GPL-2.0-or-later
Group:          System/YaST
URL:            https://github.com/yast/yast-packager

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  update-desktop-files
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  rubygem(%{rb_default_ruby_abi}:cfa) >= 0.5.0
BuildRequires:  rubygem(%{rb_default_ruby_abi}:nokogiri)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
# Y2Storage::Device#exists_in_raw_probed
BuildRequires:  yast2-storage-ng >= 4.0.141
# break the yast2-packager -> yast2-storage-ng -> yast2-packager build cycle
#!BuildIgnore: yast2-packager
# Replace PackageSystem with Package
BuildRequires:  yast2 >= 4.4.38
# "service" attribute in Pkg.SourceEditSet()
BuildRequires:  yast2-pkg-bindings >= 5.0.2
# yast/rspec/helpers.rb
BuildRequires:  yast2-ruby-bindings >= 4.4.7
# Augeas lenses
BuildRequires:  augeas-lenses
BuildRequires:  ruby-solv

# Newly added RPM
Requires:       yast2-country-data >= 2.16.3
# "service" attribute in Pkg.SourceEditSet()
Requires:       yast2-pkg-bindings >= 5.0.2
# Replace PackageSystem with Package
Requires:       yast2 >= 4.4.38
# unzipping license file
Requires:       unzip
# HTTP, FTP, HTTPS modules (inst_productsources.ycp)
Requires:       yast2-transfer
# Bugzilla #305503 - storing/checking MD5 of licenses
Requires:       /usr/bin/md5sum
# .process agent
Requires:       yast2-core >= 2.16.35
# Y2Storage::Device#exists_in_raw_probed
Requires:       yast2-storage-ng >= 4.0.141
# Augeas lenses
Requires:       augeas-lenses
# zypp.conf model and minimal modifications (bsc#1023204)
Requires:       rubygem(%{rb_default_ruby_abi}:cfa) >= 0.5.0
# parsing xml with repositories
Requires:       rubygem(%{rb_default_ruby_abi}:nokogiri)
# One of libyui-qt-pkg, libyui-ncurses-pkg, libyui-gtk-pkg
Requires:       libyui_pkg
Requires:       ruby-solv
Requires:       yast2-ruby-bindings >= 1.0.0

# setenv() builtin
Conflicts:      yast2-core < 2.15.10
# NotEnoughMemory-related functions moved to misc.ycp import-file
Conflicts:      yast2-add-on < 2.15.15
# changed API in Y2Packager::ProductUpgrade and Yast::AddOnProduct
Conflicts:      yast2-registration < 5.0.1

# ensure that 'checkmedia' is on the medium
Recommends:     checkmedia
# for registering media add-ons on SLE
# (openSUSE does not contain the registration module)
%if 0%{?sles_version}
Recommends:     yast2-registration
%endif

# force *-webpin subpackage removal at upgrade
Obsoletes:      yast2-packager-devel-doc
Obsoletes:      yast2-packager-webpin < %version

%description
This package contains the libraries and modules for software management.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%suse_update_desktop_file org.opensuse.yast.Packager
%yast_metainfo

%files
%dir %{yast_yncludedir}/checkmedia
%dir %{yast_yncludedir}/packager
%dir %{yast_libdir}/packager
%dir %{yast_libdir}/packager/cfa
%dir %{yast_libdir}/y2packager
%dir %{yast_ybindir}
%{yast_ybindir}/*
%{yast_yncludedir}/checkmedia/*
%{yast_yncludedir}/packager/*
%{yast_libdir}/language_tag.rb
%{yast_libdir}/packager/*
%{yast_libdir}/y2packager/*
%{yast_libdir}/installation/*
%{yast_clientdir}/*.rb
%{yast_moduledir}/*
%{yast_desktopdir}/*.desktop
%{_datadir}/applications/*.desktop
%{yast_metainfodir}
%{yast_scrconfdir}/*
%{yast_execcompdir}/servers_non_y2/ag_*
%{yast_icondir}
%dir %{yast_docdir}
%license COPYING
%doc %{yast_docdir}/README.md

%changelog
* Mon Jan  6 2025 mvidner@suse.com
- Adjust test for ruby-3.4 (bsc#1235099)
- 5.0.6
* Tue Mar 12 2024 lslezak@suse.com
- Change the product mapping API to be the same as in SP5 and older
  (related to bsc#1220567)
- 5.0.5
* Thu Feb 22 2024 lslezak@suse.com
- Display a better product summary for the SLE_HPC => SLES upgrade
  (jsc#PED-7841)
* Tue Feb 13 2024 lslezak@suse.com
- SLE HPC is not a base product anymore, it is replaced by
  SLES + HPC module, added migration mapping (jsc#PED-7841)
- 5.0.4
* Thu Feb  8 2024 lslezak@suse.com
- Fixed ERB template loading in self update, if the template
  cannot be found using a relative path then fallback to the
  absolute path (bsc#1219174)
- 5.0.3
* Tue Jan  9 2024 lslezak@suse.com
- After installation disable the empty installation repository
  from the SLE15 Online medium (bsc#1182303)
- 5.0.2
* Wed Sep 20 2023 lslezak@suse.com
- Properly save the repo file when changing URL of a repository
  from a service (bsc#1214135)
- Also display a warning when changing URL of a service repository,
  the change might be lost after the service is refreshed
- 5.0.1
* Wed Aug 30 2023 jreidinger@suse.cz
- 5.0.0 (bsc#1185510)
* Tue Aug  8 2023 lslezak@suse.com
- Move loading the Pkg module to fix a failing unit test (bsc#1214069)
- 4.6.2
* Thu Apr  6 2023 jreidinger@suse.com
- Adapt test to changes in ruby-bindings when detecting Yast
  modules using public only methods (related to bsc#1210051)
- Comment out expensive debug calls to improve performance
  (bsc#1210051)
- 4.6.1
* Fri Mar  3 2023 lslezak@suse.cz
- Bump version to 4.6.0 (bsc#1208913)
* Mon Feb 20 2023 lslezak@suse.com
- Fixed a crash when selecting depending products (bsc#1208421)
- 4.5.16
* Tue Feb 14 2023 mvidner@suse.com
- Ruby 3.2: Change a test to treat dir:///foo equal to dir:/foo
  (bsc#1207239)
- 4.5.15
* Wed Feb  8 2023 shundhammer@suse.com
- Prevent crash if nil dependencies instead of [] (bsc#1208068)
- 4.5.14
* Thu Jan 26 2023 kanderssen@suse.com
- Added wicked-nbft package when Linuxrc sets UseNBFT
  (jsc#PED-3138, bsc#1207573)
- 4.5.13
* Thu Jan 26 2023 lslezak@suse.com
- Unescape the product name read from package Provides
  (bsc#1207276)
- 4.5.12
* Tue Jan 10 2023 lslezak@suse.com
- Media check fixes in containerized environment
  - Start browsing the ISO files from the /host directory
    to show the host files (bsc#1206834)
  - Fixed file readability check to correctly use the specified
    ISO file
- 4.5.11
* Tue Dec 20 2022 lslezak@suse.com
- Do not fail when the installation URL contains a space
  (bsc#1201816)
- 4.5.10
* Wed Dec 14 2022 shundhammer@suse.com
- Merged PR https://github.com/yast/yast-packager/pull/623
  by Christopher Yeleighton <giecrilj@stegny.2a.pl>:
  Do not call [Install done] on aborted packages (boo#1203302)
- 4.5.9
* Mon Nov  7 2022 lslezak@suse.cz
- Do not add an empty repository to the system when upgrading
  a registered system using the Full installation medium
  (bsc#1204399)
- 4.5.8
* Mon Oct 31 2022 mvidner@suse.com
- Fix hash vs keyword arguments in RSpec expectations (bsc#1204871)
- 4.5.7
* Tue Oct 25 2022 snwint@suse.com
- support 'repo' scheme for add-ons (jsc#SLE-22578, jsc#SLE-24584)
- 4.5.6
* Thu May 26 2022 lslezak@suse.cz
- Support managing system in a chroot (bsc#1199840)
- 4.5.5
* Tue May 17 2022 igonzalezsosa@suse.com
- Fix package counters in the installation slideshow
  (boo#1199621).
- 4.5.4
* Tue May  3 2022 lslezak@suse.cz
- Run the package solver after selecting additional system
  packages, fixes possible broken package dependencies after system
  upgrade (bsc#1195828)
- 4.5.3
* Wed Apr 27 2022 shundhammer@suse.com
- Don't rely on install.inf availability #(bsc#1198560)
- 4.5.2
* Wed Apr 27 2022 lslezak@suse.cz
- Fixed migration summary in Leap -> SLES migration (bsc#1198562)
* Thu Apr  7 2022 shundhammer@suse.com
- Show package downloads in the global progress bar during package
  installation (bsc#1195608)
  PR: https://github.com/yast/yast-packager/pull/612
- 4.5.1
* Wed Apr  6 2022 lslezak@suse.cz
- Bump version to 4.5.0 (bsc#1198109)
* Thu Mar 31 2022 lslezak@suse.cz
- Fixed regression in repository alias name for add-ons (bsc#1193214)
- 4.4.27
* Thu Mar 17 2022 lslezak@suse.cz
- Read the products from libzypp in installed system, fixes crash
  during online migration (related to jsc#SLE-17309)
- 4.4.26
* Tue Mar 15 2022 snwint@suse.com
- do not keep file handle to repo metadata open accidentally (bsc#1196061)
- 4.4.25
* Tue Mar  8 2022 lslezak@suse.cz
- Properly set the repository alias for the Full medium add-ons
  (bsc#1193214)
- 4.4.24
* Mon Feb 14 2022 lslezak@suse.cz
- Remove duplicate repositories created at the end of installation
  (repositories which are stored in the *.repo_1 files, bsc#1194546)
- 4.4.23
* Tue Feb  8 2022 igonzalezsosa@suse.com
- Fix a wrong reference to PackageSystem#EnsureSourceInit
  (bsc#1195519, related to bsc#1194886).
- 4.4.22
* Tue Jan 25 2022 igonzalezsosa@suse.com
- Use Package module instead of PackageSystem (bsc#1194886).
- 4.4.21
* Tue Jan 18 2022 lslezak@suse.cz
- Enabled RSpec verifying doubles (bsc#1194784)
- 4.4.20
* Wed Jan 12 2022 jreidinger@suse.com
- Simplify slide show to support future parallel installations
  (jsc#SLE-20437)
- 4.4.19
* Fri Dec 10 2021 jreidinger@suse.com
- Adapt iso handling to do properly double escaping ( fix for wrong
  fix for bsc#954813)
- Prepare code for ruby3 (bsc#1193192)
- 4.4.18
* Thu Dec  2 2021 lslezak@suse.cz
- Unify the Yes/No popup button IDs (bsc#1193326)
- 4.4.17
* Thu Dec  2 2021 lslezak@suse.cz
- Properly set the custom repository name (#1191491)
- 4.4.16
* Wed Dec  1 2021 igonzalezsosa@suse.com
- Add the register_target property to ProductSpec so it is
  available in all the derived classes (bsc#1193212).
- 4.4.15
* Mon Nov 22 2021 lslezak@suse.cz
- Use consistent names for the Full medium repositories
  (bsc#1191652)
- 4.4.14
* Fri Nov 12 2021 igonzalezsosa@suse.com
- Introduce the product specification API (bsc#1192626):
  - Add a ProductSpec and derived classes.
  - Drop ProductLocation and ProductLocationDetails.
  - Add a specific client to initialize the workflow of the
    selected product.
- 4.4.13
* Thu Nov  4 2021 lslezak@suse.cz
- Fixed missing license translations after going back in the
  installation workflow (bsc#1186747)
- 4.4.12
* Thu Nov  4 2021 lslezak@suse.cz
- Adjusted low memory message (bsc#1139325)
- 4.4.11
* Wed Sep 15 2021 shundhammer@suse.com
- Check if the "pkg" UI plug-in is available and if not, ask
  the user if it should be installed
  (jsc#SLE-20346, jsc#SLE-20462)
- 4.4.10
* Mon Aug 23 2021 lslezak@suse.cz
- Include some hints in the "Priority" label in the repository
  manager (if there is enough screen space) (bsc#1154693)
- 4.4.9
* Tue Aug 17 2021 lslezak@suse.cz
- Fixed evaluating module dependencies on the SLE Full medium
  - Ignore soft dependencies (Recommends), use only hard
    dependencies (Requires)
  - Do not select "Python2" module for "Workstation Extensions"
    (bsc#1188633)
- 4.4.8
* Thu Aug 12 2021 lslezak@suse.cz
- Adjusted memory check to display a low memory warning on RPi
  (bsc#1139325)
- 4.4.7
* Fri Jun 18 2021 schubi@schubi.de
- Adding NFS repository: Checking user input e.g. white spaces in
  server name (bsc#1168342).
- 4.4.6
* Thu Jun 17 2021 lslezak@suse.cz
- When editing a repository display the repository alias as a
  fallback if the repository name is not set, do not display
  empty name (bsc#1184935)
- 4.4.5
* Tue Jun 15 2021 igonzalezsosa@suse.com
- Fix the Comment entry in the desktop file so the tooltip
  in the control center is properly translated (bsc#1187270).
- 4.4.4
* Thu May 27 2021 lslezak@suse.cz
- Use the "armv7hl" packages on the "armv7l" architecture
  (bsc#1183795)
- 4.4.3
* Mon May 24 2021 lslezak@suse.cz
- Logging all available product information into directory
  /var/log/YaST2/installation_info. This should help for evaluating
  the cause of e.g. bsc#1180888, bsc#1180908, bsc#1178688.
- 4.4.2
* Thu Apr 22 2021 lslezak@suse.cz
- Revert copying the libzypp cache to the target system and
  replacing it by a symlink, it is not safe and it can
  cause crash (segfault) in some cases (bsc#1183711)
- 4.4.1
* Wed Apr  7 2021 dgonzalez@suse.com
- Hide the abort button when the network client is called
  (bsc#1183586).
- 4.4.0
* Thu Mar 18 2021 lslezak@suse.cz
- Do not create zypp cache symlink when running in installed
  system, it would create /var/cache/zypp -> /var/cache/zypp
  loop (bsc#1183683)
- Remove the "Software Repositories" button from the YaST console,
  users can easily break the installer with it. Added
  "configure_repositories" command to the command line interface
  for experts (bsc#1183687)
- 4.3.20
* Thu Mar 11 2021 lslezak@suse.cz
- Move the libzypp cache to the installed system to save some
  memory and avoid crashing because out of memory (bsc#1182928)
- 4.3.19
* Tue Mar  9 2021 lslezak@suse.cz
- Added IBM tools product rename to the list (part of bsc#1182837)
- 4.3.18
* Mon Mar  8 2021 igonzalezsosa@suse.com
- During installation, explain what "online repositories" are
  (bsc#1180707).
- 4.3.17
* Mon Mar  8 2021 lslezak@suse.cz
- Extend the special installer configuration dialog with
  repository options (jsc#PM-1895, jsc#SLE-16263)
- 4.3.16
* Fri Mar  5 2021 ancor@suse.com
- Support for configuring minimalistic DNF (bsc#1182849)
  contributed by Sasi Olin (hel@lcp.world).
- 4.3.15
* Fri Feb 19 2021 jreidinger@suse.com
- Show correct number of downloaded packages in log (bsc#1180278)
- Fix crash when installation proposal require pattern and such
  pattern is not available in any repository (found during testing
  jsc#SLE-17427)
- 4.3.14
* Mon Feb 15 2021 jreidinger@suse.com
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 4.3.13
* Fri Jan 15 2021 ancor@suse.com
- Proposal: fixed the logic to detect whether the partitioning has
  changed since the previous execution (found by bsc#1180537).
- 4.3.12
* Thu Nov 26 2020 jreidinger@suse.com
- correct add-on spelling (jsc#SLE-14772)
- 4.3.11
* Mon Oct 26 2020 jreidinger@suse.com
- Confirm abort in product license dialog (bsc#1178005)
- 4.3.10
* Mon Oct 12 2020 schubi@suse.de
- VNC installation: Removed xorg-x11 package from the needed
  package list (bsc#1172459).
- 4.3.9
* Mon Sep 21 2020 lslezak@suse.cz
- Fixed WFM.Args call to not produce an error message in the y2log
  (bsc#1176653)
- 4.3.8
* Wed Sep 16 2020 lslezak@suse.cz
- Fixed name of the add-on repository (bsc#1175374, related
  to bsc#1172477)
- 4.3.7
* Thu Jul 30 2020 schubi@suse.de
- AY: Calling of post-partitioning scripts moved from dropped
  inst_autoimage to inst_kickoff (bsc#1140711).
- 4.3.6
* Mon Jul 27 2020 jreidinger@suse.com
- Handle exceptions when parsing xml file (related to bsc#1170886)
- 4.3.5
* Tue Jul 14 2020 aschnell@suse.com
- Handle variable expansion in repository name (bsc#1172477)
- 4.3.4
* Mon Jul 13 2020 lslezak@suse.cz
- Improve medium type detection, do not report Online medium
  when the /media.1/products file is missing in the repository,
  SMT does not mirror this file (bsc#1173336)
- 4.3.3
* Thu Jun  4 2020 jreidinger@suse.com
- Replace anyxml agent with rubygem-nokogiri as yast2 already
  depends on nokogiri, to reduce amount of used xml parsers.
  (related to bsc#1170886)
- 4.3.2
* Mon May 11 2020 shundhammer@suse.com
- Removed widget option :immediate which is undefined for the
  MultiSelectionBox widget (bsc#1170431)
- 4.3.1
* Thu May  7 2020 mchf@suse.cz
- bnc#1166661
  - do not crash on empty system_packages_repos.yaml
- 4.3.0
* Mon Apr 20 2020 jreidinger@suse.com
- prevent race condition between log rotation and migration
  log backup (bsc#1166174)
- 4.2.62
* Wed Apr  8 2020 lslezak@suse.cz
- Allow updating the roles via self_update repository (bsc#1168702)
- 4.2.61
* Thu Mar 26 2020 dgonzalez@suse.com
- Reverts changes made in 4.2.59 to improve the addons selection,
  keeping it as it was (bsc#1167523).
- 4.2.60
* Thu Mar 12 2020 dgonzalez@suse.com
- Improve the product selection dialog (related to bsc#1157780).
- 4.2.59
* Fri Mar  6 2020 lslezak@suse.cz
- Avoid unselecting the base product (related to bsc#1165501)
- 4.2.58
* Thu Mar  5 2020 jlopez@suse.com
- Avoid to abort the installer when the user decides to not fix a
  repository url (bsc#1163015).
- 4.2.57
* Wed Mar  4 2020 jreidinger@suse.com
- fix showing count of packages to install in slide show
  (bsc#1161412)
- 4.2.56
* Fri Feb 28 2020 igonzalezsosa@suse.com
- In the addon selector, display by default the information of the
  first available product (related to bsc#1157780).
- 4.2.55
* Fri Feb 28 2020 igonzalezsosa@suse.com
- Do not crash when the list of preselected modules is not defined
  (related to jsc#SLE-8040, jsc#SLE-11455).
- 4.2.54
* Thu Feb 27 2020 lslezak@suse.cz
- Fixed going back (bsc#1163023)
- 4.2.53
* Tue Feb 25 2020 lslezak@suse.cz
- Preselect the default modules in the offline installation
  (jsc#SLE-8040, jsc#SLE-11455)
- 4.2.52
* Wed Feb 19 2020 jlopez@suse.com
- Media checker does not complain because sha checksums
  (bsc#1158432).
- Media checker shows information about the signature.
- 4.2.51
* Tue Feb 18 2020 dgonzalez@suse.com
- Avoid crashing when changing a language and keyboard layout
  (bsc#1161842).
- 4.2.50
* Wed Feb  5 2020 igonzalezsosa@suse.com
- Enable the "Search Online" menu entry for those systems that
  are registered or that can be registered (jsc#SLE-9109).
- 4.2.49
* Tue Feb  4 2020 jreidinger@suse.com
- Mark packager and repositories as WSL capable modules
  (bsc#1162650)
- 4.2.48
* Wed Jan 29 2020 shundhammer@suse.com
- Don't overwrite the default English license for add-on modules
  with the translated license of the current installation language
  (bsc#1160806)
- 4.2.47
* Mon Jan 27 2020 lslezak@suse.cz
- Move y2packager/repository.rb to the yast2.rpm
  (related to bsc#1159433)
- 4.2.46
* Fri Jan 17 2020 igonzalezsosa@suse.com
- Enable the online_search if system is registered (jsc#SLE-9109).
- 4.2.45
* Fri Jan 10 2020 schubi@suse.de
- Do not refresh package installation overview if the medium has
  been changed and the user has switched to the release notes tab.
  (bsc#1129426, bsc#1159367)
- 4.2.44
* Fri Jan 10 2020 jreidinger@suse.com
- PackageSlideShow: Do not show medium if there is only one
  (bsc#1158498)
- PackageSlideShow: Show hourglass when computing remaining time
- PackageSlideShow: Never exceed 2 hours for time estimation
- 4.2.43
* Thu Jan  2 2020 jreidinger@suse.com
- Improve warning when all repositories are disabled (bsc#1158512)
- 4.2.42
* Mon Dec 30 2019 jreidinger@suse.com
- Do not unexpectly end during slide show script progress
  (bsc#1159461)
- 4.2.41
* Fri Dec 20 2019 jreidinger@suse.com
- do not crash when invalid URL is used in config mode
  (bsc#1073208)
- 4.2.40
* Wed Dec 11 2019 igonzalezsosa@suse.com
- Speed up product renames calculation (bsc#1157926).
- 4.2.39
* Tue Dec 10 2019 schubi@suse.de
- AY Export: Exporting product_dir into the configuration file.
  (bsc#1158450)
- 4.2.38
* Thu Dec  5 2019 jreidinger@suse.com
- Allow to override medium type to allow to upgrade registered
  system with Full medium (jsc#SLE-7101)
- 4.2.37
* Thu Nov 28 2019 schubi@suse.de
- Moved resolvable class to yast2 package (bsc1140037).
- 4.2.36
* Wed Nov 27 2019 igonzalezsosa@suse.com
- Fix a typo in the "Extension and Module Selection" screen
  (bsc#1157789).
- 4.2.35
* Tue Nov 26 2019 igonzalezsosa@suse.com
- Show beta warning only once (bsc#1156629).
- 4.2.34
* Fri Nov  8 2019 schubi@suse.de
- Using Y2Packager::Resolvable.any? and Y2Packager::Resolvable.find
  in order to decrease the required memory (bsc#1132650,
  bsc#1140037).
- 4.2.33
* Fri Nov  8 2019 lslezak@suse.cz
- Preselect the installed add-ons when upgrading from the Full
  installation medium (related to jsc#SLE-7101)
- 4.2.32
* Fri Nov  1 2019 lslezak@suse.cz
- Do not crash when the product licenses cannot be read
  (bsc#1155454)
- 4.2.31
* Tue Oct  1 2019 lslezak@suse.cz
- Do not add an empty repository from the offline medium root
  (jsc#SLE-7101)
- 4.2.30
* Tue Oct  1 2019 lslezak@suse.cz
- Small refactoring related to the offline medium (jsc#SLE-7101)
- 4.2.29
* Fri Sep 27 2019 lslezak@suse.cz
- Support for the offline installation medium (jsc#SLE-7101)
- 4.2.28
* Wed Sep 18 2019 lslezak@suse.cz
- Support for the online installation medium (jsc#SLE-7214)
- 4.2.27
* Wed Sep 18 2019 lslezak@suse.cz
- Properly initialize the used base product name at upgrade
  (bsc#1150856)
- 4.2.26
* Wed Sep  4 2019 lslezak@suse.cz
- Added Y2Packager::MediumType class for detecting the installation
  medium type (related to jsc#SLE-7214)
- 4.2.25
* Wed Aug 28 2019 jlopez@suse.com
- Avoid error when generating some warnings (bsc#1148536).
- 4.2.24
* Mon Aug  5 2019 dgonzalez@suse.com
- Select the forced base product during the repositories
  initialization (bsc#1124590, bsc#1143943).
- 4.2.23
* Fri Jul 26 2019 lslezak@suse.cz
- Fixed product selection for single repositories: do not scan
  the products when there is only one repository, the scan is not
  needed (related to bsc#1141414)
- 4.2.22
* Thu Jul 25 2019 dgonzalez@suse.com
- Set the proper release version for newly added repos always, not
  only during upgrade (bsc#1132748).
- 4.2.21
* Wed Jul 24 2019 dgonzalez@suse.com
- Add method to get the dependencies of a product (bsc#1142535).
- 4.2.20
* Tue Jul 23 2019 jlopez@suse.com
- Add method to get the summary of a product (bsc#1142414).
- 4.2.19
* Mon Jul 15 2019 lslezak@suse.cz
- Fixed the unit test for the previous change to work also on
  other architectures than x86_64 (related to bsc#1141414)
- 4.2.18
* Thu Jul 11 2019 lslezak@suse.cz
- Improved product selection for multi-repositories media
  (bsc#1141414):
  - Display more product details
  - Handle the product dependencies
- 4.2.17
* Thu Jun 20 2019 dgonzalez@suse.com
- Better handling of license agreement dialog, allowing to
  distinguish when the user is declining a license or aborting
  the installation (bsc#1114018)
- 4.2.16
* Mon Jun 17 2019 schubi@suse.de
- Package installation: Rebuild slide show dialog and enable
  realease notes tab (bsc#1136708).
- 4.2.15
* Thu Jun 13 2019 dgonzalez@suse.com
- Allow to select the license language when running in textmode
  (bsc#1135901)
- 4.2.14
* Mon Jun  3 2019 hellcp@mailbox.org
- Replace icondir with an url schema (boo#1125594)
- 4.2.13
* Mon Jun  3 2019 hellcp@mailbox.org
- Add metainfo (fate#319035)
- 4.2.12
* Mon Jun  3 2019 lslezak@suse.cz
- Fixed the unit tests for Y2packager::Resolvables to pass also on
  the other archs than x86_64 (related to bsc#1132650, bsc#1136051)
- 4.2.11
* Thu May 30 2019 lslezak@suse.cz
- Define the openSUSE => SLES product migration to properly display
  the migration summary text (bsc#1136325)
- 4.2.10
* Tue May 28 2019 lslezak@suse.cz
- With the previous fix 1GB RAM is enough for using the online
  repositories, decrease the required memory limit (remove the
  workaround for bsc#1132650)
- 4.2.9
* Thu May 23 2019 lslezak@suse.cz
- Added new Y2packager::Resolvables class
- Use it in the installer to decrease the needed memory
  (bsc#1132650, bsc#1136051)
- 4.2.8
* Tue May 21 2019 schubi@suse.de
- List of Online Repositories: Overwrite already existing repos in
  "new installation" mode (bsc#1132622).
- 4.2.7
* Tue May 14 2019 schubi@suse.de
- List of Online Repositories: Do not show already added repos.
  Replace $releasever by the current product version.
  (bsc#1132622)
- 4.2.6
* Fri May 10 2019 lslezak@suse.cz
- Increase the memory limit warning for the online repositories to
  1.5GiB to avoid freezing the installer (bsc#1132650)
* Tue May  7 2019 lslezak@suse.cz
- Properly handle going back when selecting the modules from the
  Packages DVD medium (bsc#1131968)
* Thu May  2 2019 mvidner@suse.com
- Prefer control.xml to ProductFeatures for Community Repositories
  (bsc#1132613)
- 4.2.5
* Fri Apr 26 2019 lslezak@suse.cz
- Display human readable product names instead of the internal IDs
  when upgrading from SLES12 + SUMA Proxy + SUMA Branch Server
  (related to bsc#1133215)
- 4.2.4
* Tue Apr  9 2019 schubi@suse.de
- Update proposal: Showing product obsoletes. (bsc#1131503)
- 4.2.3
* Wed Apr  3 2019 schubi@suse.de
- Package proposal: Reset solver state before starting the next
  solver run (related to bsc#1077399).
- 4.2.2
* Wed Mar 27 2019 dgonzalez@suse.com
- Fix malformed rpm commands (bsc#1129422).
- The same changes were originally made for SP1, 4.1.35.
- 4.2.1
* Tue Mar 26 2019 schubi@suse.de
- Fix: Checking if the proposal has been changed (right sorting).
  (bsc#1125718)
- 4.2.0
* Mon Mar 25 2019 shundhammer@suse.com
- Use correct method name mount_path, not nonexistent mountpoint
  (bsc#1130287)
- 4.1.34
* Fri Mar 15 2019 schubi@suse.de
- AutoYaST: Disabling local repositories in second stage only.
  (bsc#1127818)
- 4.1.33
* Thu Mar  7 2019 schubi@suse.de
- Bug fix: Changing repo URL has been ignored (bsc#1119564).
- 4.1.32
* Wed Mar  6 2019 okurz@suse.com
- Correct english wording for missing patterns (bsc#1117535).
- 4.1.31
* Mon Mar  4 2019 jreidinger@suse.com
- fix showing help text for product license (bsc#1126491)
- 4.1.30
* Wed Feb 27 2019 mvidner@suse.com
- Use the correct path for /usr/bin/eject (bsc#1127138)
- 4.1.29
* Thu Feb 14 2019 mvidner@suse.com
- When patterns are missing, use 1 pop-up instead of many,
  and suggest to register or apply add-ons (bsc#1117535).
- 4.1.28
* Thu Feb 14 2019 lslezak@suse.cz
- Automatically preselect the driver packages from new repositories
  (bsc#953522)
- 4.1.27
* Fri Feb  8 2019 knut.anderssen@suse.com
- Replaced SuSEFirewall2 by firewalld when checking if the firewall
  is running and thus maybe blocking SLP discovery (fate#323460)
- 4.1.26
* Tue Jan 29 2019 dgonzalez@suse.com
- Change wording of the popup that asks to enable online repos
  (related to bsc#1112937).
- 4.1.25
* Thu Dec 27 2018 dgonzalez@suse.com
- Display the license agreement checkbox only when needed
  (related to fate#325482)
- 4.1.24
* Mon Dec 17 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.23
* Mon Dec 17 2018 ancor@suse.com
- If linuxrc does not provide a repo URL (parameter NOREPO), use
  the fallback repository included in the inst-sys to get the
  information about the products (fate#325482).
- 4.1.22
* Sat Dec 15 2018 hellcp@mailbox.org
- Add missing icons and edit current ones (boo#1109310)
- 4.1.21
* Wed Dec  5 2018 snwint@suse.com
- remove cd:/// fallback installation URL (fate#325482)
- 4.1.20
* Thu Nov 29 2018 lslezak@suse.cz
- We do not need yast2_theme for building this package,
  the desktopfile icon is included in this package now
  (related to boo#1109310)
- 4.1.19
* Wed Nov 28 2018 noahadvs@gmail.com
- Provide icon with module (boo#1109310)
- 4.1.18
* Wed Nov 21 2018 knut.anderssen@suse.com
- software_proposal: Added warning in case the NTP configuration
  was modified but the package is not selected to be installed
  (bsc#1082369)
- 4.1.17
* Tue Nov 20 2018 schubi@suse.de
- Function SelectProduct removed in order NOT to select All
  available products (bsc#1116332).
- 4.1.16
* Mon Nov 19 2018 mfilka@suse.com
- fate#325541
  - disabling CD / DVD repositories according to control file setup
- 4.1.15
* Fri Nov 16 2018 lslezak@suse.cz
- sw_single_wrapper: fixed invalid variable reset causing a
  possible command injection vulnerability via environment
  variable (bsc#1116226)
- 4.1.14
* Wed Nov 14 2018 shundhammer@suse.com
- Support for adding online repos during installation (bsc#1112937)
- Added pop-up dialog to ask user first if he would like to add
  online repos during installation and upgrade (only once)
- 4.1.13
* Fri Nov  2 2018 lslezak@suse.cz
- Break the yast2-packager -> yast2-storage-ng -> yast2-packager
  build cycle (bsc#1114517)
- 4.1.12
* Thu Nov  1 2018 jreidinger@suse.com
- Set during upgrade proper release version for newly added repos
  (bsc#1090193)
- 4.1.11
* Wed Oct 31 2018 jreidinger@suse.com
- Allow specify alias for online repos (bsc#1017823)
- Do not depend on yast2-installation (bsc#876533)
- 4.1.10
* Tue Oct 16 2018 schubi@suse.de
- Fixed path to license file. Build error in bsc#1110913.
- 4.1.9
* Mon Oct  8 2018 lslezak@suse.cz
- Ignore a read failure when backing up /var/log/YaST2, YaST might
  be updating the logs while the archive is being created
  (bsc#1110913)
- 4.1.8
* Tue Sep 25 2018 lslezak@suse.cz
- Copy also the role packages from the self-update repository
  (bsc#1101016)
- 4.1.7
* Fri Sep 21 2018 schubi@suse.de
- add_on_products.xml : Added tag "confirm_license" to handle
  Add-On-products licenses which will be added while installation.
  (bsc#1105758)
- 4.1.6
* Thu Sep 13 2018 lslezak@suse.cz
- Copy the selected packages from the self-update repository to an
  additional add-on repository, allow updating the installation
  workflow from the self-update repository (bsc#1101016)
- 4.1.5
* Mon Sep  3 2018 lslezak@suse.cz
- Fixed service check for the newly added repositories in the
  repository manager (bsc#1106837)
- 4.1.4
* Fri Aug 31 2018 snwint@suse.com
- allow hard disks with file systems to be selected in add-on dialog (bsc#1003263)
- 4.1.3
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Mon Aug 20 2018 schubi@suse.de
- Changed destination directory of COPYING file.
* Mon Jul 16 2018 lslezak@suse.cz
- Do not display a false "not enough free space" warning popup if
  the free space is bigger than 8EiB (2^63) (bsc#991090)
- Do not display the "not enough free space" warning for partitions
  where nothing is going to be installed (bsc#926841)
- 4.1.2
* Tue Jun 26 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.1.1
* Tue Jun 12 2018 jreidinger@suse.com
- Repositories: sort by name if priorities are same (bsc#957372)
- 4.1.0
* Tue May 29 2018 igonzalezsosa@suse.com
- When running the installation in textmode, consider only the
  preselected language when showing the license for extensions,
  modules or add-ons (related to bsc#1094793).
- 4.0.67
* Tue May 29 2018 knut.anderssen@suse.com
- During an upgrade, skip the base produce license dialog when the
  same license was already accepted (bsc#1080450)
- 4.0.66
* Tue May 29 2018 jsrain@suse.cz
- rename SLES_HPC => SLE_HPC (bsc#1095053)
- 4.0.65
* Tue May 29 2018 igonzalezsosa@suse.com
- When running the installation in textmode, consider only the
  preselected language when showing the license (bsc#1094793).
- 4.0.64
* Thu May 17 2018 lslezak@suse.cz
- Display an error popup when the FIPS compliant mode is active
  and the "fips" pattern is not available (installing an
  unregistered system or without the Packages DVD) (bsc#1093060)
- 4.0.63
* Wed May 16 2018 lslezak@suse.cz
- Fixed argument handling in the .desktop file for the
  "Install/Remove Software" item (bsc#1087352)
- Properly process paths containing spaces or special shell
  characters
- 4.0.62
* Thu May  3 2018 lslezak@suse.cz
- Adapted /dev cleanup at upgrade to work properly with the
  registration rollback (bsc#1089643)
- 4.0.61
* Tue Apr 24 2018 igonzalezsosa@suse.com
- Fix text direction for RTL languages in software patterns list
  (bsc#1089846).
- 4.0.60
* Thu Apr 19 2018 gsouza@suse.com
- Added warning to inform the user that changes in a repository
  managed by a service will be lost in the next refresh of the
  service (bsc#1078323).
- 4.0.59
* Mon Apr 16 2018 igonzalezsosa@suse.com
- In AutoYaST, skip base product license dialog when the same
  license was already accepted (fate#325461).
- 4.0.58
* Mon Apr 16 2018 lslezak@suse.cz
- The Advanced Systems Management Module has been moved to the
  Basesystem module, added the product change into the list
  (related to bsc#1089477)
- 4.0.57
* Tue Apr 10 2018 schubi@suse.de
- Error: Add-On products has been reset during the installation
  workflow (bnc#1086846). Set it again while setting the base
  product.
- 4.0.56
* Thu Apr  5 2018 knut.anderssen@suse.com
- Given a license, remember whether another one with the same
  content was already accepted (fate#325461).
- 4.0.55
* Wed Apr  4 2018 lslezak@suse.cz
- Better evaluate the product to upgrade, do not use the package
  solver if there is only one base product to install, use some
  fallbacks when the solver fails (bsc#1086259)
- 4.0.54
* Tue Apr  3 2018 jlopez@suse.com
- Fix tests to use correct storage instance (part of fate#318196).
- 4.0.53
* Tue Mar 27 2018 jlopez@suse.com
- Adapt to API changes in storage-ng (part of bsc#1082542).
- 4.0.52
* Tue Mar 27 2018 lslezak@suse.cz
- Added a known upgrade from SLE-HPC to SLES_HPC (bsc#1086734)
- 4.0.51
* Mon Mar 26 2018 lslezak@suse.cz
- SLES-12 + HPC module can be upgraded to SLES_HPC-15, display
  correctly this product change in the migration selection and the
  upgrade summary dialog (bsc#1086734)
- 4.0.50
* Thu Mar 15 2018 lslezak@suse.cz
- Cleanup, do not use the obsolete scripts which have been dropped
  (part of bsc#1080979)
- 4.0.49
* Mon Mar 12 2018 lslezak@suse.cz
- Fixed crash when displaying license agreement in the registration
  module (a private method called) (bsc#1084847)
- 4.0.48
* Fri Mar  9 2018 jreidinger@suse.com
- Always allow next/back for adding new addon (bsc#1082286)
- 4.0.47
* Mon Mar  5 2018 schubi@suse.de
- Confirm base license: parameter for disabling back button.
  Needed for showing base product license while AutoYaST
  installation (bnc#1073324).
- 4.0.46
* Fri Mar  2 2018 lslezak@suse.cz
- Updated repository selection label to be more understandable
  (bsc#1081508)
- 4.0.45
* Tue Feb 27 2018 lslezak@suse.cz
- Added product merge: SLE11/12 HA GEO has been merged to SLE15 HA
  (bsc#1069705)
- Added a missing textdomain in a file (bsc#1083015)
- Unified text domains to "packager"
- 4.0.44
* Tue Feb 27 2018 lslezak@suse.cz
- Added Live Patching product rename (bsc#1074154)
- 4.0.43
* Mon Feb 26 2018 lslezak@suse.cz
- Fixed installing packages needed for accessing the installation
  repositories (e.g. "nfs-client" for "nfs://" repositories),
  additionally evaluate also the add-on repositories, not just the
  base product repository (bsc#1063980)
- 4.0.42
* Thu Feb 22 2018 schubi@suse.de
- Added textdomain in order to activate translation (bnc#1081365).
- 4.0.41
* Thu Feb 22 2018 lslezak@suse.cz
- Added product renames for the SDK and the Toolchain module
  (bsc#1080913)
- 4.0.40
* Thu Feb 15 2018 igonzalezsosa@suse.com
- Display licenses translations (related to FATE#322276).
- 4.0.39
* Thu Feb 15 2018 lslezak@suse.cz
- Also display the licenses stored in the RPM-MD repository
  metadata, fixes displaying the license e.g. for SLE15-HA
  product on the Packages DVD (bsc#1057223)
- 4.0.38
* Fri Feb  9 2018 jlopez@suse.com
- Adapt to new MountPoint API (part of fate#318196).
- 4.0.37
* Wed Feb  7 2018 jsrain@suse.cz
- only use the repo from root of installation media (bsc#1078768)
- 4.0.36
* Fri Feb  2 2018 igonzalezsosa@suse.com
- InstProductLicense client provides the current language when
  asking for the product's license to the yast2.rpm API
  (related to bsc#1079045).
- 4.0.35
* Thu Feb  1 2018 lslezak@suse.cz
- Remove also the release_notes_fetchers/base.rb file
  (related to fate#323163)
- 4.0.34
* Thu Feb  1 2018 lslezak@suse.cz
- Move some Y2Packager files to yast2 package to avoid circular
  dependency (related to fate#323163)
- 4.0.33
* Mon Jan 29 2018 lslezak@suse.cz
- Reimplemented package reset to require less memory
  (related to bsc#1076768)
- 4.0.33
* Fri Jan 26 2018 lslezak@suse.cz
- Display a correct product license and release notes at upgrade
  from SLE12, correctly filter out the old installed products
  (fate#1076513)
- 4.0.32
* Fri Jan 26 2018 jreidinger@suse.com
- Hot fix for big memory consumption during NET installer with
  whole TW repo (bsc#1076768)
- 4.0.31
* Tue Jan 23 2018 lslezak@suse.cz
- Do not display the license again when going back (bsc#1069124)
- 4.0.30
* Wed Jan 17 2018 lslezak@suse.cz
- Added a new client for displaying the product license at upgrade
  (bsc#1069124)
- 4.0.29
* Thu Jan 11 2018 lslezak@suse.cz
- Decrease the priority of the initial DVD installation repository
  to prefer the packages from the other DVD media (avoid media
  changes between the "Packages" and the "Installer" DVDs)
  (bsc#1071742)
- 4.0.28
* Tue Jan  9 2018 lslezak@suse.cz
- Space check: ignore the partitions mounted before the installer
  is started, e.g. ignore the HDD installation source or the user
  mounts for remote logging (bsc#1073696)
- 4.0.27
* Mon Jan  8 2018 lslezak@suse.cz
- Improved disk usage check - check the parent directory if the
  target directory does not exist (yet) (bsc#1073696)
- 4.0.26
* Mon Jan  8 2018 lslezak@suse.cz
- Allow different handling handling of addons without
  installation.xml file (related to bsc#1074766)
- Display the installation summary tab by default in the package
  manager when adding addons
- 4.0.25
* Fri Dec 15 2017 schubi@suse.de
- Warn the user if the infrastructure is not available for running
  the second stage (bnc#1061754)
- 4.0.24
* Thu Dec 14 2017 igonzalezsosa@suse.com
- Do not take into account non-installed products when deciding
  which local repositories should be disabled after the
  installation (bsc#1072595 and also related to bsc#1071702).
- 4.0.23
* Wed Dec 13 2017 lslezak@suse.cz
- Make the dialog for selecting modules from DVD look similar
  to the module selection dialog in registration (bsc#1071771)
- 4.0.22
* Mon Dec 11 2017 igonzalezsosa@suse.com
- Do not cache products status (related to bsc#1072063)
- 4.0.21
* Thu Dec  7 2017 igonzalezsosa@suse.com
- Consider only installed products when deciding whether to disable
  or not local repositories (bsc#1071702).
- 4.0.20
* Fri Dec  1 2017 schubi@suse.de
- Allowing AutoYaST to add initialize add-on products provided
  by the repository in order to add DriverUpdate. (bnc#1070804)
- 4.0.19
* Thu Nov  9 2017 knut.anderssen@suse.com
- VNC does not depend on xinetd anymore. (bsc#1058820)
- 4.0.18
* Wed Nov  8 2017 igonzalezsosa@suse.com
- On single product media, select the available product during
  upgrade (bsc#1066709 and bsc#1065172).
- 4.0.17
* Fri Oct 27 2017 lslezak@suse.cz
- Do not install all available products (like SLED on SLES) during
  upgrade (bsc#1065485)
- 4.0.16
* Thu Oct 26 2017 schubi@suse.de
- Fixed spelling. (bnc#1055279, bnc#1058071)
- 4.0.15
* Tue Oct 24 2017 aschnell@suse.com
- added dependency to yast2-storage-ng (bsc#1062009)
- 4.0.14
* Thu Oct 19 2017 lslezak@suse.cz
- Use `nil` for the default "display_addon_checkbox" value
  to distinguish between the default and a changed value
  to possibly hide the "I would like to install an additional Add On
  Product" check box from the external code (FATE#323163)
- 4.0.13
* Mon Oct 16 2017 jreidinger@suse.com
- Cleaning up DefaultDesktop as its usage is now reduced even for
  SLE (bsc#1057538)
- 4.0.12
* Mon Oct 16 2017 lslezak@suse.cz
- Display a confirmation popup when no add-on is selected from
  a multi-repository medium (bsc#1062356)
- 4.0.11
* Thu Oct 12 2017 lslezak@suse.cz
- Do not abort installation when no add-on product is selected from
  a multi-repository medium (bsc#1062356)
- 4.0.10
* Thu Sep 28 2017 schubi@suse.de
- Disable vpn, ssh,... and inform the user if the needed packages
  are not available. (bnc#1055279, bnc#1058071)
- 4.0.9
* Mon Sep 25 2017 igonzalezsosa@suse.com
- Bring back support to read release notes from an URL
  on non-registered systems and as fallback mechanism
  for registered ones (related to fate#323273)
- 4.0.8
* Fri Sep 22 2017 lslezak@suse.cz
- Report error when the repository URL cannot be expanded by
  libzypp (e.g. it is invalid) (bsc#1059744)
- 4.0.7
* Mon Sep 18 2017 lslezak@suse.cz
- Display a product selection dialog when the add-on medium
  contains multiple products (fate#323886)
- 4.0.6
* Mon Sep 18 2017 igonzalezsosa@suse.com
- Add support to read release notes from an RPM in the
  repository (fate#323273)
- 4.0.5
* Mon Sep 18 2017 knut.anderssen@suse.com
- Display beta info even if the license is not present
  (bsc#1047060).
- 4.0.4
* Fri Sep 15 2017 igonzalezsosa@suse.com
- Do not show license agreement twice for multi product media
  (bsc#1058503)
- 4.0.3
* Fri Sep 15 2017 jreidinger@suse.com
- do not warn that url is already used for multi modules media
  (fate#323450)
- 4.0.2
* Thu Sep 14 2017 jreidinger@suse.com
- show product path in url for multi product media
- for multi product media add product path to repository name
  (fate#323450)
- 4.0.1
* Tue Sep 12 2017 knut.anderssen@suse.com
- Replace /info.txt by /README.BETA as beta file to be shown
  (bsc#1047060).
- 4.0.0
* Thu Sep  7 2017 knut.anderssen@suse.com
- Do not copy passwd, group and shadow from ins-sys anymore
  (bsc#1057367).
- 3.3.12
* Tue Sep  5 2017 igonzalezsosa@suse.com
- Product's detection on single product media does not require
  the 'system-installation()' tag anymore (fate#322276)
- 3.3.11
* Tue Sep  5 2017 igonzalezsosa@suse.com
- Report an error when no available base products are found
- Add support to skip validations in the product license widget
  (fate#322276)
- 3.3.10
* Thu Aug 31 2017 igonzalezsosa@suse.com
- Add widgets to show/confirm product licenses (fate#322276)
- 3.3.9
* Thu Aug 31 2017 knut.anderssen@suse.com
- Do not report an error for optional resolvable patterns
  (bsc#1054670).
- 3.3.8
* Tue Aug 22 2017 igonzalezsosa@suse.com
- Moved repositories and product related classes to this module
- Extended repositories and product related API (FATE#322276)
- Added clients and dialogs to handle products licenses using
  the new yast2-pkg-bindings API
- 3.3.7
* Tue Aug 22 2017 ancor@suse.com
- Fixed a bug introduced during the code refactoring associated to
  bsc#1047060
- 3.3.6
* Fri Aug 18 2017 snwint@suse.de
- fix typo in storage_include.rb
- 3.3.5
* Mon Aug 14 2017 ancor@suse.com
- Merged storage-ng branch (fate#318196).
- Note: all changes below with this date belong to the merge.
- 3.3.4
* Mon Aug 14 2017 ancor@suse.com
- storage-ng: adapted to the new Y2Storage::StorageManager API
* Mon Aug 14 2017 shundhammer@suse.de
- Merged master to storage-ng branch
* Mon Aug 14 2017 ancor@suse.com
- Synced storage-ng and master branches. See changes below.
* Mon Aug 14 2017 ancor@suse.com
- Synced storage-ng and master branches. See changes below.
* Mon Aug 14 2017 ancor@suse.com
- Use storage-ng during installation (to check the available space
  and whether the software proposal needs to be re-calculated).
- Removed the client wrapper_storage (obsolete with storage-ng).
* Mon Aug 14 2017 ancor@suse.com
- storage-ng: removed yast2-storage buildrequire.
- commented unit tests code relying on the old yast2-storage so
  the package can be built without it.
* Mon Aug 14 2017 jreidinger@suse.com
- prevent crash from add-on workflow (bsc#1053536)
- 3.3.3
* Thu Jul 27 2017 schubi@suse.de
- AutoYaST: Configuring EULA acceptance of add-on products has
  not worked if the add-on product is on the medium of the base
  product too. (bnc#1032523).
  Now the add-on product has to be defined in the AutoYaST
  configuration file explicit.
- 3.3.2
* Wed Jul 26 2017 jreidinger@suse.com
- drop reading "/content" file (FATE#322386)
- 3.3.1
* Thu Jul 20 2017 lslezak@suse.cz
- Less strict low memory detection, there might be some rounding
  in the hwinfo memory size detection (bsc#1045915)
- 3.3.0
* Tue Jul 11 2017 lslezak@suse.cz
- Properly handle multiple product renames (bsc#1048141)
- 3.2.24
* Fri Apr 28 2017 jreidinger@suse.com
- Escape backslashes in installation repo URL (bsc#1032506)
- 3.2.23
* Fri Apr  7 2017 lslezak@suse.cz
- Create the /etc/products.d/baseproduct symlink in inst-sys when
  it is missing to allow expanding variables in the add-on
  repositories URL (bsc#972046)
- 3.2.22
* Tue Mar 28 2017 igonzalezsosa@suse.com
- Do not crash when changing the priority of a just created
  repository (bsc#1027111)
- 3.2.21
* Mon Mar 27 2017 mvidner@suse.com
- Do not ignore solver problems after touching the partitioning
  (bsc#1029306)
- 3.2.20
* Fri Mar 24 2017 lslezak@suse.cz
- Download the addon y2update.tgz file from a package referenced
  by the "installerextension()" provides dependency (FATE#320772)
- 3.2.19
* Mon Mar 20 2017 jreidinger@suse.com
- make minimal changes when modify zypp.conf (bsc#1023204)
- 3.2.18
* Tue Mar  7 2017 schubi@suse.de
- Product selection: Do not reinstall already installed products
  or products which are already included in another product.
  Fixes SLES4SAP autoupgrade with SUSE Manager repositories.
  These repositories contain SLES_SAP and SLES product. SLES
  product will not be installed because SLES_SAP already includes
  the SLES product.
  (bnc#1014861)
- 3.2.17
* Wed Feb  8 2017 jreidinger@suse.com
- drop inst_desktop client as it is replaced by new desktop
  selection based on roles (poo#14936, bsc#1025415)
- Allow Desktop module to specify that no desktop is selected
- 3.2.16
* Mon Feb  6 2017 lslezak@suse.cz
- Do not allow changing services of type "plugin" and its
  repositories, they cannot be changed (related to bsc#1021117)
- 3.2.15
* Wed Feb  1 2017 jreidinger@suse.com
- Fix escaping spaces ( yast uses web form escaping to "+" but
  libzypp expects percentage escaping to "%%20" ) (bsc#954813)
- Fix also valid showing valid libzypp formats of iso URL like
  iso:/test?iso=test.iso&path=url%%3A%%2Finstall
- Fix editing of iso:/ without triple slash that previously caused
  lost of first element of path
- 3.2.14
* Mon Jan 30 2017 igonzalezsosa@suse.com
- Packages module is able to perform a package selection proposal
  during system upgrade (bsc#1009834)
- 3.2.13
* Tue Jan 24 2017 jsrain@suse.cz
- do not check content file on media if there is none in the
  ramdisk (fate#322276)
* Thu Jan 19 2017 igonzalezsosa@suse.com
- Use information provided by libzypp to evaluate product
  renames (FATE#321751)
- 3.2.12
* Wed Dec 21 2016 schubi@suse.de
- Adjust /etc/zypp/zypp.conf in the installed system when
  software/minimalistic_libzypp_config is enabled in the control
  file (FATE#321764)
- 3.2.11
* Thu Dec  1 2016 lslezak@suse.cz
- Mark the selected default patterns as optional so the user can
  change them without blocking the installation later (fixes
  openQA tests) (related to bsc#885496)
- 3.2.10
* Fri Nov 25 2016 jreidinger@suse.com
- Revert the last change, as it is more tricky to get the correct
  behavior. For more details see the discussion in (bsc#966466).
- 3.2.9
* Thu Nov 24 2016 jreidinger@suse.com
- Always show summary mode when clicking on details in software
  proposal (bsc#966466)
- 3.2.8
* Tue Nov 15 2016 jreidinger@suse.com
- Use a non-blocking error in the installation proposal for not
  enough space issue during upgrade instead of just warning as it
  can be easier to overlook by an user
  (bsc#1003682)
- 3.2.7
* Mon Nov 14 2016 lslezak@suse.cz
- Software proposal: display an error when a package or a pattern
  required by YaST has been deselected by user, implement a generic
  solution for bsc#885496
- 3.2.6
* Mon Oct 24 2016 schubi@suse.de
- Faking /etc/mtab on target system for post RPM installation
  actions which depend on it, e.g. checking if there is a /home
  directory. (bnc#995299)
- 3.2.5
* Mon Oct 17 2016 lslezak@suse.cz
- Update the priority for the loaded packages when starting the
  repository manager from the package manager (bsc#498266)
- 3.2.4
* Fri Oct 14 2016 jreidinger@suse.com
- allow SLES for SAP upgrade from 11 to 12 as it is renamed
  (bsc#1004665)
- 3.2.3
* Mon Oct 10 2016 lslezak@suse.cz
- Do not ask for a CD when the add-on check box is unchecked
  (bsc#955186)
- 3.2.2
* Thu Oct  6 2016 lslezak@suse.cz
- Disable autorefresh for newly added local repositories ("cd",
  "dvd", "dir", "hd" (including USB flash), "iso" and "file" URL
  protocols) (bsc#948982)
- 3.2.1
* Wed Oct  5 2016 jreidinger@suse.com
- remove workaround that creates fake mtab to prevent collision
  with real one (bsc#1002978)
- 3.2.0
* Mon Oct  3 2016 jreidinger@suse.com
- prevent double URL encoding for ISO (bsc#954813)
- 3.1.118
* Wed Aug 31 2016 igonzalezsosa@suse.com
- Fix URLs handling when retrying to load an add-on from a CD/DVD
  through the add_on_products.xml (related to bsc#991935).
- 3.1.117
* Tue Aug 23 2016 jreidinger@suse.com
- Always enable "Next" button in license confirmation dialog,
  because even if not accepted, popup is shown to user
  (bnc#993530).
- Use the same popup when license not confirmed for base product in
  the license confirmation dialog (bnc#993530).
- 3.1.116
* Thu Aug 18 2016 schubi@suse.de
- Do not raise an exception if no license is available (no licence
  dir at all) to accept (bnc#994309).
- 3.1.115
* Tue Aug 16 2016 lslezak@suse.cz
- Remove the icon from the add-on selection popup (bsc#875201)
- 3.1.114
* Tue Aug 16 2016 locilka@suse.com
- Added lazy loading of licenses into AcceptanceNeeded in case of
  base product in the initial installation to fix a problem when
  explicit acceptance of the product license was always required
  (bnc#993285)
- 3.1.113
* Mon Aug 15 2016 schubi@suse.de
- Fixed parameter error while logging errors. It belongs to
  bnc#991935.
- 3.1.112
* Thu Aug 11 2016 igonzalezsosa@suse.com
- Fix automatic add-on handling when using CD/DVD medias as source
  (bsc#991935)
- 3.1.111
* Wed Aug 10 2016 kanderssen@suse.com
- List addons below base product in Software proposal during
  installation. (bsc#992304)
- 3.1.110
* Thu Jul 28 2016 jreidinger@suse.com
- allow KDE to use packager for opening rpms (boo#954143)
  thanks to  Marcelo Junior for patch
- 3.1.109
* Tue Jul 19 2016 cwh@suse.com
- Fix layout of Add-On screen (bsc#951720)
- 3.1.108
* Wed Jul  6 2016 igonzalezsosa@suse.com
- Fix remaining estimation during installation (bsc#982138)
- 3.1.107
* Wed Jul  6 2016 igonzalezsosa@suse.com
- Fix remaining packages count during installation (bsc#987791 and
  bsc#987604)
- 3.1.106
* Tue Jun 28 2016 jreidinger@suse.com
- optimize slide show size computing to improve installation
  performance (bnc#986649)
- 3.1.105
* Mon Jun 20 2016 lslezak@suse.cz
- Restored back the InstURL#GetDevicesOption method which was
  accidentaly removed in the previous update (bsc#985593)
- 3.1.104
* Wed Jun 15 2016 igonzalezsosa@suse.com
- Allow installation via HTTPS using a self-signed certificate
  when "ssl_certs=0" boot option is used (bsc#982727)
- Drop "is_network" method from InstURL module
- 3.1.103
* Thu Jun  2 2016 igonzalezsosa@suse.com
- Drop yast2-packager-devel-doc (fate#320356)
- 3.1.102
* Thu May 19 2016 jsrain@suse.cz
- fixed parsing of patterns in content file (bsc#980718)
- 3.1.101
* Thu May 12 2016 lslezak@suse.cz
- Select the new default product patterns also when adding an
  add-on from media in installed system (FATE#320199)
- 3.1.100
* Wed May 11 2016 schubi@suse.de
- Showing location of installed licenses.
  (fate#219341)
- 3.1.99
* Tue May 10 2016 igonzalezsosa@suse.com
- Local repositories are disabled at the end of the installation
  if there is an online replacement available (FATE#320494)
- 3.1.98
* Fri Apr 22 2016 lslezak@suse.cz
- Move the default pattern selection to a different place to not
  conflict with the pattern selection in the system upgrade mode
  (FATE#320199)
- 3.1.97
* Fri Apr 22 2016 knut.anderssen@suse.com
- Added public methods to modify and know info about files read,
  in this case to avoid display the welcome dialog again after
  restart yast (bsc#974409)
- 3.1.96
* Mon Apr 11 2016 lslezak@suse.cz
- Select the default product patterns defined by the
  'defaultpattern()' provides in the initial installation
  (FATE#320199)
- 3.1.95
* Wed Apr  6 2016 knut.anderssen@suse.com
- Explicitly resolve shortcut conflicts proposing 'alt-w' for
  [Network Configuration]. (bsc#974216)
- 3.1.94
* Mon Apr  4 2016 schubi@suse.de
- Using "uptime" from package yast2 instead of Builtins.time.
  Cleanup for bnc#956730.
- 3.1.93
* Fri Apr  1 2016 knut.anderssen@suse.com
- Added [Network Configuration] button to Source Dialog for
  installation or upgrade modes. (fate#319716)
- 3.1.92
* Fri Mar 18 2016 lslezak@suse.cz
- Fixed list of skipped packages in the installation summary
  dialog (boo#971759)
- 3.1.91
* Mon Feb 22 2016 igonzalezsosa@suse.com
- Show messages coming from libzypp except during installation
  (bsc#943805)
- 3.1.90
* Thu Feb 11 2016 schubi@suse.de
- Allowing AutoYaST to confirm licenses.
  (Fate#318945)
- 3.1.89
* Wed Jan 27 2016 lslezak@suse.cz
- Fixed selecting additional products during system installation
  (do not select previously unselected products after adding
  repositories from the registration server) (bsc#963036)
- 3.1.88
* Mon Jan  4 2016 jreidinger@suse.com
- do not crash if adding unknown repo type (bnc#960460)
- 3.1.87
* Tue Dec 22 2015 jsrain@suse.cz
- read release notes from media of manually added extension
  (bsc#957241)
- 3.1.86
* Mon Dec 21 2015 lslezak@suse.cz
- Removed leftover closing rich text tag (bsc#950866)
- 3.1.85
* Wed Dec 16 2015 lslezak@suse.cz
- Do not remove the system repository when adding an addon fails,
  better handle errors (bsc#956597)
- 3.1.84
* Wed Nov 11 2015 lslezak@suse.cz
- Do not check the free space on a CD/DVD mounted medium during
  online migration (the mount point has been changed from /media to
  /run/media) (bsc#952112)
* Wed Oct 21 2015 lslezak@suse.cz
- fixed crash (missing nil check) at ProductLicense.rb when
  displaying EULA in the firstboot workflow in a Studio image
  (bsc#951210)
- 3.1.83
* Fri Oct 16 2015 lslezak@suse.cz
- repository manager - properly close the main window when aborting
  after failed initialization to avoid a segfault (bsc#950525)
- 3.1.82
* Thu Oct  8 2015 lslezak@suse.cz
- repository manager - fixed switch between dvd:// and cd:// URL
  scheme (bsc#947595)
- 3.1.81
* Tue Oct  6 2015 ancor@suse.com
- Repository editor can now manage urls with repo variables like
  $arch, $releasever, etc. (bsc#944505)
- 3.1.80
* Tue Oct  6 2015 jreidinger@suse.com
- Added a filter showing only those repositories not belonging to
  any service. (bnc#944504)
- 3.1.79
* Tue Sep 29 2015 lslezak@suse.cz
- handle properly the SLES11 SMT upgrade to SLES12 (evaluate all
  removed products when checking product upgrades) (bsc#946717)
- 3.1.78
* Fri Aug 28 2015 lslezak@suse.cz
- Do not show a warning for the removed SMT product when upgrading
  from SLES11 + SMT (the SMT functionality has been integrated into
  SLES12) (bsc#942639)
- 3.1.77
* Tue Jul 21 2015 jreidinger@suse.com
- fix crash when adding addon on DVD (bnc#938786)
- 3.1.76
* Tue Jul 14 2015 lslezak@suse.cz
- fixed crash when editing the default URL of a new addon
  (bsc#937948)
- 3.1.75
* Tue Jun 30 2015 mvidner@suse.com
- Do not offer to install recommended packages for already
  installed ones on the first run (boo#902394).
- 3.1.74
* Tue Jun 30 2015 schubi@suse.de
- Checking nil result after reading /proc/cmdline (bnc#934229).
- 3.1.73
* Wed Jun 24 2015 jreidinger@suse.com
- do not crash if user want to add add-on via url (bnc#934216)
- 3.1.72
* Thu Jun 11 2015 lslezak@suse.cz
- proper fix for a float remaining time (bnc#882240)
- 3.1.71
* Thu Jun  4 2015 lslezak@suse.cz
- use the full URL (incl. the password) when editing a repository
  URL (bnc#826075)
- 3.1.70
* Tue Jun  2 2015 lslezak@suse.cz
- fixed building a local ISO URL (bnc#919138)
- 3.1.69
* Thu May  7 2015 igonzalezsosa@suse.com
- Packages module uses tags instead of package names (bnc#923901)
- 3.1.68
* Thu Apr 23 2015 ancor@suse.com
- Ensure libyui-qt is installed when using autoyast in graphical
  mode (bnc#923901)
* Fri Apr 10 2015 lslezak@suse.cz
- register addons from media (FATE#318505)
- 3.1.67
* Mon Mar 16 2015 cwh@suse.com
- Added reponame to license's title (bnc#899892)
- Display correct license URL for add-on repositories (bnc#899891)
- 3.1.66
* Fri Mar 13 2015 lslezak@suse.cz
- skip EULA also in the autoupgrade mode, not only in the autoinst
  mode (bnc#922232)
- 3.1.65
* Fri Mar 13 2015 lslezak@suse.cz
- "iproute2" package is needed for SSH installation (bnc#920175)
- 3.1.64
* Wed Mar  4 2015 lslezak@suse.cz
- removed obsolete patch download callbacks
- 3.1.63
* Wed Feb 11 2015 lslezak@suse.cz
- process "workgroup" parameter in URL properly (bnc#784978)
- 3.1.62
* Mon Feb  9 2015 ancor@suse.com
- Fixed the network configuration during upgrade (bnc#911132)
- 3.1.61
* Fri Feb  6 2015 ancor@suse.com
- The unit tests are now compatible with RSpec 3 (bnc#916364)
- 3.1.60
* Thu Feb  5 2015 jsrain@suse.cz
- initialize bootloader during update if proposed from scratch
  (bnc#899743)
- 3.1.59
* Tue Feb  3 2015 lslezak@suse.cz
- fixed file:// URL handling (same as dir://) (boo#869399)
- validate entered URL schema
- 3.1.58
* Thu Jan 29 2015 jreidinger@suse.com
- remove obsolete legacy patch callbacks
- 3.1.57
* Mon Jan 26 2015 jreidinger@suse.com
- fixed \r and \b  characters lost during conversion to Ruby
* Thu Jan 22 2015 lslezak@suse.cz
- explicitly resolve shortcut conflict in repository type dialog
  to avoid different auto correction in Qt and ncurses UI
  (bnc#913099)
- 3.1.56
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Tue Nov 18 2014 jreidinger@suse.com
- avoid warning about constant redefinition (bnc#905508)
- 3.1.54
* Thu Oct 30 2014 gber@opensuse.org
- add desktop file for yast2-packager (bnc#892936)
  - add build dependency on yast2_theme for the icon
- 3.1.53
* Thu Oct 16 2014 lslezak@suse.cz
- fixed crash when using custom license in firstboot workflow
  (affects SUSE Studio) (bnc#899482)
- 3.1.52
* Mon Sep 29 2014 lslezak@suse.cz
- display full URL to the currently displayed EULA (directory
  listing has been disabled after moving registration licenses
  from nu.novell.com to updates.suse.com) (bnc#898647)
- 3.1.51
* Wed Sep 24 2014 lslezak@suse.cz
- fixed failure when checking available free space at installation
  (by Thomas Renninger, thanks!) (bnc#898229)
- 3.1.50
* Tue Sep 23 2014 lslezak@suse.cz
- fixed installation crash when a non-btrfs file system is used
  (bnc#897909)
- 3.1.49
* Fri Sep 19 2014 lslezak@suse.cz
- handle Btrfs specifically in disk usage counting (bnc#896176)
  - use "btrfs filesystem df" instead of "df" (more accurate)
  - pass "growonly" flag to libzypp when any snapshot is found
- 3.1.48
* Thu Sep 11 2014 ancor@suse.com
- Improved automatic selection of packages for remote
  administration (VNC) and for installation with remote X11.
  Fixes bnc#896185 and bnc#895070.
- Enabled access to those selections from other yast modules.
  First step to fix bnc#896178.
- 3.1.47
* Fri Sep  5 2014 lslezak@suse.cz
- /etc/sysconfig/kernel:INITRD_MODULES has been dropped, do not
  write Xen modules there (bnc#895084)
- 3.1.46
* Thu Sep  4 2014 jreidinger@suse.com
- use new rubygem dependency syntax (bnc#895069)
- 3.1.45
* Tue Sep  2 2014 ancor@suse.com
- Use DM device for encrypted partitions during test mount
  (bnc#889334)
- 3.1.44
* Mon Sep  1 2014 ancor@suse.com
- Use options from partitioner during test mount (bnc#873180)
- 3.1.43
* Mon Aug 18 2014 lslezak@suse.cz
- fixed adding of new SLP and CD/DVD repositories
- added "Repositories from Registration Server" option to URL
  selection dialog (displyed when adding a new repository)
  (bnc#888566)
- 3.1.42
* Fri Aug 15 2014 lslezak@suse.cz
- better help text: user can confirm product removal and continue
  with the product upgrade (bnc#889749)
- 3.1.41
* Wed Aug 13 2014 locilka@suse.com
- Removed caching of already accepted licenses: if there is
  a license that needs to be accepted, user has to accept it
  (bnc#890968)
- 3.1.40
* Wed Aug  6 2014 locilka@suse.com
- Cleanup in license dialog handling, especially in handling while
  aborting the installation (bnc#886662)
- 3.1.39
* Thu Jul 31 2014 locilka@suse.com
- Added user confirmation for aborting the repositories dialogs
  (bnc#886662)
- 3.1.38
* Thu Jul 31 2014 jsrain@suse.cz
- added product rename sle-hae -> sle-ha to the list (bnc#889745)
- 3.1.37
* Wed Jul 30 2014 ancor@suse.com
- Refactored kernelCmdLinePackages to rely on .proc.cmdline agent
  (bnc#889365)
- Added dependency on yast2 >= 3.1.89 (fixed agent)
- 3.1.36
* Tue Jul 29 2014 lslezak@suse.cz
- ag_zypp_repos - do not try parsing directory entries in
  /etc/zypp/repos.d/, that leads to invalid values (bnc#867911)
- 3.1.35
* Tue Jul 29 2014 jreidinger@suse.com
- remove slide show display time recalculation to improve slide
  show user experience (bnc#885973)
- 3.1.34
* Mon Jul 28 2014 ancor@suse.com
- fixed reading of /proc/cmdline containing newline (bnc#887844)
- 3.1.33
* Fri Jul 25 2014 ancor@suse.com
- adjust width of drive selection dialog (bnc#882657)
- 3.1.32
* Fri Jul 25 2014 schubi@suse.de
- Do not overwrite the autoyast pattern selection by
  the default desktop pattern selection (bnc#888981)
- 3.1.31
* Fri Jul 25 2014 cwh@suse.com
- Made SLP browser filter case-insensitive (bnc#869653)
* Fri Jul 11 2014 lslezak@suse.cz
- fixed finding product upgrades (bnc#886621)
- 3.1.30
* Thu Jul 10 2014 lslezak@suse.cz
- select "fips" pattern if installation is booted with "fips=1"
  parameter (bnc#886582)
- 3.1.29
* Wed Jul  9 2014 schubi@suse.de
- Setting default desktop in autoyast too. (bnc#886367)
- 3.1.28
* Fri Jul  4 2014 lslezak@suse.cz
- make product renames updatable from SCC (related to bnc#883206)
- 3.1.27
* Fri Jun 27 2014 lslezak@suse.cz
- updated known product renames (bnc#883047)
- 3.1.26
* Wed Jun 25 2014 lslezak@suse.cz
- colorize the product removal warning using HTML.Colorize method
  to render the same color
- 3.1.25
* Wed Jun 25 2014 lslezak@suse.cz
- Packages.rb - added methods for checking product removal at
  update (bnc#883047)
- 3.1.24
* Thu Jun 12 2014 lslezak@suse.cz
- make sure float time is not reported (bnc#882240)
- fix total time to be exactly the sum of per media times when
  a minimum time is used
- 3.1.23
* Mon Jun  9 2014 lslezak@suse.cz
- ProductLicense.rb:
  - display URL where to download the license (bnc#880685)
  - display a checkbox instead radio buttons (bnc#878976)
- 3.1.22
* Fri May 30 2014 lslezak@suse.cz
- allow adding a title to license dialog (needed for on-line
  extensions)
- 3.1.21
* Wed May 28 2014 jsrain@suse.cz
- text improvements for adding media-based add-on product during
  installation (bnc#878534)
- 3.1.20
* Fri May 23 2014 locilka@suse.com
- SlideShow refactoring: constantized, removed unused methods,
  Rubyized (all for bnc#865037)
- 3.1.19
* Fri May 16 2014 locilka@suse.com
- Added support for software->optional_default_patterns to handle
  selecting optional patterns without reporting if they are missing
  (bnc#876760)
- 3.1.18
* Fri May 16 2014 jreidinger@suse.com
- Fix preferring DVD during installation (bnc#865819,bnc#780617)
- 3.1.17
* Thu May 15 2014 lslezak@suse.cz
- ProductLicense - allow setting the dialog title and display an
  optional heading (needed for displaying the EULA for addons from
  registration server)
- 3.1.16
* Thu May 15 2014 lslezak@suse.cz
- fixed wrong constant name resulting in a crash during
  installation
- 3.1.15
* Tue May 13 2014 lslezak@suse.cz
- add-on protocol dialog: display a global checkbox when selecting
  an add-on during registration (bnc#870625)
- 3.1.14
* Tue May 13 2014 locilka@suse.com
- Selecting missing default patterns now reports an error instead
  of raising an exception (bnc#875799)
- 3.1.13
* Mon Apr 28 2014 locilka@suse.com
- Logging status of all changed resolvables to be able to debug
  and reproduce reported issues better (bnc#875350)
- 3.1.12
* Wed Apr 23 2014 locilka@suse.com
- Fixed function call that identified ComputeSystemPatternList
  function as a constant (bnc#874725)
- 3.1.11
* Fri Apr 18 2014 locilka@suse.com
- Removed obsolete Product.patterns functionality and replaced
  by new definition in control file software->default_patterns;
  with little refactoring (bnc#873923)
- 3.1.10
* Fri Apr 11 2014 locilka@suse.cz
- Test for Packages rewritten in RSpec to fix the build
- 3.1.9
* Wed Mar 19 2014 lslezak@suse.cz
- copy libzypp credentials to the target system before starting
  package installation (bnc#869089)
- 3.1.8
* Thu Mar  6 2014 locilka@suse.com
- Changed DefaultDesktop not to select any required packages
  anymore. They have changed to packages to identify selected
  desktop only (bnc#866724).
- 3.1.7
* Fri Feb 28 2014 jreidinger@suse.com
- Fix iso detection for DVD capable UEFI boot(BNC#852436)
- 3.1.6
* Wed Feb 26 2014 lslezak@suse.cz
- Always prefer DVD medium to download (not only during update)
  (bnc#865819)
- 3.1.5
* Mon Feb 17 2014 locilka@suse.com
- Package tightvnc is no more required while installing over VNC
  (bnc#859903)
- 3.1.4
* Mon Feb 10 2014 lslezak@suse.cz
- display a warning when using online repositories with less than
  1GiB RAM (the installer may crash or freeze) (bnc#854755)
- 3.1.3
* Fri Feb  7 2014 jsrain@suse.cz
- use text version of release notes for NCurses (bnc#862578)
- 3.1.2
* Tue Jan  7 2014 locilka@suse.com
- Removed unneeded client inst_media (bnc#857681)
- 3.1.1
* Wed Nov  6 2013 lslezak@suse.cz
- reinitialize the target to sync the libzypp repomanager
  so the online repositories are correctly written during update
  (bnc#847659)
* Mon Nov  4 2013 lslezak@suse.cz
- fixed vendor detection, check the output directly in shell
  to avoid reading binary (non-UTF8) text (bnc#847153)
- removed non-working *-webpin subpackage (the external service for
  package search does not work, without that service it is useless)
  (bnc#845622)
* Tue Oct 15 2013 lslezak@suse.cz
- updated help text in "Adding a GPG Public Key" dialog
  (bnc#830853)
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Tue Sep  3 2013 lslezak@suse.cz
- don't reset package selection in the installation proposal when
  partitioning is changed (bnc#831875, port from SLE11 bnc#450786,
  bnc#371875) (see commit d1cce0e5a5)
- fixed slideshow initialization - in add-on workflow the
  initialization was called too late resulting in still 0%% total
  progress during whole installation (bnc#831875, port from SLE11
  bnc#663301) (see commit a1772b138d)
- do not skip package proposal when the partitioner has changed
  proposed packages - i.e. add snapper packages after switching to
  btrfs (bnc#831875, port from SLE11 bnc#704127) (see commit
  6c48fd7761)
- improve the progress bar during package installation slideshow
  (bnc#831875, port from SLE11 bnc#724486) (see commit 2be99dd9ff)
- REGISTERPRODUCT from content file moved to control file to
  globals->require_registration (bnc#831875, port from SLE11
  FATE #305578) (see commit 7d9a51bb4a)
- improved addon file handling (bnc#831875, port from SLE11
  bnc#815899) (see commit 3490193186)
- 3.0.5
* Tue Sep  3 2013 jsuchome@suse.cz
- do not install xorg-x11 package (bnc#837450)
- 3.0.4
* Thu Aug 29 2013 lslezak@suse.cz
- sw_single - disable "ignore recommended packages for already
  installed packages" at the first run (then use the stored
  setting) (bnc#835968)
- 3.0.3
* Thu Aug 22 2013 jsuchome@suse.cz
- use OSRelease instead of obsolete SuSERelease (bnc#833955)
- 3.0.2
* Thu Aug  1 2013 lslezak@suse.cz
- removed obsolete BuildRequires: gcc-c++ perl-XML-Writer
  yast2-slp yast2-transfer
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Mon Jul 29 2013 lslezak@suse.cz
- put the README and COPYING files to the main package instead of
  the devel-doc subpackage
- 2.24.3
* Wed Jul 24 2013 lslezak@suse.cz
- split the generated documentation to devel-doc subpackge (to save
  some space in installed system, needed only for developers)
- 2.24.2
* Mon Jul 15 2013 lslezak@suse.cz
- enable back kernel module autoloading (bnc#829265)
- 2.24.1
* Thu Jul 11 2013 gs@suse.de
- Fixed call of Online Update Configuration (don't finish sources
  if called from Package Selector, bnc #828132)
* Mon Jun  3 2013 lslezak@suse.cz
- PackageSlideShow.ycp - avoid possible division by zero
* Fri May 31 2013 lslezak@suse.cz
- removed writing a debug file (bnc#822615)
* Wed Apr 17 2013 lslezak@suse.cz
- fixed check for disabled SSL verification (bnc#807799)
* Tue Apr 16 2013 lslezak@suse.cz
- sw_single.ycp removed function nesting, updated manual-tests,
  removed old-tests (for YCP -> Ruby conversion)
* Fri Mar 15 2013 lslezak@suse.cz
- disable certificate check for HTTPS installation repository
  when sslcerts=0 boot option is used (bnc#807799)
- 2.24.0
* Wed Jan 30 2013 jsuchome@suse.cz
- added API for Storage::GetWinPrimPartitions (bnc#797665)
- 2.23.3
* Tue Jan 29 2013 lslezak@suse.cz
- ignore *-migration products in the initial product selection
  (can be present in *-Update channels) (bnc#764838)
- 2.23.2
* Mon Jan 21 2013 lslezak@suse.cz
- added support for specifying add-on repo alias name (fate#313144)
- 2.23.1
* Mon Jan 21 2013 lslezak@suse.cz
- added support to optionally set the mount options for NFS
  repositories (fate#313208)
* Fri Oct 26 2012 jsuchome@suse.cz
- remove calls to obsolete inst_suseconfig
- 2.23.0
* Tue Sep  4 2012 tgoettlicher@suse.de
- fixed dependencies for libyui
* Mon Aug  6 2012 lslezak@suse.cz
- fixed ISO image detection (space in file name or path), fixed
  shell injection vulnerability (bnc#770157)
* Mon May 21 2012 lslezak@suse.cz
- fixed RPM build (the removed files were left in *.spec)
- 2.22.6
* Wed May 16 2012 lslezak@suse.cz
- removed webpin.desktop - webpin currently does not work so the
  yast module should not be displayed in the control center
  (bnc#761075)
- 2.22.5
* Tue May 15 2012 lslezak@suse.cz
- repositories - reverted the previous patch, numerical sorting
  has been fixed at the UI level (bnc#752768)
- 2.22.4
* Thu May  3 2012 lslezak@suse.cz
- pad repository priority with "0" so table sorting works correctly
  also in non-POSIX locale (bnc#752768)
- 2.22.3
* Tue Apr  3 2012 aschnell@suse.de
- adapted to move of testX (see bnc#749184)
- 2.22.2
* Tue Mar 27 2012 lslezak@suse.cz
- removed libxcrypt-devel from buildrequires
- 2.22.1
* Wed Nov 16 2011 jsuchome@suse.cz
- merged texts from proofreading
- 2.22.0
* Tue Nov  1 2011 lslezak@suse.cz
- fixed free space check for very small partitions (~15MB), do not
  report insufficient disk space when there is actually nothing
  to install on it (bnc#724894)
- 2.21.22
* Mon Oct 31 2011 lslezak@suse.cz
- copy the metadata cache after saving repository setup to not
  confuse the package manager (avoid matadata cleanup) (bnc#700881)
- 2.21.21
* Mon Oct 17 2011 locilka@suse.cz
- Readding missing feature supported in control file: Packages
  required by a selected desktop in DefaultDesktop (bnc#724491).
- 2.21.20
* Wed Oct 12 2011 jsuchome@suse.cz
- do not add initrd modules when mkintrd itself can add them
  (bnc#716785)
- 2.21.19
* Thu Oct  6 2011 lslezak@suse.cz
- skip product selection in the second stage (do not reinstall
  the product package during autoinstallation) (bnc#721166)
- 2.21.18
* Fri Sep 23 2011 lslezak@suse.cz
- code cleanup: dropped support for selections (replaced by
  patterns long time ago)
- 2.21.17
* Fri Sep 23 2011 visnov@suse.cz
- added dialog titles
- 2.21.16
* Wed Sep 14 2011 lslezak@suse.cz
- fixed UI syntax error caused by wrong boolean expression
  (bnc#711393)
- 2.21.15
* Wed Sep 14 2011 lslezak@suse.cz
- set ignoreAlradyRecommended solver flag to false in fresh
  installation/upgrade to include file system tools
  (like btrfsprogs) (bnc#668588)
- 2.21.14
* Thu Sep  8 2011 lslezak@suse.cz
- read biosdevname option directly from /proc/cmdline (bnc#712049)
* Fri Sep  2 2011 lslezak@suse.cz
- intialize the target in the second stage to read the GPG keys,
  do not ask for importing known GPG keys again (bnc#707207)
- 2.21.13
* Wed Aug 31 2011 lslezak@suse.cz
- SpaceCalculation - improved target installation size estimation,
  consider also filesystem properties (journal size, reserved space)
  add some (static) non-package files to disk usage, increased
  some spare size constants (bnc#263275)
- 2.21.12
* Wed Aug 31 2011 locilka@suse.cz
- Cleaner solution for adjusting repository priority and fixing
  that now it also works in installation (bnc#714027)
* Tue Aug 30 2011 lslezak@suse.cz
- webpin_package_search - display popup and print error message
  when HTTP response code is not 200, don't silently ignore errors
  (bnc#714546)
* Mon Aug 29 2011 locilka@suse.cz
- Implemented possibility to set repository priority while adding
  by add_on_products.xml (bnc#714027).
- 2.21.11
* Mon Aug 15 2011 mvidner@suse.cz
- biosdevname: check just the vendor, don't compare interface names (bnc#712043).
- 2.21.10
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Fri Aug  5 2011 lslezak@suse.cz
- package installation: prefer CD/DVD media to download during
  installation/update (bnc#693230)
- 2.21.9
* Wed Aug  3 2011 lslezak@suse.cz
- cleanup: removed obsoleted SourceManager::SyncAddedAndDeleted()
  function (zmd sync code has been removed)
* Wed Aug  3 2011 lslezak@suse.cz
- use term "Software manager" instead of "Package manager"
  (bnc#585679)
- 2.21.8
* Tue Aug  2 2011 lslezak@suse.cz
- fixed biosdevname package installation (bnc#709797)
* Tue Jul 26 2011 lslezak@suse.cz
- fixed installation of src.rpm packages from command line
  (bnc#676505)
- 2.21.7
* Mon Jul 25 2011 lslezak@suse.cz
- removed trailing white space in webpin.desktop file (bnc#707984)
- 2.21.6
* Fri Jul 22 2011 locilka@suse.cz
- Removed obsoleted X-KDE-SubstituteUID from desktop file
  (bnc#540627)
* Fri Jul  1 2011 lslezak@suse.cz
- fixed a typo in help text (bnc#703199)
- 2.21.5
* Mon Jun 27 2011 lslezak@suse.cz
- remove the addon repository after aborting license confirmation
  or canceling the package manager (bnc#701497, bnc#424655)
- 2.21.4
* Fri Jun 24 2011 lslezak@suse.cz
- abort confirmation in license agreement - use Yes/No instead
  of confusing Continue/Cancel
* Thu Jun 23 2011 lslezak@suse.cz
- display installation summary when installation is aborted by user
  (part of bnc#673629)
- 2.21.3
* Tue Jun 14 2011 lslezak@suse.cz
- support for download in advance mode in yast2-wagon (fate#308951)
- 2.21.2
* Mon Jun 13 2011 lslezak@suse.cz
- properly count to be downloaded packages (bnc#683977)
- update download progress also for delta rpm files
- 2.21.1
* Fri Jun 10 2011 locilka@suse.cz
- Added support for add_on_products[.xml] also in inst-sys
  (FATE #312263). File need to be in the root of inst-sys.
* Fri Jun  3 2011 locilka@suse.cz
- Enhanced AddOnProduct Import functionality (FATE #311374)
* Wed Apr 20 2011 lslezak@suse.cz
- fixed "repositories" tab completion in shell (bnc#687997)
- removed obsoleted inst_source.ycp wrapper
- 2.21.0
* Fri Apr  8 2011 lslezak@suse.cz
- install biosdevname.rpm if biosdevname=1 kernel option is present
  (fate#311332)
* Thu Feb  3 2011 jsrain@suse.cz
- more friendly message when license on live CD is missing
- 2.20.15
* Thu Jan 20 2011 mvidner@suse.cz
- Edit complete URL by default (by Michal Marek)
* Mon Jan  3 2011 lslezak@suse.cz
- fixed partition evaluation (when thare are more than 10
  partitions) (bnc#660943)
- 2.20.14
* Tue Nov 30 2010 lslezak@suse.cz
- fixed DownloadInAdvance mode check - it's the default now
  (bnc#653497)
- 2.20.13
* Fri Nov 12 2010 lslezak@suse.cz
- display more details when adding a community repository fails
  (bnc#440332)
- 2.20.12
* Thu Nov 11 2010 lslezak@suse.cz
- fixed error handling for failed mounts, do not display negative
  disk space, allow installation in some cases (bnc#627969)
- 2.20.11
* Wed Nov 10 2010 lslezak@suse.cz
- update the number of the remaining packages when package
  installation is finished, display it at the beginning
  (bnc#473822)
- reset the list of packages so the next run displays correct
  values (used when PKGMGR_ACTION_AT_EXIT == "summary")
- 2.20.10
* Wed Nov  3 2010 lslezak@suse.cz
- don't reset package selection in dirinstall mode when target
  directory is changed (bnc#568511, bnc#568512)
- 2.20.9
* Tue Nov  2 2010 lslezak@suse.cz
- correctly display download progress in DownloadInAdvance
  libzypp mode (bnc#616708)
- 2.20.8
* Mon Nov  1 2010 lslezak@suse.cz
- sw_single: clear the startup progress dialog so it's not
  displayed in slow systems at the end (bnc#637201)
* Wed Oct 27 2010 mzugec@suse.cz
- improved UI layout (bnc#619653)
- 2.20.7
* Mon Oct 25 2010 lslezak@suse.cz
- slideshow media change callback - check whether the slideshow
  dialog is displayed, don't initialize slideshow when there is
  a popup displayed - prevent from a UI syntax error (bnc#622286)
- 2.20.6
* Fri Oct 15 2010 lslezak@suse.cz
- don't change repository alias (ABC -> ABC_1) when changing
  repository URL, keep the original alias (bnc#557556)
- 2.20.5
* Thu Oct 14 2010 lslezak@suse.cz
- offer also Ignore/Retry when a patch script fails during system
  installation (do not abort leaving inconsistent system)
  (bnc#633447)
- 2.20.4
* Tue Oct 12 2010 lslezak@suse.cz
- don't use obsoleted inst_packages.ycp client, use PackagesUI.ycp
  module instead (bnc#471490)
- 2.20.3
* Tue Oct 12 2010 lslezak@suse.cz
- repo mgr: don't change URL when nothing has changed in the URL
  dialog (bnc#529944)
- 2.20.2
* Tue Oct  5 2010 lslezak@suse.cz
- install yast2-online-update-configuration package if needed
  (bnc#609778)
- 2.20.1
* Fri Sep 10 2010 lslezak@suse.cz
- make "Medium #" more translation friendly (bnc#612977),
  PackageSlideShow::SetMediaType() function marked as obsoled
  (not used anyway)
- clear the installation log for the next run, save some memory
  (bnc#576511)
- 2.20.0
* Mon May 31 2010 lslezak@suse.cz
- repositories - refresh also enabled repositories and the end
  when "refresh-enabled" command line option is used (bnc#608562)
- 2.19.7
* Thu May  6 2010 jsrain@suse.cz
- add hv_netvsc to MODULES_LOADED_ON_BOOT on HyperV (bnc#600792)
* Fri Apr 30 2010 jsrain@suse.cz
- add hv_storvsc to MODULES_LOADED_ON_BOOT on HyperV (bnc#600792)
* Wed Apr 28 2010 jsrain@suse.cz
- add HyperV drivers to initrd if KMP is selected (bnc#600212)
* Thu Apr 22 2010 lslezak@suse.cz
- properly format installation URL when installing from ISO
  located at a SMB share (bnc#571648)
- 2.19.6
* Mon Apr 19 2010 lslezak@suse.cz
- switch pkg manager to summary mode after resolving pkg conflicts
  (kmachalkova@novell.com)(bnc#596519)
- 2.19.5
* Mon Apr 12 2010 lslezak@suse.cz
- added a nil check in InstURL.ycp so the testsuite passes
  during build
- 2.19.4
* Tue Apr  6 2010 locilka@suse.cz
- Searching for LiveCD license in /usr/share/doc/licenses and /
  directories (BNC #594042).
* Wed Mar 31 2010 lslezak@suse.cz
- put the Linuxrc CD/DVD device to the beginning of the CD/DVD
  device list - prefer the Linuxrc medium (bnc#588810)
* Tue Mar  2 2010 ug@suse.de
- fixed AutoYaST post-patterns
* Fri Feb 26 2010 locilka@suse.cz
- Calling ProductLicense cleanup before leaving the license dialog
  (BNC #581933).
* Thu Jan 14 2010 lslezak@suse.cz
- install also xorg-x11-fonts package when remote X or VNC
  installation is used (bnc#570363)
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Mon Jan 11 2010 lslezak@suse.cz
- sw_single.ycp: solve dependencies when installing a package
  from command line (via yast2 -i) - use a temporary local
  repository (bnc#459268)
- sw_single.ycp: display installation progress and show the summary
  dialog after installation when installing a package from command
  line (bnc#455768)
- sw_single.ycp: check target initialization result, abort on error
  (bnc#556477)
- 2.19.3
* Mon Jan 11 2010 locilka@suse.cz
- Fixed switching license language in ProductLicense.
- Fixed disabled Next button while showing license with no
  acceptance needed in ProductLicense.
* Fri Jan  8 2010 lslezak@suse.cz
- don't display exact total remaining time when there is an
  overflow (i.e. for >2:00:00 and e.g. 15:20 remaining time display
  >2:00:00 total instead of 2:15:20) (bnc#567966)
* Thu Jan  7 2010 lslezak@suse.cz
- pass the selected CD/DVD device to the package manager in case
  of multiple devices in the system (bnc#567403)
* Wed Jan  6 2010 lslezak@suse.cz
- do not reselect patterns which have been deselected by user
  (bnc#450786, bnc#471340)
- 2.19.2
* Mon Jan  4 2010 locilka@suse.cz
- Fixed accepting/declining the multilicense agreement.
* Fri Dec 11 2009 locilka@suse.cz
- ProductLicense prepared for multi-license dialogs (FATE #306295).
* Tue Dec  8 2009 kmachalkova@suse.cz
- 'Search' button is the one activated by pressing Enter in webpin
  client (bnc#538774)
- 2.19.1
* Tue Nov 24 2009 locilka@suse.cz
- Creating backup of old repositories at the end of initial
  installation/upgrade before any other SourceSaveAll call
  (bnc #556469).
* Mon Nov 23 2009 kmachalkova@suse.cz
- Webpin: Remaining string marked for translation (bnc#549945)
* Mon Nov 23 2009 lslezak@suse.cz
- repositories - fixed the help text to match the current layout
  (bnc#549866)
- repositories - improved ISO image file detection (use plain text
  instead of MIME type for 'file' output) (bnc#547683)
- repositories - added NFSv4 support (fate#306451), don't loose
  the current URL when switching between full and parsed view
* Fri Nov 20 2009 lslezak@suse.cz
- repositories - changed "Refresh Now" -> "Refresh Selected"
  (bnc#439067)
* Fri Nov 20 2009 lslezak@suse.cz
- sw_single - don't restart when started from command line (using
  "yast2 -i" option) and PKGMGR_ACTION_AT_EXIT="restart"
  (bnc#547609)
- 2.19.0
* Mon Oct 19 2009 lslezak@suse.cz
- Don't fail silently when an invallid repo URL is entered
  (bnc#516102)
- 2.18.13
* Wed Sep 23 2009 kmachalkova@suse.cz
- Use getenv to query current language for displaying the license
  (instead of uninitialized data from Language:: - bnc#504803, c#28)
- Removed catch-all regexps from license file name patterns - UI
  can display only html and txt anyway
- 2.18.12
* Wed Sep  9 2009 kmachalkova@suse.cz
- Correct regexp evaluation in searching for suitable file with
  license agreement (bnc#533026)
- 2.18.11
* Thu Sep  3 2009 kmachalkova@suse.cz
- Handle server-side errors in webpin search (HTTP 500 mostly), do
  not let anyxml agent parse non-XML file (bnc#526225)
* Tue Aug 25 2009 kmachalkova@suse.cz
- Prompt for installing packager-webpin if requested and not there
  yet (bnc#526225)
- Use new webpin icons, update module description (GenericName)
- 2.18.10
* Wed Jul 22 2009 kmachalkova@suse.cz
- Splitting webpin-related code off to separate package
  (yast2-packager-webpin), adding new .desktop file to it
- Start webpin search from pkg managers ( accept `webpin symbol
  from the main loop) (both FaTE#306928)
- 2.18.9
* Mon Jun 22 2009 locilka@suse.cz
- Adjusted ProductLicense to look for more license filename
  patterns (html, txt) (bnc #504803).
* Thu May 14 2009 lslezak@suse.cz
- display the Configuration menu in the package selector
  (bnc#497756)
- 2.18.8
* Wed Apr 29 2009 lslezak@suse.cz
- replace only changed cells in the table after chaging repository
  URL - keep the current sorting order (bnc#475961), do not change
  the current item (bnc#411585)
- preserve repository priority when changing URL
- open create repository dialog in a new window, fixes broken UI
  caused by the previous fix (bnc#269034)
- confirm adding of an already known repository (URL) (bnc#471054)
- 2.18.7
* Tue Apr 28 2009 lslezak@suse.cz
- use URL.ycp for processing smb:// URLs (bnc#495109)
- removed the extra error popup when adding a repository fails
  (bnc#269034)
* Thu Apr 23 2009 lslezak@suse.cz
- added a new progress dialog when registering a new repository,
  download progresses are embedded into the progress dialog instead
  of separate popups for each file (bnc#466808)
* Thu Apr 23 2009 lslezak@suse.cz
- display an additional help when adding an ISO repository over
  FTP or HTTP protocol fails (bnc#341668)
- 2.18.6
* Tue Apr 21 2009 lslezak@suse.cz
- Append additional RPM output to the installation log only if it
  is not empty (bnc#495047)
* Tue Apr 21 2009 locilka@suse.cz
- Using new function GetCachedFileFromSource from AddOnProduct
  to avoid from a 'jukebox' issues when more different physical
  media used during installation (bnc #486785).
* Mon Apr 20 2009 locilka@suse.cz
- Not checking signatures for add_on_products(.xml) file(s), the
  file is cerated by the customer and contains links to signed
  repositories (bnc #496404).
* Fri Apr 10 2009 lslezak@suse.cz
- repository manager - do not refresh CD/DVD repositories after
  changing the name, correctly display current scheme (CD/DVD),
  preserve device options when changing the repository name
  (bnc#469193)
- 2.18.5
* Wed Apr  8 2009 lslezak@suse.cz
- Slideshow fixes - display additional rpm output in the
  installation log, use installation log summary instead of
  non-existing y2logRPM file (bnc#456446)
- Avoid division by zero when total size to install is less than
  1024B (converted to 0kB)
* Fri Apr  3 2009 locilka@suse.cz
- Adjusting initial repository name according to LABEL in content
  file. Exporting the same function for Add-Ons (bnc #481828).
- 2.18.4
* Mon Mar 30 2009 lslezak@suse.cz
- sw_single - display the installation summary when there is
  something to install/remove at start (bnc#465194)
* Tue Mar 17 2009 lslezak@suse.cz
- Removed ZMD synchronization option, ZMD cannot sychronize
  all libzypp repositories (bnc#480845)
- Removed unused ZMD sync code
- 2.18.3
* Fri Feb 20 2009 locilka@suse.cz
- Always storing the current set of repositories before calling
  add-on product installation workflow (bnc #468449).
* Thu Jan 29 2009 kmachalkova@suse.cz
- Webpin search: remember all packages selected by user in all
  queries in this session + show them in "All Packages" tab
- Show "Really exit?" pop-up only if there is something to do
* Wed Jan 28 2009 lslezak@suse.cz
- do not remove kernel-xenpae package at update, it can be
  installed together with the standard kernel (bnc#468674)
* Mon Jan 26 2009 lslezak@suse.cz
- fixed another places logging complete URL including a password
  (bnc#441944)
* Fri Jan 23 2009 lslezak@suse.cz
- display the number of remaining packages during package
  installation (bnc#461970)
- 2.18.2
* Thu Jan 22 2009 lslezak@suse.cz
- installation callbacks - collect installation data for the
  summary dialog (bnc#431854)
- sw_single.ycp - do the action specified in PKGMGR_ACTION_AT_EXIT
  sysconfig variable when package installation is finished
* Fri Jan 16 2009 lslezak@suse.cz
- checkmedia - better module description (bnc#461985)
- 2.18.1
* Thu Jan 15 2009 lslezak@suse.cz
- disk usage: do not remove the leading slash in the path
  (bnc#222967)
* Wed Jan 14 2009 lslezak@suse.cz
- use a better alias instread of "repo_N" for community
  repositories (bnc#456099)
* Tue Jan 13 2009 lslezak@suse.cz
- display USB devices when adding USB mass storage repository
  (bnc#465650)
- 2.18.0
* Wed Dec 31 2008 lslezak@suse.cz
- repositories.ycp - better layout for too small window size
  (bnc#439807), use a combo box for switching the view (instead of
  the large tree widget) (bnc#433857)
* Tue Dec 30 2008 lslezak@suse.cz
- display the Package selector instead of the Pattern selector
  if there is a resolver problem during installation/update,
  display the conflicts immeditely (bnc#436721)
- do not display the free space warning in the installation summary
  for the partitions which are already almost full but nothing is
  going to be installed there (bnc#259493)
* Tue Dec 23 2008 lslezak@suse.cz
- repositories.ycp - configure 'keeppackages' repository option
  (bnc#402617)
* Mon Dec 22 2008 lslezak@suse.cz
- hide the [Back] button in the repository manager (bnc#440569)
* Thu Dec 18 2008 lslezak@suse.cz
- return back from the Repository Management to the Package
  Management after pressing [Cancel] instead of closing whole Yast
  (bnc#450336)
- checkmedia - move the "Check ISO File" button below the CD/DVD
  combo box so the button labels are not truncated (bnc#458600)
* Wed Dec 17 2008 lslezak@suse.cz
- URL edit popup - fixed layout in ncureses UI (hidden OK and
  Cancel buttons) (bnc#459580)
* Tue Dec 16 2008 lslezak@suse.cz
- inst_rpmcopy.ycp - commit also the changes if there are only
  packages to remove (bnc#416226)
* Tue Dec 16 2008 lslezak@suse.cz
- do not remove repositories belonging to an already removed
  service (service removal failed) (bnc#459413)
* Tue Dec 16 2008 locilka@suse.cz
- Fixed progress when adding community repositories (bnc #459391).
* Thu Dec 11 2008 locilka@suse.cz
- Fixed handling of patterns selected by add-ons (by using
  PackagesProposal module) (bnc #458297).
- 2.17.52
* Wed Dec 10 2008 lslezak@suse.cz
- fixed duplicating of repositories after editing, fixed comparison
  of the new and old URL of ISO repositories (bnc#449159)
- 2.17.51
* Fri Nov 28 2008 lslezak@suse.cz
- fixed changing status of the repositories belonging to a service
  (bnc#444366)
- 2.17.50
* Fri Nov 28 2008 locilka@suse.cz
- DefaultDesktop module now returns desktop name translated using
  the current language (bnc #449818).
- 2.17.49
* Thu Nov 27 2008 locilka@suse.cz
- Downloading slides only once (bnc #444612).
- Do not reset/open the slide show in inst_rpmcopy when slide show
  dialog is already available/in use (bnc #443755).
* Wed Nov 26 2008 locilka@suse.cz
- Using <pre> in ProductLicense (bnc #449188).
- 2.17.48
* Tue Nov 25 2008 lslezak@suse.cz
- use URL::HidePassword() when logging an URL (bnc#441944)
- 2.17.47
* Tue Nov 25 2008 locilka@suse.cz
- New flag no-acceptance-needed in licenses defines that users do
  not have to manually choose whether they accept the license
  agreement (bnc #448598).
- 2.17.46
* Fri Nov 21 2008 lslezak@suse.cz
- install openssh if "usessh=1" install option is used (bnc#446581)
- 2.17.45
* Wed Nov 19 2008 locilka@suse.cz
- Fixed reseting the software proposal. There are two possible
  resets now: PkgReset (full) and PkgApplReset (keeps user-made
  selection) (bnc #446406).
- 2.17.44
* Fri Nov 14 2008 lslezak@suse.cz
- changed SW selection is not an error (bnc#444517)
- 2.17.43
* Thu Nov 13 2008 kmachalkova@suse.cz
- Add xinetd to required packages for VNC mode of installation
  (needed for successful start of vnc* services) (bnc#442196)
* Wed Nov 12 2008 lslezak@suse.cz
- restore the original repository properties ("enabled",
  "autorefresh" and "keeppackages") when changing URL of
  a repository (bnc#441328)
- 2.17.42
* Sun Nov  9 2008 coolo@suse.de
- do not use InstURL::HidePassword to avoid warnings
- 2.17.41
* Fri Nov  7 2008 lslezak@suse.cz
- fixed URL logging (bnc#441944)
- use Pkg::SourceProvideDigestedFile() and
  Pkg::SourceProvideSignedFile() functions for downloading files
  from the installation repository (bnc#409927)
- 2.17.40
* Wed Nov  5 2008 locilka@suse.cz
- Fixed copying files from inst-sys to the system, some might be
  symbolic links (bnc #441829).
- 2.17.39
* Fri Oct 31 2008 locilka@suse.cz
- Fixed list of files copied in inst_kickoff from inst-sys to the
  system (bnc #440430).
- 2.17.38
* Fri Oct 31 2008 lslezak@suse.cz
- 2.17.37
* Thu Oct 30 2008 lslezak@suse.cz
- fixed missing URLs in the repository manager dialog (bnc#439060)
- set non-empty name for new services
* Wed Oct 29 2008 lslezak@suse.cz
- copy slideshow to the correct place (bnc#439799)
- 2.17.36
* Mon Oct 27 2008 locilka@suse.cz
- Reporting an error if software proposal cache is invalid
  (bnc #436925).
- 2.17.35
* Thu Oct 23 2008 lslezak@suse.cz
- properly select kernel packages (bnc#437258)
- 2.17.34
* Wed Oct 22 2008 lslezak@suse.cz
- install nfs-client instead of portmap when the system is
  installated from a NFS server (bnc#436897)
- install xen-tools-domU.rpm instead of xen-tools.rpm in XEN domU
  (bnc#437335)
- remove also the repositories which belong to a removed service,
  update status of the repositories when the service status is
  changed (bnc#437722)
- 2.17.33
* Tue Oct 21 2008 kmachalkova@suse.cz
- AddPackageList from Storage is no longer needed - now y2-storage
  handles package selection in installation by itself (bnc#433001)
* Tue Oct 21 2008 lslezak@suse.cz
- repositories.ycp - pad the priority number with spaces so the
  sorting by priority works as expected (bnc#404205)
* Mon Oct 20 2008 lslezak@suse.cz
- moved PackagesUI.ycp to yast2 package, use the new API
  (RunPackageSelector() and RunPatternSelector() functions)
  (bnc#435479)
- 2.17.32
* Mon Oct 20 2008 ug@suse.de
- workaround added to get old autoyast behaviour back
* Mon Oct 20 2008 lslezak@suse.cz
- display support status dialog in the package selector widget
  if it's requested in the control file (bnc#435479)
- 2.17.31
* Thu Oct 16 2008 mvidner@suse.cz
- Fixed localized sorting to emulate < instead of <=,
  avoiding a crash (bnc#385172).
- 2.17.30
* Thu Oct 16 2008 lslezak@suse.cz
- repositories.ycp - display name of the service (instead of alias)
  to which a repository belongs
* Wed Oct 15 2008 lslezak@suse.cz
- check signatures also when downloading slideshow images
  (bnc#409927)
- 2.17.29
* Mon Oct 13 2008 lslezak@suse.cz
- added a help text describing what services are (bnc#427728)
- fixed mounting NFS shares in free space detection code
  (bnc#433893)
- 2.17.28
* Thu Oct  9 2008 locilka@suse.cz
- Function SelectKernelPackages has been moved to from update to
  Packages module (bnc #326269).
- 2.17.27
* Mon Oct  6 2008 locilka@suse.cz
- Using PackagesProposal (`package/s, `pattern/s) to unify the
  software scenarios, desktops, and the rest of installation
  clients that can require to install some resolvables (bnc#432572)
- Do not initalize Packages before SlideShow in live install mode
  (bnc #432668).
- 2.17.26
* Fri Oct  3 2008 lslezak@suse.cz
- Fixed handling of services (bnc#427728)
- 2.17.25
* Thu Oct  2 2008 locilka@suse.cz
- Packager requires new YCP module PackagesProposal from yast2
  (bnc #431580)
- 2.17.24
* Thu Oct  2 2008 locilka@suse.cz
- Handling new tag in 'desktops' in control file:
  'do_not_deselect_patterns' - prevents deselecting patterns while
  such a desktop is selected (bnc #431251).
- New list of patterns selected by installation in Packages module
  to keep previously selected patterns selected (bnc #431251).
- 2.17.23
* Mon Sep 29 2008 locilka@suse.cz
- Always initialize Packages before SlideShowSetup (bnc #427935).
- 2.17.22
* Fri Sep 26 2008 lslezak@suse.cz
- do not use obsoleted Pkg::TargetLogfile() function (bnc#429954)
- inst_kickoff.ycp - remove nonexisting directories from /etc/mtab
  (bnc#425464)
- 2.17.21
* Thu Sep 25 2008 lslezak@suse.cz
- fixed broken tag in a richtext string (bnc#429850)
* Thu Sep 25 2008 lslezak@suse.cz
- check signatures when downloading the slideshow (bnc#409927)
- AddOnProduct.ycp - fixed GPG callbacks prototypes (bnc#370223)
- 2.17.20
* Tue Sep 23 2008 locilka@suse.cz
- New function Packages::GetBaseSourceID needed by update
  (FATE #304488).
- 2.17.19
* Mon Sep 22 2008 lslezak@suse.cz
- fixed a typo in the help text (bnc#428188)
* Mon Sep 22 2008 locilka@suse.cz
- Offering Community Repositories only if defined in control file
  otherwise they are hidden (bnc #428370).
- Returning back from Community Repositories if Canceled instead of
  continuing the workflow (bnc #428377).
- Reporting warning containing products selected for auto-removal
  during update (FATE #304488).
* Fri Sep 19 2008 locilka@suse.cz
- Fixed handling of 'PATTERNS' in content file (bnc #418821).
- Fixed checking which product can be replaced by which add-on
  (FATE #301997, bnc #427002).
- 2.17.18
* Thu Sep 18 2008 lslezak@suse.cz
- fixed "Installing Deleting <package>" message in the log view
  disaplyed during package removal (bnc#427356)
- use "repo_N" alias instead of full URL, make aliases more usable
  in zypper (bnc#395363)
* Thu Sep 18 2008 locilka@suse.cz
- Handling new 'add_on_mode' key in product control file
  (bnc #427002).
* Thu Sep 18 2008 locilka@suse.cz
- Always initialize supported desktops from control file
  (bnc #427061).
- 2.17.17
* Wed Sep 17 2008 lslezak@suse.cz
- removed suse_register code which breaks add-on config in
  installation (bnc#408835) (reverted changes from rev.48402)
- inst_rpmcopy.ycp - display more details when package installation
  fails (bnc#425373)
- inst_rpmcopy.ycp - code cleanup - removed obsoleted source
  caching code (sources are now cached directly in libzypp)
  (bnc#255758)
- 2.17.16
* Fri Sep 12 2008 lslezak@suse.cz
- sw_single - handle 'Configuration->Online Update' menu item
  (fate#303458)
- 2.17.15
* Wed Sep 10 2008 locilka@suse.cz
- Desktop selection dialog definitions have been moved to control
  file (bnc #424678).
- 2.17.14
* Wed Sep 10 2008 lslezak@suse.cz
- repositories.ycp: change table headers when switching to
  the service view
- merged proofread texts (2008-09-08)
- 2.17.13
* Tue Sep  9 2008 locilka@suse.cz
- xmlrepos SCR agent replaced with OneClickInstallStandard module
  using XML::Simple (anyxml SCR agent) instead of perl-XML-Bare
  (bnc #424263).
* Tue Sep  9 2008 locilka@suse.cz
- Packages 'Slides' and 'SlideShow' moved to yast2.
- 2.17.12
* Mon Sep  8 2008 lslezak@suse.cz
- preliminary support for sevices - display a tree on the left side
  (does not work yet), print to which service the selected
  repository belongs
- 2.17.11
* Mon Sep  8 2008 locilka@suse.cz
- Less confusing Add-On update/installation mode handling
  independent on the base-product mode (FATE #301997).
* Mon Sep  8 2008 locilka@suse.cz
- Initializing the installation repository got from install.inf in
  this order: ZyppRepoURL, YaSTRepoURL, RepoURL (bnc #406162).
- 2.17.10
* Fri Sep  5 2008 locilka@suse.cz
- Don't show selected desktop in proposal if none has been selected
  (bnc #422077).
* Thu Sep  4 2008 lslezak@suse.cz
- sw_single: display "Starting the Software Manager" instead of
  "Starting the Package Manager" (bnc#421952)
* Wed Sep  3 2008 locilka@suse.cz
- Adjusting SlideShow in inst_rpmcopy if not set.
- Using new "replaces" key returned by Pkg::ResolvableProperties
  while upgrading add-on product. Different workflow is used for
  installation and update (FATE #301997).
* Wed Sep  3 2008 locilka@suse.cz
- Fixed inst_custom_packages YCP script to reflect the changes done
  in SlideShow*.
- 2.17.9
* Tue Sep  2 2008 visnov@suse.cz
- Use unified progress bar during installation (FATE #303860)
* Wed Aug 27 2008 locilka@suse.cz
- Initializing installation URL got from install.inf (RepoURL)
  if exists (bnc #406162).
- 2.17.8
* Mon Aug 25 2008 ug@suse.de
- post_patterns added for autoyast
- 2.17.7
* Thu Aug 21 2008 lslezak@suse.cz
- repositories.ycp: update Autorefresh flag in the table when
  autorefresh is changed
- 2.17.6
* Thu Aug 21 2008 jsuchome@suse.cz
- SlideShow.ycp: do not use UI while being imported, breaks CLI
* Thu Aug 14 2008 locilka@suse.cz
- Added support for several products on one media by making
  add_on_products obsolete and introducing new add_on_products.xml
  format (FATE #303675).
- Disabling hotfix (bnc #385868) for /openSUSE-release.prod file,
  it is properly fixed in zypp already.
- 2.17.5
* Tue Aug  5 2008 locilka@suse.cz
- Reporting 'no network is running' when calling Community
  Repositories without network in mode 'normal' (bnc #327519).
* Mon Aug  4 2008 locilka@suse.cz
- Community Repositories: listing recommended repositories first
  then sorting alphabetically (bnc #399998).
* Wed Jul 30 2008 lslezak@suse.cz
- display autorefresh column in the repository config module
  (bnc#384132)
* Tue Jul 29 2008 lslezak@suse.cz
- added yast2-transfer to BuildRequires
- 2.17.4
* Mon Jul 28 2008 lslezak@suse.cz
- correctly save the installation repositories at the end of
  installation (bnc#412616)
- 2.17.3
* Tue Jul 22 2008 lslezak@suse.cz
- sw_single - don't ask "Install or remove more packages?" after
  installation (bnc#409171)
- 2.17.2
* Wed Jul 16 2008 jsrain@suse.cz
- always call inst_bootloader, even in update (fate #302245)
* Mon Jul 14 2008 locilka@suse.cz
- Removed dependency on yast2-installation.
* Fri Jul 11 2008 locilka@suse.cz
- Enhancing the Webpin Search module and client...
* Tue Jul  1 2008 locilka@suse.cz
- Added new WebpinPackageSearch YCP module.
* Wed Jun 18 2008 lslezak@suse.cz
- add an update repository obtained via suse_register (fate#302990)
- adapted to the new patch messages and patch scripts callbacks
  (bnc#401220)
- 2.17.1
* Wed Jun 18 2008 lslezak@suse.cz
- ask user when uninstalling a package via command line option
  (bnc#399795)
* Tue Jun 17 2008 lslezak@suse.cz
- use Pkg::SourceSaveAll() instead of Pkg::SourceFinishAll()
  (bnc#395738)
- 2.17.0
* Fri Jun 13 2008 lslezak@suse.cz
- install icewm instead of fvwm2 in vnc installation mode
  (bnc#399591)
- do not check for missing yast2-slp package when doing an update
  (bnc#399191)
* Thu Jun 12 2008 lslezak@suse.cz
- Ignore VFAT and NTFS partitions in the installation stage in the
  package selector (bnc#395289)
- added help text for the software proposal (bnc#393004)
- fixed help text in repositories.ycp (priority is 0-200)
- the repository manager - use OK/Cancel buttons (bnc#398481)
* Wed Jun 11 2008 lslezak@suse.cz
- added options for sw_single client, display proper workflow for
  add-ons (bnc#377154)
* Wed Jun  4 2008 lslezak@suse.cz
- use PackageLock::Connect() - display [Abort] button (bnc#293356)
- fixed editing of an invalid repository URL (bnc#386384),
  set the selected repository type when going back
* Wed Jun  4 2008 lslezak@suse.cz
- removed the workaround for locking 64-bit packages on PPC32
  (bnc#336678)
* Tue Jun  3 2008 lslezak@suse.cz
- Display the error message properly in the media change popup.
  (bnc#395328)
- 2.16.53
* Fri May 23 2008 lslezak@suse.cz
- reserve more space for the table in the repository manager,
  esp. needed in the GTK UI (bnc#392807)
- 2.16.52
* Thu May 22 2008 locilka@suse.cz
- Creating backup of files in /etc/ owned by pam package
  before installation-upgrade starts (bnc #393066).
- 2.16.51
* Thu May 22 2008 lslezak@suse.cz
- do not load repositories from the target system in repair mode
  (bnc#392508)
- the locking code was skipped, moved to the initialization part
  (bnc#336678)
* Mon May 19 2008 locilka@suse.cz
- Fixed Community Repositories module behavior when called from
  Add-Ons in the initial installation (bnc #392111).
- 2.16.50
* Mon May 19 2008 lslezak@suse.cz
- the repository manager - allow to set priority of a repository
  in range 0-200 (bnc#391764)
- increased the treshold for the free space warning in the
  installation proposal from 5%% to 25%% (bnc#178357)
- 2.16.49
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Fri May 16 2008 lslezak@suse.cz
- Slideshow - display progress dialog when only deleteing packages
  (bnc#391198)
- Slideshow - set the total progress at least to 1 to avoid
  the tick progress mode
- 2.16.48
* Thu May 15 2008 locilka@suse.cz
- Some functions from repositories.ycp were moved to a separate
  include file to share them (bnc #368207).
- 2.16.47
* Mon May 12 2008 lslezak@suse.cz
- lock 64-bit packages on PPC32 during installation (bnc#336678)
- 2.16.46
* Mon May 12 2008 jsrain@suse.cz
- copy the openSUSE product information from the media to the
  target system (bnc #385868)
- 2.16.45
* Fri May  2 2008 lslezak@suse.cz
- repositories.ycp - do not disable Progress:: when started from
  sw_single (bnc#381673)
- fixed command line mode init
- 2.16.44
* Wed Apr 30 2008 lslezak@suse.cz
- don't show "Repository" menu in the package manager during
  installation (bnc#381956)
- 2.16.43
* Tue Apr 29 2008 locilka@suse.cz
- Calling inst_extrasources in pkg_finish to get default
  repositories added in case of upgrade (bnc #384827, bnc #381360).
- 2.16.42
* Tue Apr 29 2008 lslezak@suse.cz
- repository manager - remember the URL when switching from "parts"
  view to "full" view (bnc#383984)
* Tue Apr 29 2008 lslezak@suse.cz
- use sizes in kB in the total progressbar in slideshow (progress
  bar widget uses 32 bit integers only), fixes "tick" progress
  mode when install size is greater than 2GB (bnc#380867)
- 2.16.41
* Tue Apr 29 2008 coolo@suse.de
- resubmitting package with correct version
* Mon Apr 28 2008 lslezak@suse.cz
- sw_single - removed extra UI::CloseDialog() call (bnc#382580),
  display an error message when installation of a package from
  desktop fails
- sort the patterns in the installation proposal by "order"
  property (bnc#255726)
- 2.16.40
* Mon Apr 28 2008 locilka@suse.cz
- Fixed KDE 3.5 description (bnc #379157).
- Selecting Xfce will set DEFAULT_WM to 'startxfce4' (bnc #298558).
- Handling KDE3 vs KDE4 in default logon and window managers
  (bnc #381821).
- Some more desktop-related configuration data moved to
  DefaultDesktop module from desktop_finish client.
* Fri Apr 25 2008 locilka@suse.cz
- New desktop selection dialog (bnc #379157).
- 2.16.39
* Fri Apr 25 2008 lslezak@suse.cz
- restored 'Software Repositories' icon in the control center
  (bnc#381255)
* Wed Apr 23 2008 lslezak@suse.cz
- do not check product category (it is obsoleted), install all
  products (bnc#359538)
- 2.16.38
* Mon Apr 21 2008 locilka@suse.cz
- Added new function DefaultDesktop::SelectedDesktops() to list all
  installed desktops or desktop selected for installation
  (bnc #380774).
- 2.16.37
* Fri Apr 18 2008 locilka@suse.cz
- Do not overwrite passwd and shadow files if they already exist on
  a system (e.g., from images) (bnc #381227).
- 2.16.36
* Fri Apr 18 2008 lslezak@suse.cz
- Use Pkg::PkgMediaSizes() and Pkg::PkgMediaPackageSizes() for
  computing total install and download size instead of quering
  each selected package separately (speeds up the proposal summary
  from 15-20 seconds to less than 1 second)
- this is also a workaround for broken disk usage in libzypp
  (bnc#375104)
- 2.16.35
* Wed Apr 16 2008 locilka@suse.cz
- Using pattern-xfce for XFCE Desktop selection (bnc #377584).
* Tue Apr 15 2008 lslezak@suse.cz
- disable the callbacks when downloading slideshow (bnc#377919)
- 2.16.34
* Mon Apr 14 2008 lslezak@suse.cz
- 2.16.33
* Mon Apr 14 2008 locilka@suse.cz
- Added KDE3 to a System Type selection (bnc #379157).
* Fri Apr 11 2008 locilka@suse.cz
- Fixing InstInitSourceMoveDownloadArea: mkdir -p is better than
  without -p.
* Fri Apr 11 2008 lslezak@suse.cz
- SlideShowCallbacks - fixed return value of ProgressDownload()
  callback function, check abort status
* Thu Apr 10 2008 lslezak@suse.cz
- repositories - do not initialize the package manager when
  started from sw_single (it's already done)
- SW proposal - do not display selection summary if there is no
  selection
- 2.16.32
* Thu Apr 10 2008 locilka@suse.cz
- InstInitSourceMoveDownloadArea has been moved into a separate
  module in SourceManager in order to use it from installation from
  images too.
* Tue Apr  8 2008 lslezak@suse.cz
- removed 'Software Repositories' from the yast control center
  (it can be started from 'Software Management', it's description
  has been updated) (fate#302991)
* Mon Apr  7 2008 lslezak@suse.cz
- fixed a typo in the help text (bnc#376311)
- added 'Recommends: checkmedia' dependency to ensure 'checkmedia'
  package is on the medium (bnc#372976)
* Fri Apr  4 2008 jsrain@suse.cz
- avoid calling PackageCallbacksInit::InitPackageCallbacks () to
  prevent testsuites of other packages from failing
- 2.16.31
* Wed Apr  2 2008 lslezak@suse.cz
- adapted callback registration implementation - use references
  to functions (fate#302296)
- moved package callbacks from yast2-packager to yast2 package
- 2.16.30
* Fri Mar 28 2008 lslezak@suse.cz
- use correct "X Window" label (bnc#371552)
* Thu Mar 27 2008 lslezak@suse.cz
- repositories - display and edit priorities (bnc#369827)
- repositories - preselect "URL" type when adding a new repository
  (bnc#301659)
- 2.16.29
* Wed Mar 26 2008 lslezak@suse.cz
- media check - added "Eject" button (bnc#294097)
- repositories - initialize the target in the standalone mode
  to load GPG keys
* Wed Mar 26 2008 lslezak@suse.cz
- media check - updated and improved help text (bnc#132881)
- repositories - URL can be selected and copied (bnc#334757)
- repositories - added URL column into the table (bnc#335880)
- 2.16.28
* Fri Mar 21 2008 lslezak@suse.cz
- media change callback - autoretry downloading after timeout
  (3 attempts, 30 seconds each) (bnc#328822)
- 2.16.27
* Thu Mar 20 2008 jsrain@suse.cz
- do not use double-bullet in the pattern list (fate#120376)
* Thu Mar 20 2008 lslezak@suse.cz
- when changing URL of a repository allow to change the URL as
  a whole (fate#120332)
* Wed Mar 19 2008 lslezak@suse.cz
- do not probe CD/DVD devices after pressing [Eject] (probing
  closes just the ejected device)
- added "Automatic Eject" checkbox (fate#301228)
* Wed Mar 19 2008 lslezak@suse.cz
- Slideshow - dropped vertical multi progress bar, display
  remaining size and time in the main progress bar (fate#303437)
* Mon Mar 17 2008 lslezak@suse.cz
- unified button labels (use "OK" instead of "Accept")
  (fate#120373)
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Fri Mar 14 2008 lslezak@suse.cz
- added support for starting the repository manager from
  the package manager (fate#302517)
- 2.16.26
* Fri Mar 14 2008 juhliarik@suse.cz
- added calling inst_bootloader from inst_kickoff (FATE #302660)
* Fri Mar 14 2008 lslezak@suse.cz
- support for ejecting specified CD/DVD device, handle multiple
  devices (fate#120298)
- 2.16.25
* Tue Mar 11 2008 lslezak@suse.cz
- display download rate in callbacks (bnc#168935)
- 2.16.24
* Wed Mar  5 2008 lslezak@suse.cz
- added Pkg::CallbackStartRefresh() and Pkg::CallbackDoneRefresh()
  handlers, ask user to skip repository refresh at start up
  (FATE #30962, bnc #231745)
- added menu buttons for refreshing all repositories (#344633)
- 2.16.23
* Wed Feb 27 2008 lslezak@suse.cz
- repositories - added 'community repos' text into the description
  (#346718)
- SourceManager.ycp - removed obsoleted .process agent call
- do not select a Xen kernel, it is part of the Xen pattern now
  (#362030)
- 2.16.22
* Mon Feb 25 2008 sh@suse.de
- Require yast2_ui_pkg in .spec file (bnc #363958)
- V 2.16.21
* Tue Feb 19 2008 lslezak@suse.cz
- PackageCallbacks - properly close Wizard window (#359235)
- 2.16.20
* Mon Feb 18 2008 coolo@suse.de
- use pattern:enhanced_base for "Minimal" desktop (bnc#351027)
* Mon Feb 18 2008 lslezak@suse.cz
- SourceDialogs.ycp - added support for plaindir repositories
  on an disk (incl. USB storage), generalized plaindir handling
  (added SourceDialogs::IsPlaindir(), SourceDialogs::SetURLType(),
  SourceDialogs::EditURLType())
* Fri Feb 15 2008 lslezak@suse.cz
- checkmedia - fixed output for Qt4, use .process agent instead
  of .background
* Fri Feb 15 2008 jsrain@suse.cz
- added handling installation from images (without RPMs)
* Wed Feb 13 2008 jsrain@suse.cz
- Allow to specify whole installation repo URL (in zypp-like
  format) in /etc/install.inf
* Tue Feb  5 2008 locilka@suse.cz
- Fixed filtering in Community Repositories - filtering now uses
  localized strings (bnc #358001).
* Fri Feb  1 2008 locilka@suse.cz
- Using new URL functions in AddOnProduct.
- Adjusted RPM dependencies.
- 2.16.19
* Thu Jan 31 2008 locilka@suse.cz
- Reworked ProductLicense module to handle first-stage installation
  license.
- 2.16.18
* Tue Jan 29 2008 locilka@suse.cz
- Unified DefaultDesktop module and software/desktop selection
  dialog in installation.
- 2.16.17
* Sun Jan 27 2008 coolo@suse.de
- fixing changelog order
* Fri Jan 25 2008 lslezak@suse.cz
- added support for adding repositories on a hard disk or on
  an USB storage device (USB stick, USB disk...) (FATE #302382)
- Disk URL can be edited (#287672)
* Tue Jan 22 2008 lslezak@suse.cz
- callbacks - do not open a new progress window if there is
  a progress already running (the progress will be nested in such
  case) (#352007)
- sw_single - use Progress:: to display the total progress at
  start, reinitialize the target only if it is necessary
- 2.16.16
* Thu Jan 17 2008 lslezak@suse.cz
- use a `BusyIndicator widget instead of the animated icon
- use a map parameter in the GPG key related callbacks,
  display created and expiration dates in the popups,
  display a warning if the key is expired
- implemented AcceptWrongDigest and AcceptUnknownDigest callbacks
- 2.16.15
* Wed Jan 16 2008 locilka@suse.cz
- Always use ProvideOptionalFile for downloading the Release Notes
  (#352887).
* Tue Jan 15 2008 lslezak@suse.cz
- write key manager configuration, display/edit only trusted keys
  (untrusted keys have no storage and will be lost at exit)
* Mon Jan 14 2008 lslezak@suse.cz
- display details about the GPG key selected for import, UI fully
  works, importing/removing a key works in Write()
- 2.16.14
* Thu Jan 10 2008 lslezak@suse.cz
- added preliminary support for GPG key management (FATE #300754)
* Fri Jan  4 2008 lslezak@suse.cz
- PackageCallbacks: do not remove the subprogress widget, try to
  reuse it later if possible (#350584)
- do not call Pkg::SaveState() and Pkg::RestoreState(), the state
  is saved/restored by the package selector widget
- 2.16.13
* Wed Dec 12 2007 lslezak@suse.cz
- bug fixes in the new callbacks
- 2.16.12
* Mon Dec 10 2007 locilka@suse.cz
- PATTERNS tag in Add-On content file can contain list of patterns
  that are automatically pre-selected by adding the Add-On source
  (FATE #302398).
* Mon Dec 10 2007 lslezak@suse.cz
- merged proofread texts (2007-18-23)
* Mon Dec 10 2007 locilka@suse.cz
- Dependency on yast2-country replaced with yast2-country-data
  to minimize dependencies.
* Fri Dec  7 2007 lslezak@suse.cz
- added Process callbacks (fullscreen progress with stages)
- package manager initialization runs in the main window instead
  of popups
- use generic string "Disc" for both CD and DVD repositories
  (#336881)
- 2.16.11
* Tue Dec  4 2007 locilka@suse.cz
- Speeding up Community Repositories (No need to refresh cache).
- New Progress with Icons used in Community Repositories.
* Mon Dec  3 2007 locilka@suse.cz
- Removed "If you like to print this license..." (#327542).
- Using new YCP module Icon in PackageCallbacks.
* Tue Nov 27 2007 locilka@suse.cz
- Module 'Community Repositories' merged into 'Repositories'. It's
  still possible to call 'Community Repositories' separately.
- 2.16.10
* Thu Nov 22 2007 locilka@suse.cz
- Normalizing both already used and downloaded URLs in Community
  Repositories to match them better (#329629).
* Tue Nov 20 2007 lslezak@suse.cz
- fixed a missing import and syntax errors in Packages.ycp
- 2.16.9
* Tue Nov 20 2007 lslezak@suse.cz
- checkmedia: added support for checking ISO files, display
  a warning if the medium doesn't contain MD5 checksum in the
  application area
- display the total download size from http and ftp repositories
  in the installation proposal (#331538)
- describe the items in the SW proposal
- 2.16.8
* Mon Nov 19 2007 lslezak@suse.cz
- checkmedia: colorize the output to make the result (esp. errors)
  more visible (part of #309003)
- 2.16.7
* Mon Nov 19 2007 lslezak@suse.cz
- checkmedia: always print the result of the check - fixed a race
  condition (#309003)
- 2.16.6
* Fri Nov 16 2007 locilka@suse.cz
- SCR agent for any_XML has been moved from yast2-packager-2.16.5
  to yast2-2.16.11 (#332187).
- Adjusted RPM dependencies.
- 2.16.5
* Thu Nov  8 2007 locilka@suse.cz
- Extended AskLicenseAgreement function not to skip already
  accepted license if such behavior requested (because of 'going
  back' in the installation workflow).
* Wed Nov  7 2007 locilka@suse.cz
- AutoinstSoftware::post_packages moved to
  AutoinstData::post_packages to break cyclic dependencies.
- 2.16.4
* Mon Nov  5 2007 locilka@suse.cz
- Part of the package content has been moved to a new package
  yast2-dirinstall.
- Fixed (added) generation of autodocs.
- 2.16.3
* Fri Nov  2 2007 locilka@suse.cz
- Removed dependency on yast2-bootloader, Bootloader::PreUpdate()
  does nothing.
* Thu Nov  1 2007 locilka@suse.cz
- Update/backup-related variables were moved from Update::* to
  Installation::update_* to remove RPM dependencies.
- 2.16.2
* Wed Oct 31 2007 locilka@suse.cz
- installedVersion and updateVersion moved from 'Update' to
  'Installation' YCP module to remove dependencies.
- Removed support for converting inittab from SUSE Linux 7.0 and
  older during upgrade.
- 2.16.1
* Tue Oct 30 2007 locilka@suse.cz
- Downloading only one localized slideshow (with 'en' localization
  as a fallback) instead of downloading the whole directory with
  slides (#326327).
* Fri Oct 26 2007 lslezak@suse.cz
- package kernel-bigsmp has been renamed to kernel-pae
- handle `close event (dialog closed by WM) (#335472)
- 2.16.0
* Thu Oct 11 2007 locilka@suse.cz
- Using the new FileUtils::MD5sum function.
- Adjusted RPM dependencies.
- Calling inst_suse_register instead of suse_register client in
  AddOnProduct module (#297264).
* Wed Oct  3 2007 locilka@suse.cz
- During upgrade, old repositories are removed (they are already
  readded either enabled or disabled during the initial stage
  of the upgrade).
- Before removing, repositories are backed up in
  /var/lib/YaST2/repos.d_backup directory (both #326325).
* Thu Sep 27 2007 lslezak@suse.cz
- fixed a wrong wording in the mediacheck help text (#304677)
* Mon Sep 24 2007 lslezak@suse.cz
- relese the source after it is added, allow changing the CD medium
  in the drive (#293428)
- 2.15.81
* Mon Sep 17 2007 lslezak@suse.cz
- inst_rpmcopy.ycp - check for nil result of Pkg::PkgCommit(),
  display an error message (#293428)
- 2.15.80
* Fri Sep 14 2007 locilka@suse.cz
- Fixed behavior when the same licence had to be accepted several
  times - for every single repository added. Now, the same licence
  has to be accepted only once (during one YaST run) (#305503).
- Adjusted RPM dependency (md5sum binary) (#305503).
- 2.15.79
* Wed Sep 12 2007 locilka@suse.cz
- Fixed evaluation of $short_language localization key in online
  repositories.
- Adapted ag_xmlrepos to understand xml:lang="..." additionally to
  lang="..." (both #299230).
- 2.15.78
* Tue Sep 11 2007 locilka@suse.cz
- Online repositories need to be added with unique alias (#309317).
- Better error handling in checkmedia feature (#305495).
- 2.15.77
* Tue Sep 11 2007 lslezak@suse.cz
- Properly create the progress popup in ncurses so it can be closed
  at the end (#309376), fixed refresh in ncurses
* Mon Sep 10 2007 locilka@suse.cz
- Fixed SlideShow initialization, using Pkg::SourceProvideDirectory
  instead of obsolete Pkg::SourceProvideDir (#305097).
- Calling SetFocus in SourceDialogs for http, https, samba, and ftp
  repositories to adjust the initial tab-order correctly (#305074).
- 2.15.76
* Wed Sep  5 2007 locilka@suse.cz
- Reading and using proxy settings before inst_productsources
  starts downloading files (#307680).
- Initializing packager callbacks in inst_productsources on
  a running system (#307652).
- Warning when inst_productsources is called in installation and
  the inst-sys has not enough memory (#305554).
- Adjusted RPM dependencies.
- 2.15.75
* Mon Sep  3 2007 locilka@suse.cz
- Correctly evaluating relurl:// parameters, such as
  relurl://.../?device=sda5 (#306670).
- 2.15.74
* Mon Sep  3 2007 lslezak@suse.cz
- use gif animation for the busy indicator (works also in Gtk UI)
  (#296945), do not restart the animation too often (wait at least
  3 seconds)
* Mon Sep  3 2007 lslezak@suse.cz
- better busy indicator for tick callback (#296945)
- 2.15.73
* Mon Sep  3 2007 lslezak@suse.cz
- try HTTP scheme when registering an FTP update source fails due
  to too restrictive firewall (#227059)
- 2.15.72
* Mon Sep  3 2007 locilka@suse.cz
- Added support for LiveCD installation into ProductLicense module
  (#299732).
* Fri Aug 31 2007 locilka@suse.cz
- Added commandline support for inst_productsources (#304720).
- 2.15.71
* Fri Aug 31 2007 lslezak@suse.cz
- check exit status and report errors when adding online
  repositories (#306272)
- 2.15.70
* Wed Aug 29 2007 lslezak@suse.cz
- fully initialize the target system when adding an update
  repository (#304310)
- 2.15.69
* Fri Aug 24 2007 locilka@suse.cz
- Fixed "If you like to print this license..." by moving it to the
  correct place (#304334).
- 2.15.68
* Fri Aug 24 2007 locilka@suse.cz
- Disable the [ Next ] button in the License dialog until either
  "Agree" or "Dont't Agree" is selected (#303828).
- 2.15.67
* Thu Aug 23 2007 locilka@suse.cz
- Displaying license in a separate Wizard dialog not to rewrite the
  progress or other dialogs below (#303922).
* Thu Aug 23 2007 sh@suse.de
- Beautification for bug #299787: Preserve spacings even with
  over-long repo names
- 2.15.66
* Wed Aug 22 2007 lslezak@suse.cz
- better error handling when adding Online Repositories (#302385)
- disable [Back] button in the check media module (#300208)
- 2.15.65
* Wed Aug 22 2007 locilka@suse.cz
- Make possible to abort in the the Read/Write dialog of Online
  Repositories (#298050).
- [ Back ] [ Cancel ] [ Accept ] buttons in Software Selection
  dialog (#298056).
- 2.15.64
* Thu Aug 16 2007 jsuchome@suse.cz
- inst_source.ycp renamed to repositories.ycp  (#300923)
- fixed double-click in the sources table
- 2.15.63
* Thu Aug 16 2007 ug@suse.de
- check wether packages have to be installed turned off for
  autoinstallation (#300215)
- 2.15.62
* Thu Aug 16 2007 lslezak@suse.cz
- disable autorefresh for CD repositories (#300928)
- use the last directory name from URL as name (#299816)
- display more details when adding a source fails
* Tue Aug 14 2007 jsuchome@suse.cz
- Merged proofread texts
- 2.15.61
* Tue Aug 14 2007 jsuchome@suse.cz
- double-click in the sources table toggles enabled/disabled status
  (#299787)
- 2.15.60
* Mon Aug 13 2007 lslezak@suse.cz
- report details when initialization of the installation repository
  fails (#299716)
- 2.15.59
* Fri Aug 10 2007 locilka@suse.cz
- Using "Online Repositories" for Internet/Web-based/Additional/...
  repositories downloaded from web during the first stage
  installation (#296407).
- 2.15.58
* Fri Aug 10 2007 jsrain@suse.cz
- fixed textdomain of load_release_notes.ycp
* Fri Aug 10 2007 lslezak@suse.cz
- removed extra RPM DB reload (workaround for #201121), not needed
  anymore (#296457)
* Thu Aug  9 2007 locilka@suse.cz
- Adapted License handling to search for /license.tar.gz with
  /media.1/license.zip as a backward compatibility/fallback.
- Modified text informing where to find the license
  (both bugzilla #298342 and FATE #302018).
- 2.15.57
* Wed Aug  8 2007 lslezak@suse.cz
- shorten URL used as alias or name
- 2.15.56
* Wed Aug  8 2007 locilka@suse.cz
- Fixed adding Internet repositories to be able to use them during
  installation (#298422).
- Adapted Internet repositories client to preselect recommended
  repositories for the first run of the client in installation
  and to sort by the 'recommended' tag in installation (#297628).
* Wed Aug  8 2007 jsrain@suse.cz
- updated prefix to release notes during installation slideshow
  (#296433)
* Wed Aug  8 2007 lslezak@suse.cz
- do not loose the repository name when adding has failed (#297774)
- fixed repository editing when download has failed
* Mon Aug  6 2007 lslezak@suse.cz
- properly detect ISO image (disable autorefresh)
- show download progress when installing packages (#297843)
- allow entering an IP address in the server name widget (#288445)
- 2.15.55
* Mon Aug  6 2007 lslezak@suse.cz
- fixed repository probing (merging URL and product directory has
  been moved to pkg-bindings)
- 2.15.54
* Mon Aug  6 2007 locilka@suse.cz
- Added text into the license-confirmation dialog about where to
  find the license on the media (FATE #302018).
- Using new Pkg::RepositoryAdd and Pkg::SourceRefreshNow functions
  that enables installation to set the repository name and alias
  before it is used (#297422).
* Thu Aug  2 2007 locilka@suse.cz
- Support for localized strings in remote repositories
  (inst_productsources).
- Better error handling when parsing downloaded XML file in
  ag_xmlrepos.
- Added support for downloading from HTTPS servers.
- Only repositories with 'installation_repo' tag set are used in
  first stage installation (instead of 'official') (#297628).
- Reporting when list of repositories is empty, cannot be
  downloaded or parsed (#294997).
- Using new pkg-bindings functionality to provide optional
  directory with licenses (#302018).
- New text for License dialog (FATE #302018 comment #36).
- Download and use y2update before merging installation.xml when
  use Add-On product in installation (#295160).
- Renamed product repositories to "Community Repositories".
- Adjusted RPM dependencies (yast2-pkg-bindings).
* Thu Aug  2 2007 lslezak@suse.cz
- inst_source - download metadata for CD/DVD repositories
  immedately, the medium can be changed later and accidentaly
  a different repository can registered
- improved download progress callback handlers (#292629)
- fixed "tick" callback progress
- beep when another medium is needed (#45527, FATE #120296)
- release all sources in the first stage, manual CD unmount is not
  needed anymore (FATE #413)
- 2.15.53
* Tue Jul 31 2007 locilka@suse.cz
- New location of licenses on the media - in /media.1/license/
  directory in uncompressed state (FATE #302018). Staying backward
  compatible by supporting /media.1/license.zip as well.
* Mon Jul 30 2007 locilka@suse.cz
- Adding new informative text where to find just displayed license
  (FATE #302018).
- 2.15.52
* Mon Jul 30 2007 lslezak@suse.cz
- sw_single - do not abort after pressing [Continue] when a zypp
  lock exists, use a separate error popup dialog (workaround
  for #293356)
- inst_source - updated help text (#291004)
- 2.15.51
* Mon Jul 30 2007 locilka@suse.cz
- Community servers are not used during the installation (Bugzilla
  [#293811]).
* Mon Jul 30 2007 jsrain@suse.cz
- allow to display release notes while installing packages
  (Fate #302342)
* Fri Jul 27 2007 locilka@suse.cz
- Added new SCR agents ag_anyxml and ag_zypp_repos (FATE #301785).
* Fri Jul 27 2007 lslezak@suse.cz
- use "Software Repositories" label in Y2CC (#215198)
- Updated Progress callback handler to handle a "raw" progress
- 2.15.50
* Fri Jul 27 2007 jsrain@suse.cz
- redesigned the repository management dialog (Fate #302072),
  repository name can be changed together with the URL, do not
  reset the name (#258783)
* Thu Jul 26 2007 lslezak@suse.cz
- inst_source - use product name or URL as alias for a new
  repository (instead of a timestamp)
- added inst_repo.ycp (alias to inst_source)
* Tue Jul 24 2007 lslezak@suse.cz
- use generic "Medium X" label instead of unreliable "CD"/"DVD"
  detection (the detection was based on the URL scheme of the
  repository) (#281857)
- always display source name in the table
- 2.15.49
* Mon Jul 23 2007 lslezak@suse.cz
- inst_source - add multiple installation repositories at one
  (download and parse all metadata at the end) (FATE #301730,
  bug #208461)
- added an option to completely skip metadata downloading when
  registering a repository (FATE #301894)
- 2.15.48
* Mon Jul 23 2007 lslezak@suse.cz
- Hide "Synchronize with Zenworks" option when ZMD is not available
  (#292631)
* Thu Jul 19 2007 locilka@suse.cz
- New agent .xmlrepos for parsing XML files according to One Click
  Install Standard.
- Module OneClickInstallStandard rewritten from Perl to YCP to
  use new .xmlrepos agent.
- Modified RPM dependencies.
- Removed obsolete testsuite for OneClickInstallStandard module.
- Adapted inst_productsources to the new OneClickInstallStandard.
- Adjusted spec file to the new source files (all items: #292643).
- 2.15.47
* Thu Jul 19 2007 lslezak@suse.cz
- dialog sizes adapted to support resolutions lower than 800x600
  (#273147)
- "installation source" changed to "repository"
* Wed Jul 18 2007 locilka@suse.cz
- Added support for relative URLs in the add_on_products file by
  handling a new URL type: relurl://... (FATE #302123).
* Wed Jul 18 2007 lslezak@suse.cz
- added Progress callbacks
- use "name" key for changing the name
- removed obsoleted code (no "broken" sources anymore)
- SourceManager::CreateLocalMetaData() has been removed (it's
  obsoleted and unused in any yast module)
- 2.15.46
* Thu Jul 12 2007 locilka@suse.cz
- Client inst_productsources moved here from yast2-installation.
- Adjusted Requires: tag to match inst_productsources' needs.
- Added productsources.desktop to the Software in Control Center.
- Client inst_productsources changed to use OneClickInstallStandard
  YaST module (and its XML format).
- Added helps into the inst_productsources.
- 2.15.45
* Mon Jul  9 2007 locilka@suse.cz
- Added new OneClickInstallStandard module written in Perl to
  support XML format specified by One Click Install Standard
  http://en.opensuse.org/Standards/One_Click_Install - Only
  repositories are supported now.
- Added perl-XML-Simple to the spec file as 'Requires'.
- Added testsuite for OneClickInstallStandard module.
- 2.15.44
* Wed Jul  4 2007 locilka@suse.cz
- Callback function for setting the trust level to the GnuPG key
  has been merged with a function for importing the same key. By
  now, if key is trusted, it's also imported (#282254).
- 2.15.43
* Thu Jun 28 2007 jsrain@suse.cz
- updated for live CD installation
* Fri Jun  1 2007 locilka@suse.cz
- Adjusted Add-On module to store also a "PRODUCT" tag from the
  product content file to be later used by AutoYaST cloning.
- Add-On Export uses that "autoyast_product" ("PRODUCT") instead of
  the "product" key which is used for other purposes, mostly for
  UI (#279893).
- 2.15.42
* Wed May 30 2007 lslezak@suse.cz
- do not show an installation source in the package installation
  dialog (slideshow) when there is no package to install (#277148)
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Thu May 24 2007 lslezak@suse.cz
- install 'portmap' package if installing from a NFS source
  (#277813)
- 2.15.41
* Mon May 21 2007 jsrain@suse.cz
- check if host name specified is valid (#232887)
* Thu May 17 2007 locilka@suse.cz
- Sort licenses alphabetically using an lsort instead of common
  sort builtin (#274747).
- 2.15.40
* Thu May 17 2007 lslezak@suse.cz
- Call Pkg::TargetLoad() when there is a patch provided by
  the update source to get applicable patches (#270919)
* Wed May 16 2007 locilka@suse.cz
- Fixed behavior when Add-On products are automatically added by
  list of products defined in add_on_products file. UI layer knowns
  about the products and during installation, we can remove them or
  add them again. Wizard steps are redrawn immediately after adding
  these Add-Ons (#269625).
- Function Packages::Initialize has been split into more smaller
  functions for an easier maintenance.
- 2.15.39
* Thu May 10 2007 lslezak@suse.cz
- Display "Install more packages?" question also when taboo state
  of a package is changed in the package management (#272690)
* Fri May  4 2007 lslezak@suse.cz
- close the "Initializing catalogs..." popup before opening
  another one (#269920)
- 2.15.38
* Thu May  3 2007 lslezak@suse.cz
- basic command line support for dirinstall (#269889), sw_single
  (#269908) and inst_source (#269893)
* Wed May  2 2007 lslezak@suse.cz
- inst_source - display the current alias when the table content
  is refreshed (#258776)
- 2.15.37
* Thu Apr 26 2007 lslezak@suse.cz
- use "Retry" label instead of "OK" in the media change popup
  (#264705)
* Wed Apr 25 2007 lslezak@suse.cz
- display added SLP sources in the overview table (#251182)
- preselect the choosen medium type when going back
- 2.15.36
* Wed Apr 25 2007 lslezak@suse.cz
- inst_source.ycp - display broken sources in the overview dialog
  (#265579)
- use RichText widget in the broken source popup window (make the
  message scrollable)
- 2.15.35
* Tue Apr 24 2007 lslezak@suse.cz
- fixed inverted meaning of the "Do not show again" checkbox
  (#245734)
- 2.15.34
* Mon Apr 23 2007 lslezak@suse.cz
- properly initialize desktop configuration dialog when going back
  in the installation workflow (#264295)
- the ellipsis from "Refresh Now" menu item has been removed
  (#264276)
- 2.15.33
* Fri Apr 20 2007 locilka@suse.cz
- Escaping and quoting .target.back* calls.
* Tue Apr 17 2007 locilka@suse.cz
- Initializing target in inst_rpmcopy only if some packages need
  to be installed (partly FATE #301924).
- Replacing obsolete 'find' builtins with 'regexpmatch'.
- 2.15.32
* Tue Apr 10 2007 lslezak@suse.cz
- use better heading in RPM reading popup (#261278)
- 2.15.31
* Fri Apr  6 2007 lslezak@suse.cz
- added user authentication callback - Authentication() (#190609)
- 2.15.30
* Fri Apr  6 2007 lslezak@suse.cz
- fixed missing translation mark (#252551)
* Wed Apr  4 2007 ug@suse.de
- 2.15.29
* Wed Apr  4 2007 ug@suse.de
- signature checks for individual add-ons for autoyast
* Mon Apr  2 2007 locilka@suse.cz
- Making SLP Catalog Details wider and higher. The exact dialog
  size depends on selected UI and ammount of information presented
  in table (#237337).
- 2.15.28
* Mon Apr  2 2007 lslezak@suse.cz
- Pkg::CallbackSourceCreateInit/Destroy() and
  Pkg::CallbackSourceReportInit() handlers (#251726)
- 2.15.27
* Fri Mar 30 2007 locilka@suse.cz
- Added global variable into AddOnProduct that informs installation
  whether low-memory issue has been already reported or not
  (bugzilla #239630).
* Wed Mar 28 2007 locilka@suse.cz
- Moved some testsuites from yast2-packager to yast2
- 2.15.26
* Wed Mar 28 2007 locilka@suse.cz
- Most of the AddOnProduct functionality has been made more
  abstract and moved to a new module WorkflowManager to yast2.rpm
  in order to make possible Pattern-based workflow (FATE #129).
- Adjusted RPM requierements and BuildRequires
- Adjusted testsuites
- 2.15.25
* Thu Mar 22 2007 lslezak@suse.cz
- display remaining unconfirmed licenses of selected packages
  (#242298)
- 2.15.24
* Tue Mar 20 2007 lslezak@suse.cz
- display timeout value in seconds instead of milliseconds
  (#223808)
* Tue Mar 13 2007 locilka@suse.cz
- Making AddOnProduct::RedrawWizardSteps function global to be able
  to redraw Wizard look from whereever we need.
- Directory /usr/share/YaST2/control/ owned by this package.
- 2.15.23
* Fri Mar  9 2007 locilka@suse.cz
- Adding 'unzip' into RPM dependencies because it's needed by
  ProductLicense module to unzip license.
* Fri Mar  9 2007 locilka@suse.cz
- Module InstShowInfo has been moved from yast2-installation to
  yast2-packager because this module is used by Add-Ons and
  installation sources only.
- 2.15.22
* Thu Mar  8 2007 mvidner@suse.cz
- Escape the URL properly when appending an alias before syncing with
  ZMD (#247249).
- Therefore reverted the underscore change from 2.15.16. (#248228).
- 2.15.21
* Wed Mar  7 2007 locilka@suse.cz
- Added more debugging logs for selecting XEN kernel in case of
  xen pattern selected for installation (#250131).
* Tue Mar  6 2007 locilka@suse.cz
- AddOnProduct and ProductLicense finally moved to yast2-packager
  from yast2-installation to avoid build cycles.
- 2.15.20
* Fri Mar  2 2007 lslezak@suse.cz
- add Xen paravirtual drivers to initrd if they are selected for
  installation (#241564)
- correctly test non-root partition size (#245734)
- 2.15.19
* Mon Feb 26 2007 jsrain@suse.cz
- added yast2-add-on to dependencies
- 2.15.18
* Fri Feb 23 2007 lslezak@suse.cz
- it is posible to specify HTTP/HTTP port in the source
  configuration module (#247019), removed workaround for #179424
- 2.15.17
* Wed Feb 21 2007 lslezak@suse.cz
- allow to change name (alias) of a source (#228978)
- 2.15.16
* Wed Feb 21 2007 sh@suse.de
- Renamed iconst for desktops (bug #247294):
  kde.png -> yast-kde.png,
  gnome.png -> yast-gnome.png
* Wed Feb 21 2007 lslezak@suse.cz
- replace spaces by underscore in alias when it's passed to rug
  (#247249)
- media change callback - display label "(Medium Number x)"
  for network sources (#156028)
* Mon Feb 19 2007 lslezak@suse.cz
- added Browse buttons for scanning the network in NFS source
  dialog, use Label::BrowseButton()
- fixed errors reported by check_ycp
- 2.15.15
* Mon Feb 19 2007 locilka@suse.cz
- Do not call bind mount and do not remove devs.rpm when running
  the System Update. Only remove from rpm database in that case
  (#246389).
* Mon Feb 19 2007 lslezak@suse.cz
- do not show "install more" question when the package selection
  has been aborted or the package selection has not been changed
  (#230773)
- installation source - renamed menu item ("Enable or Disable" ->
  "Status On or Off") to be consistent with the table header
  (#231225)
- do not display "CD x" medium description in the media change
  popup if the source is a network source (#156028)
* Fri Feb 16 2007 lslezak@suse.cz
- Replace the middle part of a long URL/file name by ellipsis
  to display the most interesting part of the message in
  the progress popup (#221163)
- 2.15.14
* Thu Feb 15 2007 locilka@suse.cz
- Disabling removing information about installed patches
  (FATE #301990, Bugzilla #238488).
- 2.15.13
* Thu Feb 15 2007 lslezak@suse.cz
- handlers for ScanDB callbacks (RPM DB reading) (#219953)
- 2.15.12
* Tue Feb 13 2007 locilka@suse.cz
- Calling bind mount and removing devs.rpm only in case of upgrade
  (#244937).
- 2.15.11
* Mon Feb 12 2007 lslezak@suse.cz
- Fixed AcceptUnknownGpgKey() and TrustGpgKey() GPG callback
  handlers (#242087, #240771)
- 2.15.10
* Fri Feb  9 2007 lslezak@suse.cz
- ignore mounted sources in SpaceCalculation::EvaluateFreeSpace()
  (#221308)
- use 'Unsigned Package/File' heading in the callback for
  handling unsigned files/packages (#171105)
- removed dependency on yast2-storage (#238673)
- 2.15.9
* Wed Feb  7 2007 locilka@suse.cz
- Removing devs.rpm in case of update before installation starts.
- Bind-mounting the current instsys:/dev/ to installedsys:/dev/.
  Both requested in feature #301903.
* Wed Feb  7 2007 lslezak@suse.cz
- slideshow - enable Abort button and reset abort status when
  the slideshow is started again ('install more packages' has
  been accepted) (#226041)
* Tue Feb  6 2007 lslezak@suse.cz
- inst_source - display the alias in the overview if the product
  is not known (#241032)
- callbacks - close download popup and source progress popup if
  an error occurrs (#216950)
- 2.15.8
* Mon Feb  5 2007 lslezak@suse.cz
- dirinstall - properly initialize Slideshow module, supress
  an invalid warning during initialization (#187352)
- slideshow - display sw_single icon in the dialog
- 2.15.7
* Fri Feb  2 2007 locilka@suse.cz
- Separating SLP-related functions to the SourceManagerSLP module.
- Creating new add_inst_source_slptype client.
- Handling not installed yast2-slp package in inst_source client.
- All to make system without yast2-slp package installed possible
  (#238680).
* Thu Feb  1 2007 lslezak@suse.cz
- inst_source - "Synchronize with ZENworks" setting is persistent
  now (#230727)
- dirinstall - recheck disk space when the target directory
  is changed (#224150), properly initialize partitioning
  (use the mount points only below the target)
- dirinstall - display a progress dialog at start/finish
* Wed Jan 31 2007 lslezak@suse.cz
- inst_source: disable autorefresh for a new ISO image based
  source (#223585)
- inst_source: merged "Package Directory" into "Local Directory",
  added "Local ISO Image" source type (#204943)
- fixed checkmedia test in the first installation stage (#238670)
- 2.15.6
* Fri Jan 26 2007 lslezak@suse.cz
- inst_source - validate the entered path, added ISO image check
  (#224797)
* Fri Jan 26 2007 lslezak@suse.cz
- removed obsolete module PackageSelectionIO.ycp (reading/writing
  of the current package selection is implemented in UI)
- removed Packages::languagePackages() - yast2-trans-* packages are
  selected by the solver
- use new Pkg::*Locale functions, do not install language packages
  when yast2 -i is invoked in another locale (#223624)
- 2.15.5
* Thu Jan 25 2007 lslezak@suse.cz
- improved the disk space check - compute disk usage of a packge
  for the current partitioning (#222556), ignore read-only
  partitions (#211735)
- install 'checkmedia' package in run time, removed RPM
  dependency (#238670)
- 2.15.4
* Fri Jan 19 2007 kmachalkova@suse.cz
-  Make MediaChange dialog more readable in text-mode (#222602)
* Wed Jan 17 2007 lslezak@suse.cz
- show the pattern selection dialog when doing update in a running
  system (#229951)
* Fri Jan 12 2007 lslezak@suse.cz
- use "label" in the installation proposal dialog and in
  the source summary dialog (#231521)
- 2.15.3
* Thu Dec 14 2006 lslezak@suse.cz
- use "Skip" button instead of "Ignore" in the download error
  popup (#228370)
- inst_source: display complete URL dialog when the http source
  URL has a port specified (#179424)
* Thu Dec 14 2006 lslezak@suse.cz
- do not display full path to a package in the installation popup
- free size warning: prepend '/' to a partition name if it
  does not begin with '/'
* Wed Dec 13 2006 lslezak@suse.cz
- display the correct error description in the error popup when
  a download fails (#228178)
- 2.15.2
* Tue Dec 12 2006 locilka@suse.cz
- Desktop selection dialog doesn't use [Select] button anymore.
  Other options are solved by another hidden radio-buttons
  (#202132).
* Thu Dec  7 2006 lslezak@suse.cz
- inst_source: `restart_menu is not needed anymore (#148683)
* Wed Dec  6 2006 lslezak@suse.cz
- inst_source: removed extra UI::CloseDialog() call (#224944),
  check number of arguments
- 2.15.1
* Mon Dec  4 2006 locilka@suse.cz
- Wider text entry for filter form in SLP sources.
* Wed Nov 29 2006 lslezak@suse.cz
- split the long label to more lines (#215340)
* Wed Nov 29 2006 lslezak@suse.cz
- use Report::LongError(), the error message might be very long
  (esp. important in ncurses UI) (#222893)
- do not install "mol" and "sudo" on ppc (#222906)
- install "xen-tools" in a Xen VM (required for registration)
  (#223643)
- 2.15.0
* Wed Nov 22 2006 lslezak@suse.cz
- removed the workaround for #202088 (target is reloaded
  automaticaly, removed the unnecessary reload)
- show the GPG key name in the trust key dialog (#223170)
- fixed initialization for YUM sources in slideshow, show output
  for a YUM source (medium number 0 is allowed) (#220242)
- 2.14.10
* Wed Nov 22 2006 lslezak@suse.cz
- installation source: make the input widgets wider (#222548)
- package selection: do not use dropped PPC packages (#222909)
- 2.14.9
* Tue Nov 21 2006 mvidner@suse.cz
- Implemented sw_single --remove and sw_single --update (#222757).
  (Called by yast2-2.14.14)
- Say "Synchronizing with ZENworks" instead of "Initializing Catalogs"
  when doing so after the first reboot (#221250).
- 2.14.8
* Mon Nov 20 2006 lslezak@suse.cz
- if the installation source is SMB/CIFS share then install
  'cifs-mount' package to mount the source later; check whether
  the package is installed when creating a SMB/CIFS source at
  run-time (#220921)
- fixed copy&paste typo in PackageCallbacks::SetScriptCallbacks()
  and CleartScriptCallbacks() functions
- 2.14.7
* Mon Nov 13 2006 lslezak@suse.cz
- add a local directory as an installation source (support for
  "Plaindir" source type) (#168358)
- 2.14.6
* Mon Nov 13 2006 locilka@suse.cz
- Removing information about applied patches and used selections
  during update (#210552).
- Added dependency on yast2-pkg-bindings >= 2.14.0
* Mon Nov 13 2006 mvidner@suse.cz
- ZENworks sync: delete disabled sources, add enabled ones (#182992).
  Also during system upgrade (#219414).
- Do not try to sync with ZENworks if there have been no changes (#217697).
* Fri Nov 10 2006 locilka@suse.cz
- Fixed 'fixed' SLP attribute scanning - key "ip" contains IP of
  server which sent the information about SLP service, not "pcHost"
- Removed /usr/bin/host call which is not needed anymore again
  (used for converting "pcHost" to "ip").
- Services with no label are now correctly listed as a root-tree
  items instead of listing under one tree-item with empty label.
- All changes fixed according to bugzilla #219759.
- One more UI::CloseDialog() call in inst_source client.
* Thu Nov  9 2006 lslezak@suse.cz
- install packages for additional languages (invalidate
  the software proposal cache when the language selection has
  been changed) (#218769)
- 2.14.5
* Thu Nov  9 2006 lslezak@suse.cz
- sw_single: do not install the UI language when it already has
  been installed (#206076), do not refresh target when no change
  has been done (#219330)
- 2.14.4
* Wed Nov  8 2006 lslezak@suse.cz
- installation source: split directory name from host name
  (#211522), refresh "User" and "Password" widget status when
  scheme is changed
- callbacks: return correct ignore value in the command line mode
- 2.14.3
* Mon Nov  6 2006 lslezak@suse.cz
- fixed the default button in the SLP source selection dialog
  (#214924)
- allow to enter more character in the filter widget (#216277)
- fixed SLP attribute scanning
- 2.14.2
* Wed Nov  1 2006 mvidner@suse.cz
- Ask the user for confirmation before removing broken installation
  sources. The failure may be permanent (source is gone) or temporary
  (network is down, proxy problem) (#210514).
- 2.14.1
* Mon Oct 30 2006 lslezak@suse.cz
- do not show hidden patterns in the installation proposal
- 2.14.0
* Mon Oct 30 2006 locilka@suse.cz
- Moving ProductFeatures::Save() to save_config_finish.ycp
  (bugzilla #209119).
- Create SourceManager::InstallationSourceOnPartition function that
  returns the disk partition used as installation source (if any).
- Calling Storage::RemoveDmMapsTo (device) in the begining of
  inst_rpmcopy (#208222).
- Fixed include path for packager (/packager).
- Added RPM dependency on yast2-rpm.
* Tue Oct 24 2006 mvidner@suse.cz
- If ZMD is not installed, do not complain about not being able
  to start it (#214588).
- 2.13.158
* Tue Oct 24 2006 lslezak@suse.cz
- Fixed SourceProgressCallback() return value (do not abort)
  (#213628)
- 2.13.157
* Mon Oct 23 2006 mvidner@suse.cz
- Added a checkbox Synchronize Changes with ZENworks to make the
  undocumented feature "yast2 inst_source norug" more visible.
- Added a popup while doing the sync (#201453).
- 2.13.156
* Fri Oct 20 2006 lslezak@suse.cz
- handle Ignore button properly when a download fails, do not
  abort installation (#200084)
- 2.13.155
* Thu Oct 19 2006 lslezak@suse.cz
- dirinstall - quote directory name, it can contain spaces
  (locilka@suse.cz) (bug #211576)
- 2.13.154
* Mon Oct 16 2006 lslezak@suse.cz
- script callbacks - installation and run-time (feature #100233)
- 2.13.153
* Mon Oct 16 2006 locilka@suse.cz
- Window listing found SLP sources in ncurses is newly based on the
  currently available space (#209426).
* Wed Sep 27 2006 locilka@suse.cz
- YCP modules that originated in yast2-packager and had been in
  yast2-installation were moved back to yast2-packager. Done in
  installation version 2.13.155.
- Removed yast2-installation and yast2-firewall from build
  requirements.
- 2.13.152
* Mon Sep 25 2006 jsrain@suse.cz
- fixed incorrect casting string to symbol (#204814)
* Fri Sep 22 2006 lslezak@suse.cz
- callback handler - close the error popup window (#206953)
- reinitialize the package manager after installation
  (temporary workaround for #201121, #202088)
- 2.13.151
* Wed Sep 20 2006 lslezak@suse.cz
- checkmedia - show output in a richtext widget, fixed labels
  (feature #422), adapted to chages in 'checkmedia' output
- 2.13.150
* Mon Sep 18 2006 lslezak@suse.cz
- handlers for the new source callbacks (feature #1466), requires
  yast2-pkg-bindings >= 2.13.95
- 2.13.149
* Wed Sep  6 2006 lslezak@suse.cz
- print a warning in the installation proposal if there is
  a partition with too low free space (#179953)
- don't run the solver after selecting a Xen kernel, run it just
  once when creating the proposal
- evaluate the package selection only once in the installation
  proposal, cache the software proposal and evaluate the package
  selection only when it's necessary (feature #300709)
- 2.13.148
* Mon Sep  4 2006 lslezak@suse.cz
- install all packages in the first stage if it's possible
  (feature #3425, bugzilla #103800)
- 2.13.147
* Fri Aug 18 2006 jsrain@suse.cz
- syntax fix
- 2.13.146
* Thu Aug 17 2006 jsrain@suse.cz
- added callbacks for patch/delta RPMs
- 2.13.145
* Wed Aug  9 2006 jsrain@suse.cz
- select packages also according to architecture and version for
  2nd stage of installation (#186912)
* Tue Aug  8 2006 jsrain@suse.cz
- updated KDE blurb in desktop selection dialog (#144612)
* Mon Aug  7 2006 jsrain@suse.cz
- add possibility to change order of sources (#190069)
- updated texts in slideshow log (#177502)
- 2.13.144
* Fri Aug  4 2006 jsrain@suse.cz
- optimized the source management dialog (#190069)
- updated help texts
- 2.13.143
* Tue Aug  1 2006 jsrain@suse.cz
- removed Up/Down buttons from inst_source dialog (#190069)
* Wed Jul 26 2006 jsrain@suse.cz
- provide earlier feedback for sw_single (jsuchome)
- remove blank spaces from host name (if accidentally entered)
  (#176762)
- 2.13.142
* Mon Jul 24 2006 jsrain@suse.cz
- remove bold highlight in help text (#179420)
- allow to abort installation if CD1 not in the drive (#167674)
- report proper message if no catalog found via SLP and firewall
  is running (#156444)
* Sun Jul 16 2006 olh@suse.de
- introduce a Linuxrc::display_ip and use it instead of Arch::s390
- 2.13.141
* Mon Jul 10 2006 jsrain@suse.cz
- clean-up of selection related stuff
- 2.13.140
* Thu Jun 29 2006 jsrain@suse.cz
- optimized source dialogs (#179447)
- import Storage later to prevent early run of construcor
* Mon Jun 26 2006 jsrain@suse.cz
- preselect patterns according to selected desktop (#183944)
* Thu Jun 22 2006 jsuchome@suse.cz
- do not clear directory entry when Anonymous is (un)checked (#186849)
- 2.13.139
* Tue Jun 20 2006 jsrain@suse.cz
- abort installation completly if package installation aborted
  (#186660)
- 2.13.138
* Mon Jun 19 2006 jsrain@suse.cz
- ask about add-on product license if add-on product was used as
  bootable medium (#186148)
- 2.13.137
* Tue Jun 13 2006 ug@suse.de
- a warning popups breaks autoinstallation (#184349)
- 2.13.136
* Mon Jun 12 2006 mvidner@suse.cz
- Respect /etc/sysconfig/security:CHECK_SIGNATURES in callbacks.
- 2.13.135
* Mon Jun 12 2006 jsrain@suse.cz
- ask user to confirm a license if product added via the
  inst_source module (#183733)
- 2.13.134
* Fri Jun  9 2006 jsrain@suse.cz
- handle list of all resolvables needed to be selected in 2nd stage
  of the installation (#181198)
- 2.13.133
* Thu Jun  8 2006 schubi@suse.de
- Selecting product in the init of Packages.ycp ( only autoyast mode)
  Bug 178831
* Wed Jun  7 2006 jsuchome@suse.cz
- show detailed error message when adding of source failed (#182462)
- 2.13.131
* Tue Jun  6 2006 mvidner@suse.cz
- Moved SourceManager + deps from yast2-packager to yast2-installation
  to avoid circular BuildRequires.
- 2.13.130
* Tue Jun  6 2006 mvidner@suse.cz
- Moved the major part of Register::add_update_sources to
  SourceManager::AddUpdateSources.
- In SourceManager::AddUpdateSources, also tell rug
  which zypp/yum sources it should add. This enables
  rejecting broken or untrusted sources (#180820).
- 2.13.129
* Tue Jun  6 2006 jsrain@suse.cz
- do not report error if slideshow missing on the media (#182008)
- 2.13.128
* Tue Jun  6 2006 mvidner@suse.cz
- Source synchronization: call rug with --quiet (#179080).
  Enable aborting the sync. Increase logging.
- 2.13.127
* Mon Jun  5 2006 jsrain@suse.cz
- do not call Pkg::PkgCommit (9999) in first stage (#181195)
- 2.13.126
* Fri Jun  2 2006 lslezak@suse.cz
- run the solver after selecting a Xen kernel (#178306)
- fixes in SourceManager module (nil check, infinite loops)
- 2.13.125
* Fri Jun  2 2006 jsrain@suse.cz
- log Report messages by default (bug 180862)
- 2.13.124
* Thu Jun  1 2006 jsrain@suse.cz
- initialize package callbacks earlier to allow install from
  incorrectly signed installation source (#179567)
- 2.13.123
* Wed May 31 2006 locilka@suse.cz
- Adding simple editor for viewing and removing "Do Not Show Again"
  entries from the current configuration.
- Correcting function that removes these entries inside the
  DontShowAgain module.
* Tue May 30 2006 jsrain@suse.cz
- fixed installation into directory (preselect patterns, don't ask
  about base selection if pattern-based installation) (#177917)
- 2.13.122
* Tue May 30 2006 locilka@suse.cz
- Reimplementing the "Do Not Show Again" popups to store this flag
  permanently. It stores URL + dialog type + default return
  value (#175845).
- 2.13.121
* Thu May 25 2006 mvidner@suse.cz
- Use Pkg::SourceSaveAll which always saves even if no sources are
  enabled (#176013).
- 2.13.120
* Wed May 24 2006 jsrain@suse.cz
- properly integrate YCP code for add-on product installation if
  add-on product media booted (if YCP code present) (#178311)
- 2.13.119
* Fri May 19 2006 jsrain@suse.cz
- store ProductFeatures before starting package installation
  (#176993)
- 2.13.118
* Wed May 17 2006 jsrain@suse.cz
- decode %%2f from FTP path from install.inf (#169310)
- 2.13.117
* Tue May 16 2006 jsrain@suse.cz
- don't use patterns required by product during autoinstallation
  (#159466)
- 2.13.116
* Tue May 16 2006 jsrain@suse.cz
- fixed selecting XEN kernel (normal vs. PAE) (#173593)
- fixed help text to make xgettext extract it (#175930)
- 2.13.115
* Fri May 12 2006 mvidner@suse.cz
- Before synchronizing sources with ZenWorks, check whether we are in
  sync already (#168740, #175174).
- When syncing source changes to ZenWorks, first delete and then add,
  otherwise replacing a source with itself breaks (#175159).
- Removed dead code, fixed the (unused) return value.
- "yast2 inst_source norug" will not try to sync with ZenWorks (#175173).
- 2.13.114
* Thu May 11 2006 jsrain@suse.cz
- disable automatic modprobe just before starting copying the
  RPM packages (#172149)
- 2.13.113
* Thu May 11 2006 jsrain@suse.cz
- preselect patterns specified in the content file (#168297)
- 2.13.112
* Wed May 10 2006 lslezak@suse.cz
- dirinstall - deselect the previous selection when the selection
  is changed (#166962)
- 2.13.111
* Tue May  9 2006 jsrain@suse.cz
- properly select newer version of packages if service pack is
  added (#172271)
- 2.13.110
* Tue May  9 2006 jsrain@suse.cz
- preselect relevant packages for X11 installation (#168056)
- 2.13.109
* Thu May  4 2006 locilka@suse.cz
- Merged text from proofreading
- 2.13.108
* Tue May  2 2006 locilka@suse.cz
- Allways install from all media when Packages::metadir_used is set
  to true. This adds the missing functionality to the previous fix.
- 2.13.107
* Tue May  2 2006 locilka@suse.cz
- Splitting inst_rpmcopy source code into smaller functions
- Calling first stage installation packages commit limited to first
  media, unlimited in other cases (such as second stage
  installation) (#170079)
- 2.13.106
* Tue May  2 2006 mvidner@suse.cz
- Reverted the redirection, ag_background will be changed instead
  (#169648#c39).
* Tue May  2 2006 mvidner@suse.cz
- Redirect rug stdout to null because it can block (#169648).
- Sometimes rug ping gives the exit code 0xff_ffff_ffff_ffff so
  declare success if stderr is empty (#170549).
- 2.13.105
* Fri Apr 28 2006 jsuchome@suse.cz
- show reasonable error message when rug fails
- 2.13.104
* Thu Apr 27 2006 mvidner@suse.cz
- Tell libzypp-zmd-backend not to write sources to zypp db,
  we are going to do it ourselves (#170113).
- 2.13.103
* Thu Apr 27 2006 locilka@suse.cz
- Do not create the /etc/mdadm.conf file when it is not needed
  or when the file already exists (during inst-update) (#169710)
- 2.13.102
* Thu Apr 27 2006 lslezak@suse.cz
- dirinstall - create /dev/null and /dev/zero devices in
  the target directory (some packages require them in the
  postinstall script) (#158476)
- dirinstall - updated the list of disabled services, do not
  modify /etc/inittab - it's not needed for a Xen guest
  installation
- 2.13.101
* Wed Apr 26 2006 jsrain@suse.de
- fixed setting language adter package manager reset (#162064)
- 2.13.100
* Wed Apr 26 2006 mvidner@suse.cz
- Detect source manager init failure and tell the user why the package
  management is going to exit (#166278).
- 2.13.99
* Wed Apr 26 2006 lslezak@suse.cz
- display removed packages during system update (#167957)
- 2.13.98
* Tue Apr 25 2006 jsrain@suse.de
- fixed checking of add_on_products on CD1
* Tue Apr 25 2006 mvidner@suse.cz
- Rug and zmd timeout should not be necessary having fixed #165821,
  but 2 minutes is too short. Increasing it to 30 min everywhere just
  to be safe (#165753).
- 2.13.97
* Tue Apr 25 2006 locilka@suse.cz
- Improved GnuPG dialogs for changed zypp and pkg-bindings
  to display the full URL and not to break visibility.
- Adding Progress popup information when syncing ZMD/YaST sources
  (#168742)
- 2.13.96
* Mon Apr 24 2006 mvidner@suse.cz
- Always tell rug that zypp owns the source (#168739).
- 2.13.95
* Mon Apr 24 2006 locilka@suse.cz
- modified help texts for importing GnuPG keys to make removing
  the [Details...] button possible. Leaving the old ones unchanged.
- splitting displayed fingerprint with space after every 4th
  character
* Fri Apr 21 2006 jsrain@suse.de
- create 1st source as source containing base product (#160585)
- 2.13.93
* Thu Apr 20 2006 mvidner@suse.cz
- The separator for URL query parameters is '&', not ';' (#168030).
- 2.13.92
* Thu Apr 20 2006 locilka@suse.cz
- GnuPG dialogs enhanced with optional fingeprint parameter,
  dialogs should handle both defined and undefined one (#167519).
- 2.13.91
* Wed Apr 19 2006 jsuchome@suse.cz
- after finishing sources configuration, restart menu.ycp (#162966)
- 2.13.90
* Wed Apr 19 2006 mvidner@suse.cz
- Fixed a false timeout when calling rug (#165821).
- Really increased the rug timeout (#165145#c11).
- 2.13.89
* Tue Apr 18 2006 jsrain@suse.de
- inform in the log that installation was aborted (#157322)
- 2.13.88
* Tue Apr 18 2006 jsrain@suse.de
- provide function to install add-on products specified on medium
* Tue Apr 18 2006 sh@suse.de
- Fixed bug #164869: No dependency check in pattern selector
  due to duplicated "Accept" button
- V 2.13.87
* Tue Apr 18 2006 lslezak@suse.cz
- allow system update although there is not enough free space
  (#158785)
- 2.13.86
* Tue Apr 18 2006 lslezak@suse.cz
- DirInstall - don't initialize the sources in the constructor,
  install the package callbacks in the dirinstall mode (#167281)
- 2.13.85
* Fri Apr 14 2006 jsrain@suse.de
- reverted displaying selected patterns in simple proposal (#162281)
- 2.13.84
* Fri Apr 14 2006 mvidner@suse.cz
- Detect failure when creating the installation source (#166210).
- 2.13.83
* Thu Apr 13 2006 jsrain@suse.de
- allow to repartition disk if too much software selected (#163316)
- 2.13.82
* Wed Apr 12 2006 jsuchome@suse.cz
- enable editing iso sources
- do not add more slashes when concatenating server and directory
  for non-ftp source url (#163791)
- 2.13.81
* Wed Apr 12 2006 locilka@suse.cz
- Correct handling of copying slides to the local directory when no
  slides found on the source.
* Wed Apr 12 2006 jsuchome@suse.cz
- enable saving the sources if rug reports errors (#165478)
- 2.13.80
* Wed Apr 12 2006 locilka@suse.cz
- Merged text from proofreading
* Wed Apr 12 2006 mvidner@suse.cz
- Increased the timeout for ZMD source syncing to 30 minutes (#165145).
- 2.13.79
* Tue Apr 11 2006 jsrain@suse.de
- display selected patterns in simple proposal (#162281)
* Tue Apr 11 2006 jsrain@suse.de
- select laptop pattern on laptops (#165155)
- 2.13.78
* Tue Apr 11 2006 locilka@suse.cz
- Increasing time-out for calling 'rug' from 60 to 120 secs.
- 2.13.76
* Tue Apr 11 2006 locilka@suse.cz
- Added function for callback Pkg::CallbackAcceptFileWithoutChecksum()
- 2.13.75
* Mon Apr 10 2006 locilka@suse.cz
- Hide password when reporting the URL for failed adding add-on
  product (#164881).
- 2.13.74
* Mon Apr 10 2006 visnov@suse.cz
- adapt slideshow for new pkg-bindings API (#161298)
- 2.13.73
* Fri Apr  7 2006 lslezak@suse.cz
- display a warning when Pkg::SourceStartCache fails (#163267)
- 2.13.72
* Fri Apr  7 2006 jsuchome@suse.cz
- import gpg keys before creating source (#164001)
- 2.13.71
* Fri Apr  7 2006 kkaempf@suse.de
- call rug with source type 'zypp' instead of 'yast'.
- 2.13.70
* Fri Apr  7 2006 locilka@suse.cz
- Disabling [Details...] button in ImportGPGKeyDialogs when no
  details are available.
* Thu Apr  6 2006 mvidner@suse.cz
- Only add the alias parameter to rug sa for --type=ZYPP (#164083).
- 2.13.69
* Thu Apr  6 2006 jsrain@suse.de
- do not display hidden patterns in proposal (#159450)
* Thu Apr  6 2006 mvidner@suse.cz
- Use Pkg::SourceGeneralData["type"] for rug sa, do not hardcode "zypp".
* Thu Apr  6 2006 lslezak@suse.cz
- increased minimum free size for update (from 2%% to 5%%) (#163197)
- 2.13.68
* Thu Apr  6 2006 visnov@suse.cz
- delete broken sources if they cannot be restored (#157100)
- 2.13.67
* Thu Apr  6 2006 locilka@suse.cz
- Adding Do_not_show_this_dialog_again functionality into some
  SignatureCheckDialogs.
* Wed Apr  5 2006 jsrain@suse.de
- call Pkg::PkgFreshen in proposal (#156980)
- 2.13.65
* Wed Apr  5 2006 jsrain@suse.de
- do not preselect X11 packages if not running VNC installation
  (#163201)
- 2.13.64
* Wed Apr  5 2006 mvidner@suse.cz
- Call SourceManager::SyncYaSTInstSourceWithZMD () in
  inst_rpmcopy(continue) because inst_suse_register does not run
  without a network connection (#156030#c30).
- Do not sync if rug not present.
- Report rug errors to the user.
- Delete sources only after we do not need their data for syncing.
- 2.13.63
* Wed Apr  5 2006 mvidner@suse.cz
- Added SourceManager::SyncAddedAndDeleted and calling it from
  inst_source (#156030#c29).
- 2.13.62
* Wed Apr  5 2006 locilka@suse.cz
- Some new texts and dialogs for SignatureCheckDialogs
- New functions for Pkg:: callbacks:
  - CallbackAcceptUnsignedFile
  - CallbackAcceptUnknownGpgKey
  - CallbackImportGpgKey
  - CallbackAcceptVerificationFailed
  - CallbackTrustedKeyAdded
  - CallbackTrustedKeyRemoved
- 2.13.61
* Wed Apr  5 2006 visnov@suse.cz
- Show the type of the source in installation sources module if needed
- 2.13.60
* Tue Apr  4 2006 jsrain@suse.de
- fixed servicepack.tgz integration
- added support for loopback mounted ISO (#159565)
- 2.13.59
* Tue Apr  4 2006 mvidner@suse.cz
- Call rug sa for all known installation sources,
  using the URL+alias instead of /installation (#156030).
- 2.13.58
* Tue Apr  4 2006 locilka@suse.cz
- Added initial Signatures-Handling callbacks (#162858)
- 2.13.57
* Thu Mar 30 2006 mvidner@suse.cz
- Don't run the modules if another process has the zypp lock (#160319).
- 2.13.56
* Wed Mar 29 2006 locilka@suse.cz
- Enhanced texts in SignatureCheckDialogs module
* Wed Mar 29 2006 locilka@suse.cz
- Merged proofread texts for SignatureCheckDialogs
- Adjusted dialogs for SignatureCheckDialogs to show informative
  icons/images (warning/error/question).
- Improved SignatureCheckDialogs UI
- Stopping ZMD after the Sync is done when is wasn't running before
  (#161279)
- 2.13.55
* Wed Mar 29 2006 locilka@suse.cz
- Moving ZMD sync from pkg_finish to SourceManager module (#161279)
* Tue Mar 28 2006 locilka@suse.cz
- Added the first implementation of SignatureCheckDialogs module.
- 2.13.54
* Tue Mar 28 2006 visnov@suse.cz
- Show type of installation source if name is not known
* Tue Mar 28 2006 locilka@suse.cz
- Moving ZMD sync to the pkg_finish client that is called after the
  switch_scr client (#161299).
* Tue Mar 28 2006 visnov@suse.cz
- fix slideshow in 1st stage (#154324)
- 2.13.53
* Mon Mar 27 2006 locilka@suse.cz
- YaST installation source is added into ZMD after the installation
  or update at the end of the inst_rpmcopy client. It checks the
  ZMD status and starts it if isn't running. Then it adds the
  'ZYPP' service if such service is not listed and activates it
  (#156030).
- 2.13.52
* Wed Mar 22 2006 locilka@suse.cz
- release media before asked for another (partly fixes #159754)
- 2.13.51
* Tue Mar 21 2006 lslezak@suse.cz
- 2.13.50
* Tue Mar 21 2006 lslezak@suse.cz
- don't show /dev and /media filesystems in disk usage overview
  at update, properly report disk usage (#159517)
* Tue Mar 21 2006 visnov@suse.cz
- Show also errors from ZYPP why sources cannot be restored (#157880)
* Tue Mar 21 2006 visnov@suse.cz
- Lookup the add_on_products file as optional (#159116)
- V 2.13.49
* Mon Mar 20 2006 sh@suse.de
- V 2.13.48
- Fixed bug #154872: Pkg names truncated at "-"
* Mon Mar 20 2006 locilka@suse.cz
- proper handling with data returned from Pkg::TargetGetDU()
  boolean -> integer (#159463)
* Thu Mar 16 2006 jsrain@suse.de
- provide function to initialize installation sources with
  visual feedback
- 2.13.47
* Thu Mar 16 2006 locilka@suse.cz
- better handling of 'yast2 -i $param', if the $param points to the
  file which exists and is bigger than 0, it's parsed, else it is
  handled as the package-name (#158226)
* Wed Mar 15 2006 jsrain@suse.de
- select proper desktop during installation (#155095)
* Wed Mar 15 2006 schubi@suse.de
- removed "taring" of the rpm-DB. We will mentioned it in the release notes
* Tue Mar 14 2006 jsrain@suse.de
- do not call PkgCommit if there are no packages left (#156365)
- 2.13.46
* Tue Mar 14 2006 schubi@suse.de
- tar does not support bzip2 in the inst-sys
* Tue Mar 14 2006 visnov@suse.cz
- disable sources on the target system for upgrade (#154850)
- 2.13.44
* Mon Mar 13 2006 jsrain@suse.de
- do not report void error during installation after reboot
- fixed encodign the URL options (#155428)
- 2.13.43
* Mon Mar 13 2006 visnov@suse.cz
- backup old RPM database for testing
- 2.13.42
* Fri Mar 10 2006 lslezak@suse.cz
- 2.13.41
* Fri Mar 10 2006 lslezak@suse.cz
- merged proofread texts
* Fri Mar 10 2006 lslezak@suse.cz
- fixed disk usage summary in update proposal (total installation
  size was 1024x greater) (#156382)
* Fri Mar 10 2006 visnov@suse.cz
- fix packageprovide callback signature (#155016)
* Fri Mar 10 2006 lslezak@suse.cz
- dirinstall - initialize the package manager (#152311)
* Wed Mar  8 2006 jsrain@suse.de
- report if selecting package during 2nd stage installation fails
  (#155471)
* Wed Mar  8 2006 jsrain@suse.de
- fixed automatical inserting of system packages even if they were
  removed before (#155819)
- 2.13.40
* Wed Mar  8 2006 jsrain@suse.de
- correctly encode the URL (#155428)
* Mon Mar  6 2006 lslezak@suse.cz
- display correct installation size (#154296)
- 2.13.39
* Fri Mar  3 2006 jsrain@suse.de
- check whether correct media is in drive when initializing package
  maneger (#154344)
- 2.13.38
* Fri Mar  3 2006 jsrain@suse.de
- use target system as download area (#151862)
* Thu Mar  2 2006 jsrain@suse.de
- keep selected products on package manager reset (#154631)
- 2.13.37
* Thu Mar  2 2006 visnov@suse.cz
- fix ProvidePackage callback signatures
* Wed Mar  1 2006 jsrain@suse.de
- correctly display pattern summary in proposal (#153713)
* Tue Feb 28 2006 jsrain@suse.de
- added more checking for laptop (#151813)
- 2.13.36
* Mon Feb 27 2006 jsrain@suse.de
- removed order/instorder file handling
- fixed setting default desktop according to destop dialog (#152709)
- 2.13.35
* Fri Feb 24 2006 jsuchome@suse.cz
- added dialogs for ISO installation source
- 2.13.34
* Thu Feb 23 2006 jsrain@suse.de
- add support for patterns to proposal routines
- 2.13.33
* Wed Feb 22 2006 jsrain@suse.de
- updated BuildRequires
- do not reset selection if running out of disk space (#148658)
- 2.13.32
* Tue Feb 21 2006 jsrain@suse.de
- fixed displaying add-on selections (#152332)
- 2.13.31
* Tue Feb 21 2006 kkaempf@suse.de
- append "filesytem" modifier with "&" instead of ";" (#152017)
- V 2.13.30
* Mon Feb 20 2006 visnov@suse.cz
- Properly detect laptop (#158813)
- Improve handling of installation sources (#150237)
- V 2.13.29
* Fri Feb 17 2006 visnov@suse.cz
- properly report package removal problems
- V 2.13.28
* Thu Feb 16 2006 visnov@suse.cz
- don't show non-remote files as a downloaded ones
* Wed Feb 15 2006 jsrain@suse.de
- create /etc/mdadm.conf on update (#146304)
- 2.13.27
* Wed Feb 15 2006 visnov@suse.cz
- V 2.13.26
* Tue Feb 14 2006 visnov@suse.cz
- susetags source type identifier is "YaST" (#150237)
* Tue Feb 14 2006 visnov@suse.cz
- store persistently the sources in inst_source (#150237)
- fix store removal (#150237)
- V 2.13.25
* Tue Feb 14 2006 visnov@suse.cz
- adapt testsuite a bit more
- V 2.13.24
* Mon Feb 13 2006 kkaempf@suse.de
- adapt testcase to changed url behaviour
- V 2.13.23
* Mon Feb 13 2006 kkaempf@suse.de
- switch from "path param" to "query param" in URLs passed to
  the media backend (#150230)
- V 2.13.22
* Mon Feb 13 2006 sh@suse.de
- V 2.13.21
- Applied olh's patch to reduce warnign logging
* Tue Feb  7 2006 visnov@suse.cz
- close the package eval progress dialog later
- adapt Slideshow for ZYPP
- V 2.13.20
* Sun Feb  5 2006 olh@suse.de
- powerpc-utils is now pulled in via Requires in lilo
* Wed Feb  1 2006 sh@suse.de
- Now using patterns selection during installation
  (user can go to detailed software selection with "Details" button
- V 2.13.19
* Tue Jan 31 2006 jsrain@suse.cz
- add function to set packages to be selected prior to installation
  proposal (needed for iSCSI)
- 2.13.18
* Wed Jan 25 2006 olh@suse.de
- ppc64-utils -> powerpc-utils (#144758)
* Mon Jan 23 2006 jsrain@suse.cz
- merged texts from proofread
- renamed installation sources to catalogs
- 2.13.17
* Tue Jan  3 2006 visnov@suse.cz
- Added base selection selection client
- 2.13.16
* Wed Dec 21 2005 visnov@suse.cz
- Merged proofread texts
* Tue Dec 20 2005 sh@suse.de
- Fixed bug #65913: inst_rpmcopy / slide show needs reinit() call
- V 2.13.15
* Fri Dec 16 2005 jsrain@suse.cz
- removed call of obsolete script gnome-preinstall
- 2.13.14
* Fri Dec  2 2005 jsrain@suse.cz
- do not report that source refresh was skipped if user skipped
  it via pressing a button (#133811)
- report more information about source if refresh fails (#133811)
* Mon Nov 28 2005 jsrain@suse.cz
- display GNOME as the first desktop (#132491)
- 2.13.13
* Mon Nov 28 2005 visnov@suse.cz
- adding of SLP installation source
* Tue Nov 22 2005 jsrain@suse.cz
- showing better popup during package download and installation
- set default desktop according to control file
- 2.13.12
* Tue Nov 15 2005 ug@suse.de
- don't overwrite additionalLocales in autoinstallation
- 2.13.11
* Tue Nov  8 2005 lslezak@suse.cz
- URL escaping moved to URL.ycp
- 2.13.10
* Wed Nov  2 2005 lslezak@suse.cz
- command line mode support in the error callbacks (#131746)
- 2.13.9
* Tue Nov  1 2005 jsrain@suse.cz
- added support for HTTPS installation source (#130710)
- do not ask about desktop during installation if base selection
  is fixed in the control file
- renamed inst_desktop_new.ycp to inst_destkop.ycp
- 2.13.8
* Mon Oct 31 2005 jsrain@suse.cz
- fixed copying GPG keys from installation media during
  installation (#130579)
* Mon Oct 24 2005 lslezak@suse.cz
- installation source module can be closed by window
  manager (#118233)
* Mon Oct 24 2005 lslezak@suse.cz
- reimplemented callbacks for the command line mode (#91033)
- 2.13.7
* Tue Oct 18 2005 jsrain@suse.cz
- don't allow to set "autorefresh" to "PlainDir" sources (#128379)
- made source adding popups wider, added possibility to set URI
  directly (#120954)
- 2.13.6
* Wed Oct  5 2005 jsrain@suse.cz
- allow to break package download (#115534)
- fixed installation progress handling (#114653)
- 2.13.5
* Tue Oct  4 2005 jsrain@suse.cz
- correctly calculate used/free space on disks which are not
  formatted during installation (#113605)
- 2.13.4
* Tue Oct  4 2005 mir@suse.de
- inst_source_dialogs.ycp: added getUrl2 and editUrl2 which
  can deal with https if allowHttps is set. Needed for
  online_update_start.ycp to deal with https
  (Bug #118781, needs fix for yast2-online-update, too)
  (backport from 2.9.71)
- 2.13.3
* Mon Oct  3 2005 jsrain@suse.cz
- reinitialize slideshow data for 2nd round of package installation
  (#113946)
- changed the condition checking whether there is enough space to
  install a package (#115235)
- store list of failed packages from installation, offer to install
  them when later installing packages (#114658)
- enable visual feedback of package (un)installation related
  callback by default (#73044)
* Fri Sep 30 2005 jsrain@suse.cz
- fixed confusing popup after software installation (#113640)
- reinitialize language selection if user returns to initial
  language selection dialog (#114782)
- 2.13.2
* Tue Sep 27 2005 jsrain@suse.cz
- do not use confusing labels when modifying CD/DVD installation
  source (#116321)
* Mon Sep 26 2005 jsrain@suse.cz
- do not report void message when adding YUM source (#113688)
- react correctly on closing button of the window in installation
  source dialog (#114660)
- avoid modifying installed system if installing to directory
  (#86283)
- check whether running as root in 'yast -i' (#75335)
- 2.13.1
* Fri Sep 16 2005 kkaempf@suse.de
- allow slideshow path with long language code (#115589)
- 2.13.0
* Thu Sep  8 2005 jsrain@suse.cz
- fixed untranslated text in installation wizard (#114934)
- 2.12.31
* Tue Sep  6 2005 jsrain@suse.cz
- use correct icon for desktop selection dialog (#105158)
- install irqbalance on AMD64 SMP systems (#114425)
- 2.12.30
* Mon Sep  5 2005 lslezak@suse.cz
- detect all ready CD drives - enable using of more CD drives for
  installation (#114762), testsuite updated
- 2.12.29
* Fri Sep  2 2005 jsrain@suse.cz
- offer software selection when installing into directory (#105818)
- 2.12.28
* Fri Aug 26 2005 jsrain@suse.cz
- deselect package "ial" on Toshiba laptops (#112949)
- 2.12.27
* Thu Aug 25 2005 jsrain@suse.cz
- fixed unmounting of /sys and /proc during dirinstall (#104659)
- 2.12.26
* Wed Aug 24 2005 jsrain@suse.cz
- added missing translation mark (#106117)
- 2.12.25
* Mon Aug 22 2005 lslezak@suse.cz
- removed XEN dirinstall client (obsoleted by yast2-vm - full
  installation inside XEN VM) (#105831)
- 2.12.24
* Mon Aug 22 2005 jsrain@suse.cz
- do not put ACPI modules to initrd on architectures which do not
  support ACPI (#105997)
* Fri Aug 19 2005 jsrain@suse.cz
- changed the way source refresh is set on/off
- 2.12.23
* Thu Aug 18 2005 jsrain@suse.cz
- fixed list of packages for VNC installation (#105167)
- added alternative dialog for desktop selection (#104643)
- don't reset software selection if disk exhausted, just warn user
  and prevent from installing (#104626)
- 2.12.22
* Thu Aug 18 2005 lslezak@suse.cz
- checkmedia - adapted to the new version of checkmedia utility
* Thu Aug 18 2005 jsrain@suse.cz
- fixed switching automatical source refresh on/off (#104995)
* Mon Aug 15 2005 jsrain@suse.cz
- make the OK button in alternate desktops popup default button
  (#104589)
- merged texts from proofread
- 2.12.21
* Mon Aug 15 2005 jsrain@suse.cz
- changed description of software manager (#104076)
- 2.12.20
* Fri Aug 12 2005 jsrain@suse.cz
- don't ask for selections when packages in proposal selected
  (#104059)
* Fri Aug 12 2005 jsrain@suse.cz
- fixed several errors in code, added missing shortcuts
* Thu Aug 11 2005 jsrain@suse.cz
- changed the order of offered desktops (#103803)
- added missing comments for translators
* Wed Aug 10 2005 jsrain@suse.cz
- remember entered value for source location for "retry" (#102996)
- fixed pkgdb rebuilding callbacks (#78359)
- 2.12.19
* Tue Aug  9 2005 jsrain@suse.cz
- removed yast2-x11 from Requires and nfb (#102621)
- add the required ACPI modules to initrd always (#90345)
- show information text in the desktop selection dialog (#102943)
- 2.12.18
* Mon Aug  8 2005 jsrain@suse.cz
- add some ACPI modules to initrd (#90345)
- 2.12.17
* Mon Aug  8 2005 lslezak@suse.cz
- checkmedia - don't print MD5 checksum (#97207)
* Mon Aug  8 2005 jsrain@suse.cz
- fixed spacing in desktop selection dialog (#102537)
- force to resolve conflict in software selection dialog (#102539)
* Fri Aug  5 2005 jsrain@suse.cz
- added callbacks for source refresh
- updated the desktop selection dialog
- 2.12.16
* Fri Jul 29 2005 jsrain@suse.cz
- allow to show source URL without refresh check box needed for YOU
- 2.12.15
* Thu Jul 28 2005 jsrain@suse.cz
- merged texts from proofread
- 2.12.14
* Tue Jul 26 2005 jsrain@suse.cz
- added option to swith source auto-refresh on/off
- 2.12.13
* Fri Jul 22 2005 jsrain@suse.cz
- fix desktop selection dialog under NCurses (#97410)
- added help text to desktop selection dialog
- 2.12.12
* Fri Jul 15 2005 jsrain@suse.cz
- updated the inst_desktop cilent
- 2.12.11
* Thu Jul 14 2005 jsrain@suse.cz
- reset the proposal if desktop changes
- moved inst_desktop.ycp from yast2-installation
* Thu Jul 14 2005 jsrain@suse.cz
- adapted for desktop selection from installation wizard
- added simple proposal
- allowed to go back in installatino through checkmedia
- adapted to new partitioner using storage-lib (arvin)
- 2.12.10
* Mon Jul 11 2005 jsrain@suse.cz
- removed missed dependency on Display.ycp
- 2.12.9
* Mon Jul 11 2005 jsrain@suse.cz
- removed dependency on vanished Display.ycp to fix build
- 2.12.8
* Wed Jun 15 2005 jsrain@suse.cz
- fixed copying of gpg keys during installation (#84175)
- 2.12.7
* Tue Jun  7 2005 jsrain@suse.cz
- report meaningful error if installation source ID changes
  (#78998)
* Mon Jun  6 2005 jsrain@suse.cz
- fixed creating an image for directory installation (#86983)
- 2.12.6
* Wed Jun  1 2005 jsrain@suse.cz
- cache service pack CD if installed from DVD (#85850)
* Thu May 26 2005 jsrain@suse.cz
- cache packages from service pack CD (#85850)
* Mon May 23 2005 jsrain@suse.cz
- fixed integration of patch CD (#84735)
* Mon May 16 2005 jsrain@suse.cz
- rename 'default' variable (Runlevel::default)
- 2.12.5
* Tue May  3 2005 visnov@suse.cz
- replaced 'default', it's a keyword now
- 2.12.4
* Wed Apr 27 2005 jsrain@suse.cz
- added client for finishing basic installation
- 2.12.3
* Mon Apr 25 2005 jsrain@suse.cz
- enhanced selection of CD drive to use for isntallation (#75980)
* Wed Apr 20 2005 lslezak@suse.cz
- checkmedia - moved CD device probing to CheckMedia.ycp
  (see #75980)
* Tue Apr 19 2005 jsrain@suse.cz
- more adaptations to new interface of ProductFeatures.ycp
- 2.12.2
* Mon Apr 18 2005 jsrain@suse.cz
- adapted to new interface of ProductFeatures.ycp
- 2.12.1
* Wed Mar 30 2005 jsrain@suse.cz
- check for solver errors during installation proposal (#61787)
- 2.12.0
* Thu Mar 24 2005 jsrain@suse.cz
- display size of downloaded packages (#74012)
- warn user and enter single package selection if after setting
  base selection caused a conflict (#72423)
- report an error if yast -i is run on unexistent package (#71892)
* Mon Mar 14 2005 nashif@suse.de
- Reverted changes for space checking, needs more work
- 2.1.36
* Sat Mar 12 2005 nashif@suse.de
- Bug #67337: Create /var/lib/YaST2/runme_at_boot
- Bug #71973: Check for required space when installing into
  directory
- Bug #72257: select Xen when installing into directory
- 2.1.35
* Fri Mar 11 2005 lslezak@suse.cz
- fixed name of the icon for checkmedia client (#72160)
- 2.11.34
* Fri Mar 11 2005 jsrain@suse.cz
- fixed incorrecto counting of disk space (#71772)
- fixed generating list of language-dependend packages (#71099)
- ensure Pkg target is inited before installing a package via
  command-line (#71761)
- 2.11.33
* Mon Mar  7 2005 jsrain@suse.cz
- fixed counting disk size of packages to install (#67278)
* Thu Mar  3 2005 jsrain@suse.cz
- added xen-dirinstall client
* Wed Mar  2 2005 sh@suse.de
- Renamed some icons in .desktop files (name clashes)
* Wed Mar  2 2005 jsrain@suse.cz
- merged texts from proofread
* Wed Mar  2 2005 jsrain@suse.cz
- provide visual feedback before initializing package manager
* Tue Mar  1 2005 jsrain@suse.cz
- use product macro in desktop selection dialog help (#8876)
* Mon Feb 28 2005 lslezak@suse.cz
- checkmedia - UI fixes: header layout fixed, improved help text,
  disabled progress bar, use Close button instead of OK (#66642)
* Sat Feb 26 2005 nashif@suse.de
- Added missing import
- 2.11.29
* Wed Feb 23 2005 jsrain@suse.cz
- fixed comments for translators
- fixed some check_ycp errors
- changed the form of SMB/CIFS URL according to packagemanager
  (#53423)
- 2.11.28
* Mon Feb 21 2005 lslezak@suse.cz
- checkmedia - check wheter the drive contains CD1 when
  the module finishes (#65947)
- removed "CD/DVD Media Check" link from the installation proposal
- version 2.11.27
* Mon Feb 21 2005 jsrain@suse.cz
- fixed handling of samba URLs containing workgroup (#53423)
- display Samba as SMB/CIFS (#53423)
- 2.11.26
* Fri Feb 18 2005 lslezak@suse.cz
- checkmedia: unmount CD (allow to change the media) and remount
  back (#50627)
* Fri Feb 18 2005 jsrain@suse.cz
- import Product.ycp in inst_software in order to correctly replace
  the &product; macro in helps (#46247)
- 2.11.25
* Thu Feb 17 2005 nashif@suse.de
- Adapted creation of samba URLs (#26059)
- Do not rewrite multiple CD urls (multiple sources on CD) with one
  sinle URL read from install.inf
- Testsuites for source URLs
- V 2.11.24
* Thu Feb 17 2005 sh@suse.de
- Fixed bug #51006: sw_single during installation starts with "search"
- V 2.11.23
* Wed Feb 16 2005 jsrain@suse.cz
- fixed getting URL from install.inf if installation from CDs
  (#50893)
- 2.11.22
* Mon Feb 14 2005 jsrain@suse.cz
- fixed inst_custom_packages.ycp syntax
- 2.11.21
* Mon Feb 14 2005 lslezak@suse.cz
- checkmedia - fixed automatic start (#50621)
- 2.11.20
* Fri Feb 11 2005 nashif@suse.de
- disabled detecting slp sources
- 2.11.19
* Fri Feb 11 2005 jsrain@suse.cz
- better warning if out-of-disk-space during update (#50376)
- 2.11.18
* Thu Feb 10 2005 lslezak@suse.cz
- checkmedia - updated help texts, added read check, translate
  output from checkmedia
- 2.11.17
* Wed Feb  9 2005 nashif@suse.de
- Do not run remove_junk when updating on running system
* Wed Feb  9 2005 kkaempf@suse.de
- drop installation of fixed list of packages when PCMCIA is
  detected. Theses packages are covered by the 'laptop' selections.
* Wed Feb  9 2005 nashif@suse.de
- Added module SourceManager and client for 3rd party package
  installation
- 2.11.15
* Tue Feb  8 2005 kkaempf@suse.de
- add 'laptop' selections to proposal if PCMCIA interface
  is detected.
- 2.11.14
* Mon Feb  7 2005 jsrain@suse.cz
- merged texts from proofread
- 2.11.13
* Mon Feb  7 2005 jsrain@suse.cz
- display total size of packages to be installed
- install pbbuttonsd instead of pmud on PowerBooks
- 2.11.12
* Mon Jan 31 2005 lslezak@suse.cz
- checkmedia - show progress, show link in the software proposal
  only when using CD/DVD installation source
- version 2.11.11
* Fri Jan 28 2005 lslezak@suse.cz
- Check media feature (#100172)
- 2.11.10
* Mon Jan 24 2005 nashif@suse.de
- Set arguments according to new installation workflow interface
* Wed Jan 19 2005 jsrain@suse.cz
- removed unneeded import
- 2.11.7
* Tue Jan 11 2005 jsrain@suse.cz
- improve checks if base selection was changed (#37726)
- display information what package is downloaded in installation
  log (#37712)
- 2.11.6
* Mon Jan 10 2005 jsrain@suse.cz
- fixed parser of yast2/order and yast2/instorder files (#39405)
- displaying more meaningful label if cannot reach network server
  while installing packages (#28605)
* Fri Jan  7 2005 jsrain@suse.cz
- don't use YCP keyword as variable name
* Wed Jan  5 2005 jsrain@suse.cz
- adapted to new interface of Kernel.ycp
- 2.11.5
* Tue Jan  4 2005 jsrain@suse.cz
- fixed error reporting when unable to initialize isntallation
  source during installation (#40876)
- removed dependency on yast2-bootloader
* Thu Nov 11 2004 arvin@suse.de
- always use Directory::logdir
* Tue Nov  9 2004 arvin@suse.de
- added missing imports
* Wed Nov  3 2004 arvin@suse.de
- fixed return type of SourceChange
* Wed Oct 27 2004 arvin@suse.de
- adapted to new Mode.ycp
* Mon Oct 11 2004 jsrain@suse.cz
- adapted to new Arch:: interface
- 2.11.0
* Fri Oct  1 2004 sh@suse.de
- Fixed bug #44853 (again): Bad "next CD" msg upon last CD
- V 2.10.24
* Thu Sep 30 2004 arvin@suse.de
- removed confusing superfluous error message (bug #46411)
* Wed Sep 29 2004 arvin@suse.de
- fixed build
* Mon Sep 27 2004 kkaempf@suse.de
- Read(.probe.system) to get board/vendor specific packages
  (#35245), V 2.10.22
* Fri Sep 24 2004 sh@suse.de
- V 2.10.21
- Added some blanks as margin in slide show details table
* Thu Sep 23 2004 nashif@suse.de
- Use service pack even if the product CD has no order/instorder
  files in "yast2/"
* Thu Sep 23 2004 nashif@suse.de
- Copy service pack archive from the correct location
* Wed Sep 22 2004 sh@suse.de
- V 2.10.18
- Fixed bug #45824: Bad total slide show times if >2:00:00 per CD
* Wed Sep 22 2004 arvin@suse.de
- allow to disable some callbacks (needed for bug #45647)
* Thu Sep 16 2004 sh@suse.de
- V 2.10.16
- Reduced logging - no more complaints about no slides on CD2..CD10
- Fixed bug #44853: Bad "next CD" display when installing from the
  last CD
* Wed Sep 15 2004 sh@suse.de
- V 2.10.15
- Added check for 'nil' to avoid crashing back to linuxrc when no
  base selection is selected (bug #45312)
* Wed Sep  8 2004 sh@suse.de
- Fixed remaining times for CD2..CDx:
  Local variables shadowed each other
- Suppressed superfluous warning about non-existent widget `slideText
- V 2.10.14
* Tue Sep  7 2004 arvin@suse.de
- added proposal step to initialize sources (needed to solve
  bug #44724)
* Mon Sep  6 2004 visnov@suse.cz
- V 2.10.12
- ComputeKernelPackages moved to Kernel
* Fri Sep  3 2004 sh@suse.de
- V 2.10.11
- Fixed bug #44407: Faster restart of sw_single
  Now asking "Would you like to install more packages"
  rather than exiting right away
* Thu Sep  2 2004 sh@suse.de
- V 2.10.10
- Added package counter to slide show details table
* Mon Aug 30 2004 arvin@suse.de
- add nongpl kernel package during installation (bug #44394)
* Fri Aug 27 2004 sh@suse.de
- V 2.10.8
- Reduced debug logging
- Removed excessive debugging code
* Fri Aug 27 2004 sh@suse.de
- V 2.10.7
- First version of new slide show that actually displays slides
* Fri Aug 27 2004 arvin@suse.de
- merged proof read messages
* Mon Aug 23 2004 sh@suse.de
- V 2.10.5
- Replace &imagedir; with slide_pic_path in slide show
* Fri Aug 20 2004 sh@suse.de
- V 2.10.4
- First version (in CVS HEAD) with new slide show
* Wed Aug 18 2004 nashif@suse.de
- Using xorg-x11 instead of XFree86.
* Fri Aug 13 2004 kkaempf@suse.de
- add languagePackages() to select yast2-trans-$lang for each
  selected locales (#42844)
* Thu Aug 12 2004 nashif@suse.de
- merged changes for from 9.1 Branch (SLES,NLD)
  - Handle Service Pack CDs
  - Desktop Selection
* Tue Aug 10 2004 jsrain@suse.cz
- report if invalid source media location was entered (if media of
  other type than UnitedLinux is found) and ask user before adding
  such source (#43421)
* Thu Jul 29 2004 nashif@suse.de
- Remove Mode::live_eval
* Wed Jul 14 2004 jsrain@suse.cz
- report missing media properly (#42553)
* Wed Jun 16 2004 arvin@suse.de
- removed obsolete document y2c_spkg.html (bug #42048)
* Fri May 28 2004 arvin@suse.de
- nicer dialog with failed packages (bug #37529)
* Thu May 27 2004 arvin@suse.de
- fixed eject button (bug #39872)
* Tue May 25 2004 arvin@suse.de
- maybe fixed slide show (bug #38708)
* Fri May 21 2004 nashif@suse.de
- Use Report for failing messages
- Also allow space delimited fields in order/instorder
* Tue May 18 2004 sh@suse.de
- Changed slide show layout to make more CDs fit (bug #35612)
* Tue May  4 2004 arvin@suse.de
- merged proofread messages
* Tue Apr 27 2004 jsrain@suse.cz
- update EFI partitioning layout before package update starts
  (#21644)
- 2.9.45
* Thu Apr 22 2004 arvin@suse.de
- don't install iprutils on prep (bug #39292)
* Mon Apr  5 2004 arvin@suse.de
- load all network modules during update (bug #38115)
* Fri Apr  2 2004 arvin@suse.de
- finally changed license to GPL for good
* Thu Apr  1 2004 arvin@suse.de
- enhanced media label handling in media change callback
  (bug #35924)
* Thu Apr  1 2004 arvin@suse.de
- install download callbacks only during slide show (bug #37151)
* Thu Apr  1 2004 kkaempf@suse.de
- skip base selection screen if there is no choice (#37831)
* Wed Mar 31 2004 arvin@suse.de
- added product feature about suboptimal distribution (bug #36823)
* Tue Mar 30 2004 fehr@suse.de
- add storage dependent package to ComputeSystemPackageList (#37279)
- 2.9.39
* Mon Mar 29 2004 kkaempf@suse.de
- use the fallback kernel (#37326)
- 2.9.38
* Sat Mar 27 2004 arvin@suse.de
- fixed syntax error
* Fri Mar 26 2004 arvin@suse.de
- removed useless popup (bug #37042)
* Wed Mar 24 2004 arvin@suse.de
- fixed update of default runlevel for old distributions
* Wed Mar 24 2004 kkaempf@suse.de
- ppc64-tools -> ppc64-utils (#23386)
- 2.9.34
* Tue Mar 23 2004 arvin@suse.de
- disable reset of packagemanager again (bug #36788)
* Tue Mar 23 2004 kkaempf@suse.de
- Fix "progress done" popup (#36783)
- 2.9.32
* Tue Mar 23 2004 arvin@suse.de
- handle installation from name-based virtual hosts (bug #34452)
* Tue Mar 23 2004 lnussel@suse.de
- set sort key in desktop file to move module icon to front (#36466)
* Mon Mar 22 2004 arvin@suse.de
- reset packagemanager if user resets proposal (bug #35787)
* Fri Mar 19 2004 nashif@suse.de
- close all sources, target and reset destdir after die install
  (#36465)
* Wed Mar 17 2004 arvin@suse.de
- added download progress callbacks (bug #31445)
* Wed Mar 17 2004 arvin@suse.de
- don't ignore return of Pkg::DoProvide (bug #36022)
* Tue Mar 16 2004 kkaempf@suse.de
- run GNOME cleanup before upgrade starts (#36196)
* Sat Mar 13 2004 arvin@suse.de
- DVD sides are called "Side A" and "Side B"
* Fri Mar 12 2004 arvin@suse.de
- fixed use of Pkg::SourceGeneralData (bug #35712)
* Fri Mar 12 2004 sh@suse.de
- Fixed bug #34973: No slide show
  Now doing late initialization to overcome initialization
  dependencies
* Wed Mar 10 2004 sh@suse.de
- V 2.9.23
- Migration to new wizard
- Fixed ycpc complaints
* Tue Mar  9 2004 kkaempf@suse.de
- vnc -> tightvnc, drop mesasoft (ro@suse.de)
- use Report module (nashif@suse.de)
- 2.9.22
* Thu Mar  4 2004 kkaempf@suse.de
- revoke bugfix #35052, this needs another solution
* Thu Mar  4 2004 visnov@suse.cz
- 2.9.19
* Thu Mar  4 2004 kkaempf@suse.de
- implement full kernel fallback strategy
* Thu Mar  4 2004 visnov@suse.cz
- added type info
* Wed Mar  3 2004 nashif@suse.de
- Read product features from new feature module
* Wed Mar  3 2004 msvec@suse.cz
- fixed textdomain
- fixed one message to use plural
* Tue Mar  2 2004 arvin@suse.de
- make it build
* Fri Feb 27 2004 nashif@suse.de
- Move software_proposal from installation
- Adapted for new Control file
* Thu Feb 26 2004 kkaempf@suse.de
- install in one go if packages are coming via network (#35052)
* Wed Feb 25 2004 arvin@suse.de
- improved setting of locales of packagemanager
* Wed Feb 25 2004 arvin@suse.de
- fixed update mode (bug #34994 and #35007)
* Tue Feb 24 2004 arvin@suse.de
- check return value of Pkg::SourceProvideDir (bug #28346)
* Fri Feb 20 2004 arvin@suse.de
- during update make backup of /var/log/YaST2 and then remove it
  before starting real update (bug #31743)
* Fri Feb 20 2004 arvin@suse.de
- reduced minimum of free space required on a partition to 1 MB
  (bug #33074)
* Fri Feb 20 2004 arvin@suse.de
- removed yast2-mouse from neededforbuild
* Fri Feb 20 2004 cschum@suse.de
- Add support for canceling changes in the installation source
  configuration.
* Thu Feb 19 2004 kkaempf@suse.de
- drop "cpufreqd" and "apmd" on all platforms, now "powersave"
  will be installed.
* Thu Feb 19 2004 mvidner@suse.cz
- changed sort to use "<" instead of "<=" because of the switch to std::sort
* Mon Feb 16 2004 arvin@suse.de
- added more flexible package handling for products
* Mon Feb 16 2004 arvin@suse.de
- added yast2-x11 to requires (bug #34558)
* Thu Feb 12 2004 arvin@suse.de
- fixes for new interpreter
* Wed Feb 11 2004 arvin@suse.de
- more control over base selection handling
* Sat Feb  7 2004 arvin@suse.de
- removed config files (*.y2cc)
* Fri Feb  6 2004 gs@suse.de
- function keys added to buttons of the Source of Installation
  dialog
* Thu Feb  5 2004 arvin@suse.de
- fixed calling of Pkg::TargetInitDU
* Wed Feb  4 2004 arvin@suse.de
- fixed some SlideShow callbacks
* Sun Feb  1 2004 arvin@suse.de
- fixed return value in inst_kickoff.ycp
* Sat Jan 31 2004 arvin@suse.de
- fixed faking of mtab in inst_kickoff.ycp
- import Directory in inst_kickoff.ycp
* Mon Jan 19 2004 arvin@suse.de
- united inst_rpmcopy.ycp and inst_rpmupdate.ycp
- added inst_kickoff.ycp
* Fri Jan 16 2004 arvin@suse.de
- restore callbacks after slideshow
* Thu Jan 15 2004 jsrain@suse.de
- Require.ycp and package callbacks initialization moved to
  yast2.ycp
* Thu Nov 20 2003 sh@suse.de
- Break circular dependencies: Moved "import SlideShowCallbacks"
  from "SlideShow.ycp" to "Packager.ycp"
* Fri Oct 24 2003 arvin@suse.de
- better (more inexpressive) message during rpm database convert
  (bug #30457)
* Thu Oct 23 2003 jsrain@suse.de
- made more interface of Require global
* Tue Sep 23 2003 arvin@suse.de
- fixed media change callback for double sided media
* Tue Sep 23 2003 sh@suse.de
- Fixed bug #31491: No slide show in exotic update case
* Tue Sep 23 2003 sh@suse.de
- V 2.8.24
- Fixed bug #31606: Undeclared variable in SlideShow.ycp
* Sun Sep 21 2003 arvin@suse.de
- finished support of double sided media
* Fri Sep 19 2003 kkaempf@suse.de
- add numactl on AMD64-smp systems (#31338)
* Thu Sep 18 2003 sh@suse.de
- V 2.8.22
- Fixed bug #31140: Predicted SlideShow timings
* Thu Sep 11 2003 kkaempf@suse.de
- move Pkg::SetLocale() to Packages::Init() (#30438)
* Tue Sep  9 2003 kkaempf@suse.de
- install 'cpufreqd' on laptops and
  single-processor AMD64 systems.
* Mon Sep  8 2003 arvin@suse.de
- sync rpm database
* Fri Sep  5 2003 sh@suse.de
- V 2.8.18
- Fixed bug #30151: Start pkg mgr in search mode by default
* Thu Sep  4 2003 arvin@suse.de
- proof-read messages
* Thu Sep  4 2003 kkaempf@suse.de
- clear list of yet-to-be-installed packages if all packages
  are installed.
* Thu Sep  4 2003 kkaempf@suse.de
- acpid is installed by default now
* Tue Sep  2 2003 kkaempf@suse.de
- add code to ask for front or back side of a media (unfinished).
* Sun Aug 31 2003 arvin@suse.de
- use Popup::ConfirmAbort
* Sat Aug 30 2003 arvin@suse.de
- fixed installing of required bootloader on alpha
* Fri Aug 29 2003 arvin@suse.de
- implemented callbacks for converting rpm database (bug #29484)
* Thu Aug 28 2003 arvin@suse.de
- run inst_rpmcopy during update after reboot
* Tue Aug 26 2003 kkaempf@suse.de
- don't release the sources in sw_single any more, the package-
  manager handles this.
* Tue Aug 26 2003 msvec@suse.cz
- add a proper error reporting (#29325)
- added missing imports
- 2.8.11
* Fri Aug 22 2003 lnussel@suse.de
- add code for installing into a directory
* Fri Aug 22 2003 arvin@suse.de
- skip inst_rpmcopy for update
* Thu Aug 21 2003 nashif@suse.de
- Install post-package from CD1 in autoinst mode
* Tue Aug 19 2003 arvin@suse.de
- always use String::FormatSize
* Tue Aug 19 2003 arvin@suse.de
- fixed failed package message (bug #29091)
* Fri Aug 15 2003 arvin@suse.de
- fixed summary of failed packages (bug #28758)
* Mon Aug  4 2003 jsrain@suse.de
- Enhanced Require in order to provide information if
  RequireAndConflict* was canceled by user or really failed
- 2.8.6
* Tue Jul 22 2003 cschum@suse.de
- Added "Replace" button to inst_source module (#25260).
- Let user edit URL in case of error (#21582).
- 2.8.5
* Mon Jul 21 2003 mvidner@suse.cz
- Require::DoInstallAndRemove...: do not return nil.
- 2.8.4
* Thu Jun 26 2003 msvec@suse.de
- using Label and Popup modules instead of includes in require.ycp
- 2.8.3
* Tue Jun 17 2003 jsrain@suse.de
- using Label and Popup modules instead of includes in Require.ycp
- 2.8.2
* Wed May  7 2003 kkaempf@suse.de
- add scpm, acpid, and irda if laptop (#26561)
- 2.8.1
* Tue Apr  1 2003 arvin@suse.de
- fixed text in software selection (bug #25507)
- 2.8.0
* Mon Mar 17 2003 kkaempf@suse.de
- drop extra code for certify CD, it's not needed any more.
- 2.7.33
* Sun Mar 16 2003 kkaempf@suse.de
- call SlideShow::InitPkgData() after package status is
  determined (#25437)
- 2.7.32
* Sat Mar 15 2003 kkaempf@suse.de
- don't call SpaceCalculation::GetPartitionInfo() at runtime,
  yast2-packagemanager does it itself (#23544)
- 2.7.31
* Sat Mar 15 2003 kkaempf@suse.de
- fix typo in widget type
- 2.7.30
* Thu Mar 13 2003 kkaempf@suse.de
- save the list of remaining source packages to srcremaining,
  re-read it in 2nd stage install and mark these packages
  as source-to-install properly. (#25318)
- 2.7.29
* Tue Mar 11 2003 mvidner@suse.de
- Do not run SuSEconfig in [Rr]equire.ycp when adding packages
  during installation. Real fix for (#25071).
- 2.7.28
* Tue Mar 11 2003 kkaempf@suse.de
- always let TargetInit create everything which doesn't exist.
  (#24932)
* Tue Mar 11 2003 kkaempf@suse.de
- fix parameters of doneProvide() callback (#25081)
- 2.7.25
* Tue Mar 11 2003 kkaempf@suse.de
- do not run SuSEconfig when adding packages during installation
  (#25071)
- 2.7.24
* Tue Mar 11 2003 sh@suse.de
- Fixed blocker bug #25055: Change CD popup hangs
* Tue Mar 11 2003 cschum@suse.de
- Don't wronlgy display an error when adding installation source
  from local directory (#24996).
- 2.7.22
* Mon Mar 10 2003 kkaempf@suse.de
- fix syntax error in Require.ycp (#24994)
- 2.7.21
* Mon Mar 10 2003 kkaempf@suse.de
- error popups have "Abort", "Retry", "Ignore" as buttons.
* Mon Mar 10 2003 mvidner@suse.de
- [Rr]equire.ycp: fixed package installation after YOU (#24744).
- 2.7.19
* Sat Mar  8 2003 arvin@suse.de
- added missing include statements (bug #24881)
* Thu Mar  6 2003 kkaempf@suse.de
- prepend msg and button functions with UI:: namespace (#24704)
* Wed Mar  5 2003 kkaempf@suse.de
- enhance provideDone and packageDone callbacks to pop up
  a window on error, displaying the error code and the last
  10 lines (tail) from y2logRPM. Offer ok/retry/skip/abort
  buttons and return the button code to the packagemanager.
  (#23780)
- 2.7.17
* Wed Mar  5 2003 kkaempf@suse.de
- fallback to "k_deflt" if real kernel not available (#16047)
* Tue Mar  4 2003 kkaempf@suse.de
- use new state checking functions to decide if the user has
  changed the selection (#23616)
* Mon Mar  3 2003 gs@suse.de
- pass the floppy device to PackageSelector widget (needed to save
  or load a package selection, bug #23923)
* Mon Mar  3 2003 arvin@suse.de
- once more merged proofread texts
* Fri Feb 28 2003 kkaempf@suse.de
- don't start source unconditionally (in constructor) any more,
  but only if explicitly requested (#24201)
* Fri Feb 28 2003 kkaempf@suse.de
- fix parameter for Pkg::DoProvide()
* Fri Feb 28 2003 kkaempf@suse.de
- hide username:password from URL logging (#24473)
* Thu Feb 27 2003 mvidner@suse.de
- require.ycp:
  * Fix not recognizing installed packages (#23882).
  * Do not call "Reading package information" until necessary (#20486).
- 2.7.12
* Wed Feb 26 2003 kkaempf@suse.de
- pass language to packagemanager (#23828)
* Wed Feb 26 2003 gs@suse.de
- bugfix in space calculation module (bug #24311)
* Mon Feb 24 2003 kkaempf@suse.de
- Allow "yast2 -i <tagname>" besides "yast2 -i <packagename>".
* Mon Feb 24 2003 cschum@suse.de
- Moved "Enable or Disable" button to own row (#20776).
* Fri Feb 21 2003 sh@suse.de
- Fixed bug #23945: SpaceCalculation 14%% off
* Thu Feb 20 2003 arvin@suse.de
- use title-style capitalization for menu names (bug #23848)
* Wed Feb 19 2003 kkaempf@suse.de
- only offer eject button for cd or dvd (#23827)
- reduce duplicate code
* Wed Feb 19 2003 kkaempf@suse.de
- check existance of id(`url) widget before checking its
  contents (#23786)
* Wed Feb 19 2003 kkaempf@suse.de
- keep silent if no backup_path exists (#23784)
* Tue Feb 18 2003 kkaempf@suse.de
- stop timer during wait for medium (#21026)
* Mon Feb 17 2003 cschum@suse.de
- inst_source: Removed back and abort button because they didn't work.
- inst_source: Don't show redundant cd selection dialog.
- inst_source: Show "Adding source ..." dialog while adding a source.
* Tue Feb 11 2003 kkaempf@suse.de
- Correct error message (#21754)
* Mon Feb 10 2003 nashif@suse.de
- Modified names of autoinstall modules
- 2.7.5
* Fri Feb  7 2003 arvin@suse.de
- add package ppc64-tools on chrp ppp64 boards (bug #23386)
* Mon Feb  3 2003 arvin@suse.de
- new pot file handling
* Thu Jan 30 2003 arvin@suse.de
- fixed autoinstalling of graphics packages (bug #22936)
* Tue Jan 28 2003 arvin@suse.de
- fixed installation from DVD in VMWare (bug #21226)
* Fri Jan 24 2003 gs@suse.de
- Calling SuSEConfig after deleting a package only (#22317)
* Tue Jan 14 2003 arvin@suse.de
- support installation from DVD for drives that also have other
  capability (bug #20068)
* Fri Oct 18 2002 kkaempf@suse.de
- de-select last tried selection if none of the base selections
  fits the current partitioning.
- remember if a "file provide" progress was started (for remote
  package sources).
- 2.6.78
* Fri Oct 18 2002 kkaempf@suse.de
- remember choosen selection only if the selection fits, else
  force re-calculation of selections (#21077)
- 2.6.77
* Thu Oct 17 2002 sh@suse.de
- V 2.6.76
- Recalc current medium progress on medium change
* Thu Oct 17 2002 kkaempf@suse.de
- fix progress bar to stay on correct source
- 2.6.75
* Wed Oct 16 2002 sh@suse.de
- V 2.6.74
- Fixed bug #20988: Time estimate for unneeded CD shown
* Tue Oct 15 2002 sh@suse.de
- V 2.6.72
- Fixed bug #20008: Block installation if insufficient disk space
  even for minimal system
* Mon Oct 14 2002 sh@suse.de
- Better fix for bug#20686 (partition overflow):
  Don't reset all SW settings, just warn what partition is
  overflowed
* Fri Oct 11 2002 sh@suse.de
- Fixed bug #20686: SW selection resets without warning upon
  partition overflow
- V2.6.70
* Fri Oct 11 2002 kkaempf@suse.de
- only activate the proposed selections if it's a new proposal.
  (#20194)
- 2.6.69
* Fri Oct 11 2002 kkaempf@suse.de
- fix URL construction if installing from harddisk partition
  (#19803, lnussel@suse.de)
- 2.6.68
* Wed Oct  9 2002 kkaempf@suse.de
- fix cd progress bar display when installing from
  multiple source (#20726)
- 2.6.67
* Tue Oct  8 2002 kkaempf@suse.de
- fix SlideShow to display media sorted by source sorted by
  installation order (sh@suse.de)
- 2.6.66
* Mon Oct  7 2002 kkaempf@suse.de
- read "yast/instorder" to specify installation order (#20609)
- 2.6.65
* Tue Oct  1 2002 kkaempf@suse.de
- pass media number '0' to PkgCommit so all CDs get installed
  in a single run.
- 2.6.64
* Tue Oct  1 2002 kkaempf@suse.de
- when slide show is available, display download progress in
  existing progress bar instead of an extra popup window.
* Tue Oct  1 2002 kkaempf@suse.de
- fix sorting selections by order. Allow multiple selections
  with equal order.
* Mon Sep 30 2002 kkaempf@suse.de
- declare 'shutup' where needed.
* Thu Sep 26 2002 arvin@suse.de
- more fixes for slide show
* Wed Sep 25 2002 arvin@suse.de
- if necessary append leading slash to serverdir of
  installation url (bug #20152)
* Tue Sep 24 2002 arvin@suse.de
- workaround to get slide show working on systems with
  big memory
* Fri Sep 20 2002 kkaempf@suse.de
- add SourceChange callback
- 2.6.60
* Thu Sep 19 2002 kkaempf@suse.de
- replace unused variable in space calculation
- 2.6.59
* Thu Sep 19 2002 kkaempf@suse.de
- fix SpaceCalculation, it's all in bytes.
- usage calculation in packagemanager returns the
  new usage (current usage + package diff), not the diff only.
- dont restart packagemanager internally.
- drop unneeded popup during packager init.
- 2.6.58
* Wed Sep 18 2002 kkaempf@suse.de
- implement separated installation and product medias.
- 2.6.57
* Tue Sep 17 2002 kkaempf@suse.de
- read y2logRPM from target directory (#19772)
* Mon Sep 16 2002 mvidner@suse.de
- Added missing translation marks to On/Off (inst. source selection).
* Mon Sep 16 2002 kkaempf@suse.de
- remove unneeded Packages::Save() (#19591)
- 2.6.56
* Fri Sep 13 2002 kukuk@suse.de
- Revert fix for space calculation, breaks space calculation on
  update (workaround for #19657)
* Fri Sep 13 2002 lnussel@suse.de
- initialize target system in continue mode too, to make backup work (#19620)
- 2.6.55
* Fri Sep 13 2002 lnussel@suse.de
- fix wrong function call for space calculation
- 2.6.54
* Fri Sep 13 2002 mvidner@suse.cz
- Re-fixed #19550: kernel change would never be detected.
- 2.6.53
* Fri Sep 13 2002 lnussel@suse.de
- treat nil as empty too
- 2.6.51
* Fri Sep 13 2002 lnussel@suse.de
- read /var/lib/YaST2/backup_path to determine wheter backups have to be created
- 2.6.51
* Thu Sep 12 2002 kkaempf@suse.de
- release media at end
- 2.6.49
* Thu Sep 12 2002 kkaempf@suse.de
- call rewriteUrl correctly (#19501)
- start package at 0%%, end at 100%% (#19506)
- popup "please wait" during packagemanager init
- drop unused CallbackDisplayError()
- display full slide show during runtime (#19496)
- correctly evaluate return from package selection (#19055)
- check if kernel changed in sw_single (#19550)
- 2.6.48
* Wed Sep 11 2002 kkaempf@suse.de
- save/restore state of packages
- allow to abort during package installation
- 2.6.47
* Wed Sep 11 2002 kkaempf@suse.de
- fix callback label display (gs@suse.de) (#19178)
- 2.6.46
* Wed Sep 11 2002 kkaempf@suse.de
- solve packages installed with "yast2 -i" and popup
  conflicts if any exist.
- 2.6.45
* Wed Sep 11 2002 kkaempf@suse.de
- correctly init SpaceCalculation during runtime (#19458)
- 2.6.44
* Wed Sep 11 2002 kkaempf@suse.de
- evaluate return code from package selection (#19142)
- 2.6.43
* Wed Sep 11 2002 kkaempf@suse.de
- rewrite cd/dvd url in 2nd stage of installation (#19185)
- 2.6.42
* Tue Sep 10 2002 kkaempf@suse.de
- drop argument "beginner" in calling sw_single
- 2.6.41
* Tue Sep 10 2002 kkaempf@suse.de
- full source media manager (cschum@suse.de)
- show failed packages or full log after PackageInstallation
- 2.6.40
* Tue Sep 10 2002 kkaempf@suse.de
- Add "url" text entry to media change popup
- 2.6.39
* Mon Sep  9 2002 kkaempf@suse.de
- show "Ignore" only if prompting with wrong media
- 2.6.38
* Mon Sep  9 2002 kkaempf@suse.de
- fix handling of installation sources (cschum@suse.de)
- move source handling to spkg (runtime stuff)
- init SpaceCalculation at runtime properly
- 2.6.36
* Mon Sep  9 2002 mvidner@suse.cz
- require.ycp: Fixed DoInstallAndRemove (#18904).
- 2.6.35
* Mon Sep  9 2002 kkaempf@suse.de
- check base selections in reverse order for matching partition
  space (default ... minimal). Selection with highest priority
  matching the current partitioning will be choosen (#18855)
- 2.6.34
* Mon Sep  9 2002 kkaempf@suse.de
- call solver after activating selections
- allow installing list of packages from ascii file
- fix filtering network related data from install.inf
- 2.6.33
* Mon Sep  9 2002 kkaempf@suse.de
- InstURL: default directory to "/"
- PackageCallbacks: remove bogus loop
- 2.6.32
* Sun Sep  8 2002 kkaempf@suse.de
- pass correct locale to packagemanager
- filter /etc/install.inf entries, linuxrc bug workaround
- 2.6.31
* Sat Sep  7 2002 kkaempf@suse.de
- adapt media change api
- 2.6.30
* Sat Sep  7 2002 kkaempf@suse.de
- pass probed devices to URL
- 2.6.29
* Fri Sep  6 2002 kkaempf@suse.de
- prepare for handling of multiple sources (cschum@suse.de)
- 2.6.28
* Fri Sep  6 2002 kkaempf@suse.de
- report failed packages properly (#19022)
- addind missing import to Packages.ycp (nashif@suse.de)
- 2.6.27
* Thu Sep  5 2002 kkaempf@suse.de
- properly detect cd,dvd drives
- 2.6.26
* Thu Sep  5 2002 mvidner@suse.cz
- require.ycp: Adapted for the new packagemanager, yet again. (#18904)
- 2.6.25
* Wed Sep  4 2002 kkaempf@suse.de
- fix run-time package selection
- 2.6.24
* Wed Sep  4 2002 kkaempf@suse.de
- force /dev/cdrom symlink
- 2.6.23
* Wed Sep  4 2002 kkaempf@suse.de
- Fix MediaChange callback in PackageCallbacks
  import old code from MediaUI. Drop MediaUI.
- 2.6.22
* Wed Sep  4 2002 mvidner@suse.cz
- Re-added require.ycp which got dropped by an accident.
- 2.6.21
* Tue Sep  3 2002 kkaempf@suse.de
- improved callback handling
- cleaned up sw_single
- 2.6.20
* Thu Aug 29 2002 kkaempf@suse.de
- symlink /dev/cdrom for DVD too
- 2.6.19
* Thu Aug 29 2002 kkaempf@suse.de
- activate selections before entering package manager (#18501)
- show all selected selections in proposal (#18523)
* Wed Aug 28 2002 kkaempf@suse.de
- Add directory to Url if not given by linuxrc
- 2.6.18
* Wed Aug 28 2002 kkaempf@suse.de
- drop InstMedia, it's all in packagemanager now
- 2.6.17
* Tue Aug 27 2002 kkaempf@suse.de
- fix installation workflow to properly report progress
- 2.6.16
* Mon Aug 26 2002 mvidner@suse.cz
- require.ycp: Adapted for the new packagemanager.
- require.ycp: New function IsPackageAvailable.
- 2.6.15
* Mon Aug 26 2002 kkaempf@suse.de
- copy /etc/passwd and /etc/group from inst-sys to target (#18243).
* Thu Aug 22 2002 kkaempf@suse.de
- default to UnitedLinux.sel if default.sel missing
  default to first available base selection if UnitedLinux.sel
  missing too.a
  give up and make a blocker error if no base selection exists.
  (#18207)
* Wed Aug 21 2002 nashif@suse.de
- disabled testsuite for spkg for now
- fixed spec
* Wed Aug 21 2002 kkaempf@suse.de
- fix for build
  V 2.6.12
* Wed Aug 21 2002 kkaempf@suse.de
- initial switch to new packagemanager.
- V 2.6.11
* Mon Aug 12 2002 kkaempf@suse.de
- fix /etc/install.inf:InstMode reading.
- fix network parameters reading.
* Mon Aug  5 2002 arvin@suse.de
- changes for new /etc/install.inf agent
* Mon Aug  5 2002 kkaempf@suse.de
- added xf86, mesasoft to required packages for vnc installation
- provide create_update_inf
* Fri Aug  2 2002 arvin@suse.de
- added yast2-qt to required packages for vnc installation
* Mon Jul 29 2002 arvin@suse.de
- make correct package
* Fri Jul 26 2002 ms@suse.de
- changed use of X11 module. The X11 module does no longer exist
  to provide the information of "having X11" installed (have_x11) the
  module X11Version is used
* Wed Jul 24 2002 kkaempf@suse.de
- provide "create_update_inf"
* Tue Jul 16 2002 arvin@suse.de
- include rpm groups names for translation
* Tue Jul  9 2002 mvidner@suse.cz
- fixed Provides/Obsoletes
* Sat Jul  6 2002 arvin@suse.de
- added config files to file list
* Thu Jul  4 2002 arvin@suse.de
- added ag_instsource to file list
- fixed location of include files
* Wed Jul  3 2002 arvin@suse.de
- merged yast2-agent-package and yast2-agent-targetpkg
- moved non binary files to /usr/share/YaST2
* Mon Jul  1 2002 arvin@suse.de
- fixed linking on lib64 archs
* Mon Jul  1 2002 arvin@suse.de
- merged libpkg, client-packager (for yast2-core-clients) and
  some package related scripts (from yast2-inst) to new
  package yast2-packager
